@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -157,7 +157,7 @@ public class Action {
 	int wTexte, hTexte;
 	// fonte du texte
 	// TODO : les '*' sont mal rendus (pb de fonte), faut il passer  une fonte PLAIN ?
-	static private Font FONT = Aladin.SBOLD;//new Font("SansSerif",Font.PLAIN,  Aladin.SIZE-1);
+	static private Font FONT = Aladin.SBOLD;
 	static private int FONT_SIZE = Aladin.SSIZE;//Aladin.SIZE-1;
 
     // Reference to Aladin
@@ -1319,7 +1319,8 @@ public class Action {
             Iterator<Obj> it = ((PlanCatalog)plans[i]).iterator();
             for( j=0; it.hasNext(); j++ ) {
                Obj o = it.next();
-               if( !(o instanceof Source) ) continue;
+//               if( !(o instanceof Source) ) continue;
+               if( !o.asSource() ) continue;
                Source s = (Source)o;
 
                 if( s!=null) {
@@ -1362,7 +1363,8 @@ public class Action {
     	    Iterator<Obj> it = p.iterator();
     	    for( j=0; it.hasNext(); j++ ) {
     	         Obj o = it.next();
-    	         if( !(o instanceof Source) ) continue;
+//    	         if( !(o instanceof Source) ) continue;
+    	         if( !o.asSource() ) continue;
     	         Source s = (Source)o;
 
     	   	    if( s!=null) {
@@ -1404,7 +1406,8 @@ public class Action {
     	    Iterator<Obj> it = ((PlanCatalog)p).iterator();
     	    for( j=0; it.hasNext(); j++ ) {
     	         Obj o = it.next();
-    	         if( !(o instanceof Source) ) continue;
+//    	         if( !(o instanceof Source) ) continue;
+                 if( !o.asSource() ) continue;
     	         Source s = (Source)o;
 
     	        if( s!=null) {
@@ -1977,7 +1980,7 @@ public class Action {
 		double petitAxe = Math.sqrt(Math.pow(p2.x-p1.x,2)+Math.pow(p2.y-p1.y,2));
 
 	      // Ne passe-t-on pas "derrire le ciel" - Modif PF dc 2010
-        if( proj.t==Calib.AIT || proj.t==Calib.MOL ) {
+        if( proj.t==Calib.AIT || proj.t==Calib.MOL) {
            Coord coordBis = new Coord(s.raj,s.dej);
            coordBis.al -= (majAxis/3600)*Math.sin(posAngle*2*Math.PI/360)/Math.cos(coordBis.del*2*Math.PI/360);
            coordBis.del -= (majAxis/3600)*Math.cos(posAngle*2*Math.PI/360);
