@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -25,8 +25,6 @@ import java.net.URL;
 import java.util.Hashtable;
 import java.util.Iterator;
 
-import cds.xml.Field;
-
 /**
  * <P>Aladin stack plane access for plugins. </P>
  * This class allows Aladin compatible plugins to access the stack plane data.
@@ -125,7 +123,14 @@ public class AladinData {
    public double [][] getPixels() throws AladinException {
       testImage();
       testHuge();
-      return ((PlanImage)plan).getPixels();
+      PlanImage p = (PlanImage)plan;
+      double [][] pix = null;
+      try {
+         p.setLockCacheFree(true);
+         if( !p.hasOriginalPixels() || !p.pixelsOriginFromCache() ) throw new AladinException(ERR004);
+         pix = ((PlanImage)plan).getPixels();
+      } finally { p.setLockCacheFree(false); }
+      return pix;
    }
 
    /** Return the full pixel value convert in double for a dedicated position.
@@ -137,11 +142,15 @@ public class AladinData {
    public double getPixel(int x,int y) throws AladinException {
       testImage();
       testHuge();
-      if( !((PlanImage)plan).hasOriginalPixels()
-            || !((PlanImage)plan).pixelsOriginFromCache() ) throw new AladinException(ERR004);
-      if( x<0 || x>=((PlanImage)plan).naxis1
-       || y<0 || y>=((PlanImage)plan).naxis2 ) return Double.NaN;
-      return ((PlanImage)plan).getPixelOriginInDouble(x, y);
+      PlanImage p = (PlanImage)plan;
+      double pix=Double.NaN;
+      try {
+         p.setLockCacheFree(true);
+         if( !p.hasOriginalPixels() || !p.pixelsOriginFromCache() ) throw new AladinException(ERR004);
+         if( x<0 || x>=p.naxis1 || y<0 || y>=p.naxis2 ) return Double.NaN;
+         pix = p.getPixelOriginInDouble(x, y);
+      } finally { p.setLockCacheFree(false); }
+      return pix;
    }
 
    /** Return the full pixel value from a cube convert in double for a dedicated position.
@@ -366,9 +375,10 @@ public class AladinData {
    public byte [] seeCodedPixels() throws AladinException {
       testImage();
       testHuge();
-      if( !((PlanImage)plan).hasOriginalPixels()
-            || !((PlanImage)plan).pixelsOriginFromCache() ) throw new AladinException(ERR004);
-      return ((PlanImage)plan).pixelsOrigin;
+      PlanImage p = (PlanImage)plan;
+      p.setLockCacheFree(true);
+      if( !p.hasOriginalPixels() || !p.pixelsOriginFromCache() ) throw new AladinException(ERR004);
+      return p.pixelsOrigin;
    }
 
    /**
@@ -382,7 +392,7 @@ public class AladinData {
     */
    public Hashtable seeFitsKeys() throws AladinException {
       testImage();
-      fitsKeysModified();
+//      fitsKeysModified();   // Aucune raison de le faire ici PF. 8/10/2021
       return ((PlanImage)plan).headerFits.getHeaderFits().getHashHeader();
    }
 
@@ -458,6 +468,7 @@ public class AladinData {
    public double[] getCoord(double x, double y) throws AladinException {
       testImage();
       if( !Projection.isOk(plan.projd) ) throw new AladinException(ERR006);
+      Coord coo = new Coord();
       coo.x = x-0.5; coo.y = y-0.5;
       coo.y = ((PlanImage)plan).naxis2 - coo.y ;
       plan.projd.getCoord(coo);
@@ -473,10 +484,11 @@ public class AladinData {
     */
    public double [] getXY(double ra, double dec) throws AladinException {
       if( !Projection.isOk(plan.projd) ) throw new AladinException(ERR006);
+      Coord coo = new Coord();
       coo.al = ra; coo.del = dec;
       plan.projd.getXY(coo);
       coo.y = ((PlanImage)plan).naxis2 - coo.y;
-      return new double[]{coo.x,coo.y};
+      return new double[]{coo.x+0.5,coo.y+0.5};
    }
 
    // ********************** OVERLAY PLANE METHODS ****************************** //
@@ -547,6 +559,15 @@ public class AladinData {
     */ 
    public void setName(String [] name) { leg = Legende.adjustDefaultLegende(leg,Legende.NAME,name); }
    
+   /** FOR ADVANCED DEVELOPERS ONLY !
+    * This method is dedicated to the overlay planes and specifically source planes
+    * For providing a fast and direct way for creating overlay source plane.
+    * Set the column description list for a source plane.
+    * @see addObj(Obj obj) method for adding new sources
+    * @param name column description list
+    */ 
+   public void setDescription(String [] desc) { leg = Legende.adjustDefaultLegende(leg,Legende.DESCRIPTION,desc); }
+   
    /** FOR ADVANCED DEVELOPERS ONLY !
     * This method is dedicated to the overlay planes and specifically source planes
     * For providing a fast and direct way for creating overlay source plane.
@@ -669,9 +690,6 @@ public class AladinData {
    // Plane reference
    protected Plan plan;
 
-   // pre-allocation
-   private final Coord coo = new Coord();
-
    // current source plane "legende" (see setName())
    private Legende leg=null;
 
@@ -712,10 +730,20 @@ public class AladinData {
       if( plan==null ) throw new AladinException(ERR001);
    }
    
+   /**
+    * Aladin plane data for the specified plane
+    * @param aladin Aladin object reference
+    * @param planeHashCode plane hashCode (see getPlaneHashCode())
+    * @throws AladinException
+    */
+   public AladinData(Aladin aladin,Plan plan) throws AladinException {
+      this.plan = plan;
+   }
+   
    /**
     * Aladin plane data creation and/or simple access.
     * @param aladin aladin object reference
-    * @param mode Plan mode:  0-get a plane, 1-create a new image, 2-create a new catalog
+    * @param mode Plan mode:  0-get a plane, 1-create a new image, 2-create a new catalog, 3-create a new plantool
     * @param name plane name for mode 0 (as displayed in the Aladin stack)
     * @throws AladinException
     */
@@ -758,10 +786,16 @@ public class AladinData {
                plan.planReady(true);
                
                // catalog
-            } else {
+            } else if( mode==2 ) {
                planeID = aladin.calque.newPlanPlugCat(name);
                plan = aladin.calque.getPlan(planeID,1);
-            }
+               
+               // Graphic
+            } else if( mode==3 ) {
+               planeID = aladin.calque.newPlanPlugTool(name);
+               plan = aladin.calque.getPlan(planeID,1);
+               
+            } else throw new Exception();
          } catch( Exception e ) { throw new AladinException(AladinData.ERR009); }
       }
    }
@@ -787,11 +821,11 @@ public class AladinData {
       if( !plan.isReady() ) throw new AladinException(ERR002);
       if( plan.pcat==null ) throw new AladinException(ERR007);
    }
-
+   
    // Create a new projection associated to the plane
    private void setCalib() {
       try {
-         Projection proj = new Projection(Projection.WCS,new Calib(((PlanImage)plan).headerFits.getHeaderFits()));
+         Projection proj = new Projection(Projection.WCS,new Calib(((PlanImage)plan).headerFits.getHeaderFits()),plan);
          plan.setNewProjD(proj);
          plan.setHasSpecificCalib();
          repaint();
