@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -112,10 +112,14 @@ public final class CanvasPixelRange extends JPanel  implements MouseMotionListen
       if( isFitsHiPS ) { rectRange.x+=20; rectRange.width -= 2*20; }
 
       if( isFullDynamic ) {
-         pixelRangeMin = pimg.dataMin * pimg.bScale + pimg.bZero;
-         pixelRangeMax = pimg.dataMax * pimg.bScale + pimg.bZero;
-         pixelCutMin   = pimg.pixelMin* pimg.bScale + pimg.bZero;
-         pixelCutMax   = pimg.pixelMax* pimg.bScale + pimg.bZero;
+//         pixelRangeMin = pimg.dataMin * pimg.bScale + pimg.bZero;
+//         pixelRangeMax = pimg.dataMax * pimg.bScale + pimg.bZero;
+//         pixelCutMin   = pimg.pixelMin* pimg.bScale + pimg.bZero;
+//         pixelCutMax   = pimg.pixelMax* pimg.bScale + pimg.bZero;
+         pixelRangeMin = pimg.uncompressPixel(pimg.dataMin);
+         pixelRangeMax = pimg.uncompressPixel(pimg.dataMax);
+         pixelCutMin   = pimg.uncompressPixel(pimg.pixelMin);
+         pixelCutMax   = pimg.uncompressPixel(pimg.pixelMax);
 
          if( pixelCutMin<pixelRangeMin ) pixelRangeMin=pixelCutMin;
          if( pixelCutMax>pixelRangeMax ) pixelRangeMax=pixelCutMax;
