@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -60,7 +60,7 @@ public class Constellation {
          is = new BufferedReader(new InputStreamReader(
                    aladin.getClass().getResourceAsStream("/"+CONSTELLATION_FILE)));
          
-         cstMap = new HashMap<String, ArrayList<Position>>();
+         cstMap = new HashMap<>();
          String s,oCst=null;
          ArrayList<Position> cc = null;
          LigneConst oc = null;
@@ -125,11 +125,11 @@ public class Constellation {
                   }
                   
                   // Prparation de la liste des coordonnes de la nouvelle constellation
-                  cc = new ArrayList<Position>();
+                  cc = new ArrayList<>();
                   
                   // Generation d'une projection centre sur la constellation
                   // afin de dterminer la position du label au barycentre
-                  proj = new Projection(null,Projection.WCS,ra,dec,60,0,0,60,0,false,Calib.SIN,Calib.FK5);
+                  proj = new Projection(null,Projection.WCS,ra,dec,60,0,0,60,0,false,Calib.SIN,Calib.FK5,null);
                }
                oCst = cst;
                
