@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -65,7 +65,7 @@ public class CubeControl {
 
    private StringBuilder sedit=null;
 
-   protected int mode=PLAY;
+   protected int mode=PAUSE;
    protected int delay;         // Dlai en ms entre deux Frames
    protected int nbFrame;       // Nombre de frames
    protected int lastFrame=-1;   // Dernire Frame affiche
@@ -124,6 +124,7 @@ public class CubeControl {
       this.v=v;
       this.aladin=v.aladin;
       this.p=p;
+      nbFrame = p.getDepth();
       delay = d;
       startTime=System.currentTimeMillis();
       if( delay==0 || pause ) setMode(PAUSE);
@@ -146,6 +147,7 @@ public class CubeControl {
     */
    protected void init(int size) {
       int dx=0;
+      size = Math.round( aladin.getUIScale() * size );
       SIZE=size;
 
       pauseX1[0]=3+dx; pauseX1[1]=3+dx; pauseX1[2]=4+dx; pauseX1[3]=4+dx;
@@ -429,19 +431,23 @@ public class CubeControl {
 
    /** Double le dlai entre 2 frame sans dpasser la limite max */
    protected void increaseDelay() {
+      int z = lastFrame;
       int max = FrameBlink.getMaxDelay();
       if( delay>=max ) return;
       delay*=2;
       if( delay>max ) delay=max;
+      setFrameLevel(z,false);
       aladin.status.setText("New blink delay: "+delay+"ms");
    }
 
    /** Divise par 2 le dlai entre 2 frame sans dpasser la limite min */
    protected void decreaseDelay() {
+      int z = lastFrame;
       int min = FrameBlink.getMinDelay();
       if( delay<=min ) return;
       delay/=2;
       if( delay<min ) delay=min;
+      setFrameLevel(z,false);
       aladin.status.setText("New blink delay: "+delay+"ms");
    }
 
@@ -490,7 +496,7 @@ public class CubeControl {
       Polygon p;
 
       g.setColor(mouseMove==EDIT ? Aladin.COLOR_GREEN : Color.red);
-      g.setFont(Aladin.SPLAIN);
+      g.setFont( Aladin.fontResize( Aladin.SPLAIN ));
       g.drawString(Util.align3(frame+1),edit[0]=x+labelX,edit[1]=y+labelY);
 
       g.setColor(Color.red);
