@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -47,7 +47,7 @@ public class DirectorySort {
    public static final String ADDS        = "Adds";
    
    public static final String[] BRANCHES   = { 
-         "Image", "Data base", "Catalog", "Cube", "Solar system", "Ancillary", "Outreach", OTHERS, PROBLEMATIC };
+         "Image", "Data base", "Catalog", "Cube", "Solar system", "Ancillary", "Outreach", "Deprecated", OTHERS, PROBLEMATIC };
    
    public static final String[] PROTOCOLS = { "HiPS", "SIA2 (image|cube)", "SIA (image)",
          "SSA (spectrum)","CS (table)","TAP (table)"};
@@ -351,6 +351,17 @@ public class DirectorySort {
                   new SortRule("Date","Descending date, grouped by year",
                         new int[] { BRANCH, YEAR, DATE } )
       } );
+      initBranchRules("Deprecated",  
+            new SortRule[] {
+                  new SortRule("Protocol","Ascending wavelength, grouped by protocol and origin",
+                        new int[] { BRANCH, PROTOCOL, ORIGIN, WAVELEN } ),
+                  new SortRule("Regime","Ascending wavelength, grouped by regime", 
+                        new int[] { BRANCH, BRANCH2, WAVELEN  } ),
+                  new SortRule("Name","By name, grouped by origin",
+                        new int[] { BRANCH, ORIGIN, NAME} ),
+                  new SortRule("Origin","Ascending wavelength, grouped by origin", 
+                        new int[] { BRANCH, ORIGIN, WAVELEN  } ),
+       } );
    }
    
    /** Positionnement d'une rgle de tris pour la branche dsigne
@@ -546,6 +557,7 @@ public class DirectorySort {
          int c = countSlash(branch);
          assert c<=9;
          key = key+(9-c);
+//         key = key+c;
       }
       return key;
    }
