@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -1431,7 +1431,8 @@ public final class FilterProperties extends Properties implements MouseListener,
                Iterator<Obj> it = p.iterator();
                while( it!=null && it.hasNext() ) {
                   Obj o1 = it.next();
-                  if( !(o1 instanceof Source) ) continue;
+//                  if( !(o1 instanceof Source) ) continue;
+                  if( !o1.asSource() ) continue;
                   s = (Source)o1;
                   if( s.getLeg()==null || s.getLeg().field==null ) {
                      System.out.println("Bizarre");
@@ -1676,7 +1677,8 @@ public final class FilterProperties extends Properties implements MouseListener,
 	               Iterator<Obj> it = plan.iterator();
 	               while( it.hasNext() ) {
 	                  Obj o = it.next();
-	                  if( !(o instanceof Source) ) continue;
+//	                  if( !(o instanceof Source) ) continue;
+	                  if( !o.asSource() ) continue;
 	                  s = (Source)o;
 
 	                  leg = s.getLeg();
