@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -170,7 +170,7 @@ public final class FrameColorMap extends JFrame implements MouseListener {
             || p instanceof PlanBG && ((PlanBG)pimg).isColored() ) return;
       pixelCutMinField.setText(p.getDataMinInfo());
       pixelCutMaxField.setText(p.getDataMaxInfo());
-      comboCM.setSelectedIndex(p.typeCM);
+      if( comboCM!=null ) comboCM.setSelectedIndex(p.typeCM);
    }
 
    /** Mise a jour de l'objet en fonction de l'image slectionne.
