@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -60,7 +60,7 @@ public final class FrameContour extends JFrame implements ActionListener {
                          CHOOSELEVEL, GENERATE, SMOOTH, LEVEL, MANUALLY,
                          USESM, REDUCE, CONSIDER, TITRE2;
 
-       static final Font HELPFONT = new Font("Monospaced",Font.PLAIN,10);
+       static final Font HELPFONT = Aladin.SPLAIN; 
 
        boolean showHelp = false;	    // faut-il montrer les labels d'aide ?
 
