@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -131,7 +131,7 @@ public class FrameCooToolbox extends JFrame {
       cooField = new JTextField[n];
       for( int i=0; i<n; i++ ) {
          label[i] = new JLabel( Localisation.REPERE[i] );
-         cooField[i] = new JTextField(22);
+         cooField[i] = new JTextField(38);
          cooField[i].setActionCommand(i+"");
          cooField[i].addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
@@ -153,9 +153,6 @@ public class FrameCooToolbox extends JFrame {
       JPanel p = new JPanel();
       p.setLayout( new FlowLayout(FlowLayout.CENTER));
       JButton b;
-//      p.add( b=new JButton(aladin.chaine.getString("UPAPPLY"))); 
-//      b.addActionListener( new ActionListener() { public void actionPerformed(ActionEvent e) { modify(); }} );
-//      b.setFont(b.getFont().deriveFont(Font.BOLD));
       p.add( b=new JButton(aladin.chaine.getString("TAGIT"))); 
       b.addActionListener( new ActionListener() { public void actionPerformed(ActionEvent e) { tagit(); }} );
       p.add( b=new JButton(aladin.chaine.getString("CLEAR"))); 
@@ -588,7 +585,6 @@ public class FrameCooToolbox extends JFrame {
       targetCoo.set(ra,dec,originEpoch,null,pmra,pmdec,originEpoch,null,
             new double[] { plx,0}, new double []{ rv,0});
       if( precision>-1 ) targetCoo.setPrecision(precision);
-      targetCoo.convertTo( Localisation.getAstroframe(Localisation.ICRS) );
       targetCoo.toEpoch(targetEpoch);
       
       Coord coo = new Coord( targetCoo.getLon(), targetCoo.getLat() );
@@ -600,19 +596,45 @@ public class FrameCooToolbox extends JFrame {
    private String getCoordIn(int frameTarget) {
       if( !init ) return "";
       Astropos targetCoo = new Astropos(Localisation.AF_ICRS);
-      targetCoo.set(ra,dec,originEpoch,null,pmra,pmdec,originEpoch,null,
-            new double[] { plx,0}, new double []{ rv,0});
+      
+      double [] plxParam  = plx==0 ? null : new double[] { plx,0};
+      double [] rvParam = rv==0 ? null : new double []{ rv,0};
+      double pmraParam = pmra==0 ? Double.NaN : pmra;
+      double pmdecParam = pmdec==0 ? Double.NaN : pmdec;
+      
+      targetCoo.set(ra,dec,originEpoch,null,pmraParam,pmdecParam,originEpoch,null, plxParam, rvParam);
       if( precision>-1 ) targetCoo.setPrecision(precision);
-      targetCoo.convertTo( Localisation.getAstroframe(frameTarget) );
       targetCoo.toEpoch(targetEpoch);
+      if( frameTarget!=Localisation.ICRS && frameTarget!=Localisation.ICRSD ) {
+         targetCoo.convertTo( Localisation.getAstroframe(frameTarget) ); 
+      }
       
       String s = (frameTarget==Localisation.J2000D || frameTarget==Localisation.B1950D 
                || frameTarget==Localisation.ICRSD  || frameTarget==Localisation.ECLIPTIC
                || frameTarget==Localisation.GAL    || frameTarget==Localisation.SGAL )?
-                  targetCoo.toString("2d"):targetCoo.toString("2s");
+                  targetCoo.toString("2d"): targetCoo.toString("2s");
                   
       if( s.indexOf("--")>=0 ) return "";
       return s;
    }
+   
+//   static public void main(String [] a) {
+//      try {
+//         Astropos targetCoo = new Astropos( Astroframe.create("ICRS") );
+//         double ra=10;
+//         double dec=20;
+//         double pmRa=0.01;
+//         double pmDec=0.01;
+//         double originEpoch=2016;
+//         double targetEpoch=2000;
+//         targetCoo.set(ra,dec,originEpoch,null,pmRa,pmDec,originEpoch,null, null, null);
+//         System.out.println(originEpoch+" => "+targetCoo.toString("2s"));
+//         targetCoo.convertTo( Astroframe.create("ICRS") );
+//         targetCoo.toEpoch(targetEpoch);
+//         System.out.println(targetEpoch+" => "+targetCoo.toString("2s"));
+//      } catch( Exception e ) {
+//         e.printStackTrace();
+//      }
+//   }
       
 }
