@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -117,7 +117,7 @@ public final class FrameMocGenProba extends FrameMocGenImg {
          Plan [] ps = new Plan[]{ getPlan(ch[0]) };
          int order = ((PlanBG)ps[0]).getMaxHealpixOrder();
          if( getOrder()>order ) {
-            mocOrder.setSelectedIndex(order-FIRSTORDER);
+            mocOrder.setSelectedIndex(order-FIRSTORDER_S);
          }
       } catch( Exception e ) { }
    };
