@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -69,7 +69,16 @@ class HealpixAllsky extends HealpixKey {
       
       // Chargement immdiat des donnes
       try {
-         if(  mode==SYNC ||
+         
+         // Juste pour un test - temps rcupr dans "timeStream"
+         if( mode==TESTNET ) {
+            stream = loadStream(planBG.url+"/"+fileNet);
+            if( stream!=null ) sizeStream = stream.length;
+            stream=null;
+         }
+         
+          // Normal
+         else if(  mode==SYNC ||
              (mode==SYNCONLYIFLOCAL && (planBG.useCache && isCached() || planBG.isLocalAllSky())) ) loadNow();
       } catch( Exception e ) {
          if( Aladin.levelTrace>=3 ) e.printStackTrace();
@@ -77,12 +86,15 @@ class HealpixAllsky extends HealpixKey {
 
    }
    
+   /** Indique si on veut charger les tuiles distantes en gzip live ou non */
+   protected boolean askGzip() { return Aladin.GZIP==1 || Aladin.GZIP==2; }
+   
    // On essaye de garder le plus longtemps possible les allsky en mmoire */
    protected long getLiveTime() { 
       return planBG.aladin.enoughMemory() ? -1 : PlanBG.LIVETIME; 
    }
    
-   HealpixKey createOneKey(int npix,int width,byte [] pix) {
+   protected HealpixKey createOneKey(int npix,int width,byte [] pix) {
       HealpixKey h = new HealpixKey();
       h.allSky=true;
       h.planBG=planBG;
@@ -99,7 +111,7 @@ class HealpixAllsky extends HealpixKey {
       return h;
    }
    
-   HealpixKey createOneKeyRGB(int npix,int width,int []rgb) {
+   protected HealpixKey createOneKeyRGB(int npix,int width,int []rgb) {
       HealpixKey h = new HealpixKey();
       h.allSky=true;
       h.planBG=planBG;
