@@ -47,6 +47,7 @@ import java.awt.image.Raster;
 import java.awt.image.SampleModel;
 import java.awt.image.SinglePixelPackedSampleModel;
 import java.awt.image.WritableRaster;
+import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
@@ -496,7 +497,10 @@ public class HealpixKey implements Comparable<HealpixKey> {
 
             setStatus(ERROR);
             if( this instanceof HealpixAllsky ) askForRepaint();
-            if( Aladin.levelTrace>=6 ) System.err.println("HealpixKey.loadFromNet error: "+e.getMessage());
+            if( Aladin.levelTrace>=6 ) {
+               System.err.println("HealpixKey.loadFromNet error: "+e.getMessage());
+               e.printStackTrace();
+            }
          }
       }
    }
@@ -1101,66 +1105,64 @@ public class HealpixKey implements Comparable<HealpixKey> {
       }
    }
 
+
    /** Chargement du losange sous forme de FITS. Si le BITPIX n'est pas  8, il y a conversions des pixels
     * en 8 bits en fonction des valeurs PIXELMIN et PIXELMAX indiques dans l'entte. Si ces valeurs
     * sont absentes ou gales (par exemple 0,0), Aladin effectue un autocut
     * @return le nombre de bytes du flux FITS */
    protected int loadFits(String filename) throws Exception {
-
+      
       stream = loadStream(filename);
-
+      
       boolean initPixMode = planBG.pixMode==-1;
       if( initPixMode ) planBG.setPixMode(PlanBG.PIX_TRUE);
-
-      // Lecture de l'entete Fits ( la brute - elle ne doit pas dpasser 2880 catactres)
-      byte [] head = new byte[2880];
-      System.arraycopy(stream, 0, head, 0, 2880);
+      
+      Fits fits=null;
+      MyInputStream is=null;
+      try {
+         fits = new Fits();
+         is = new MyInputStream( new ByteArrayInputStream(stream) );
+         fits.setFilename(filename);
+         fits.loadFITS(is);
+         is.close(); 
+         is=null;
+      } finally { if( is!=null ) is.close(); }
+      
       int bitpix=8;
-      boolean flagARGB=false;
       double pixelMin=planBG.pixelMin;
       double pixelMax=planBG.pixelMax;
-      try {
-         width  = (int)getValue(head,"NAXIS1");
-         height = (int)getValue(head,"NAXIS2");
-         bitpix = (int)getValue(head,"BITPIX");
-         if( flagARGB =isARGB(head) ) {
-            bitpix=0;
-            if( initPixMode ) planBG.setPixMode(PlanBG.PIX_ARGB);
-            //            System.out.println("HealpixKey FITS in ARGB");
-         }
-         if( bitpix!=8 && !flagARGB ) truePixels=true;
-
-      } catch( Exception e ) { width=height=512; bitpix=8; }
-
-      int taille=width*height*(Math.abs(bitpix)/8);
-
-      // Lecture FITS couleur ARGB
+      width  = fits.headerFits.getIntFromHeader("NAXIS1");
+      height = fits.headerFits.getIntFromHeader("NAXIS2");
+      bitpix = fits.headerFits.getIntFromHeader("BITPIX");
+      boolean flagARGB = fits.headerFits.hasKey("COLORMOD");
+      if( flagARGB ) {
+         bitpix=0;
+         if( initPixMode ) planBG.setPixMode(PlanBG.PIX_ARGB);
+         //            System.out.println("HealpixKey FITS in ARGB");
+      }
+      if( bitpix!=8 && !flagARGB ) truePixels=true;
+      
+      // Lecture Fits couleurs
       if( flagARGB ) {
          planBG.color=true;     // PEUT ETRE PAS VRAIMENT NECESSAIRE
-         rgb = new int[width*height];
-         for( int i=0; i<width*height; i++ ) {
-            rgb[i]  =  (stream[2880 + i*4]   & 0xFF)  << 24
-                  | (stream[2880 + i*4+1] & 0xFF)  << 16
-                  | (stream[2880 + i*4+2] & 0xFF)  << 8
-                  | (stream[2880 + i*4+3] & 0xFF) ;
-         }
-
-         // Lecture FITS classique
+         rgb = fits.rgb;
+         
+      // Lecture FITS classique
       } else {
-
-         // Allocation puis lecture
-         byte [] in = new byte[taille];
-         System.arraycopy(stream, 2880, in, 0, taille);
-
+         byte [] in = fits.pixels;
+                  
          boolean flagInit = planBG.bitpix==0 || planBG.flagRecut ;
 
          if( flagInit ) {
             boolean init = planBG.bitpix==0;
             planBG.bitpix=bitpix;
             planBG.flagRecut=false;
-            try { planBG.bScale = getValue(head,"BSCALE"); } catch( Exception e ) { planBG.bScale=1; }
-            try { planBG.bZero  = getValue(head,"BZERO");  } catch( Exception e ) { planBG.bZero=0;  }
-            try { planBG.blank  = getValue(head,"BLANK"); planBG.isBlank = true; } catch( Exception e ) { planBG.isBlank = false; }
+            try { planBG.bScale = fits.headerFits.getDoubleFromHeader("BSCALE"); }
+            catch( Exception e ) { planBG.bScale=1; }
+            try { planBG.bZero  = fits.headerFits.getDoubleFromHeader("BZERO");  }
+            catch( Exception e ) { planBG.bZero=0;  }
+            try { planBG.blank  = fits.headerFits.getDoubleFromHeader("BLANK"); planBG.isBlank = true; }
+            catch( Exception e ) { planBG.isBlank = false; }
 
             // Est-ce que j'ai des informations de range et de cut via le fichier de properties ?
             boolean flagPixelRange=false;
@@ -1234,20 +1236,13 @@ public class HealpixKey implements Comparable<HealpixKey> {
          pixels = to8bits(in,bitpix,pixelMin,pixelMax, PlanBG.PIX_255);
          
          if( flagInit ) planBG.initTileParam(width,height,bitpix,in,pixels);
-//         if( flagInit && !planBG.color) {
-//            planBG.pixelsOrigin=in;
-//            planBG.setBufPixels8(pixels);
-//            planBG.bitpix=bitpix;
-//            planBG.npix=Math.abs(bitpix)/8;
-//            planBG.naxis1=planBG.width=width;
-//            planBG.naxis2=planBG.height=height;
-//         }
          in=null;
       }
 
       return stream.length; //2880+taille;
    }
 
+   
    private double [] split(String s) {
       double [] a = new double[3];
       StringTokenizer st = new StringTokenizer(s);
