@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -70,6 +70,7 @@ public class HealpixKeyCat extends HealpixKey {
       stream=null;     // Inutile de conserver le stream puisqu'on le prend du cache
       return 0;
    }
+   
 
    protected long loadNet(String filename) throws Exception {
       loadTSV(filename);
@@ -87,6 +88,11 @@ public class HealpixKeyCat extends HealpixKey {
 
          int trace=planBG.aladin.levelTrace;
          planBG.aladin.levelTrace=0;
+         
+      // Indique a priori la lgende  utiliser
+         if( ((PlanBGCat)planBG).hasGenericPcat() ) {
+            pcat.leg = ((PlanBGCat)planBG).getGenericPcat().leg;
+         }
 //         Legende leg = planBG.getFirstLegende();
 //         if( leg!=null ) pcat.setGenericLegende(leg);   // Indique a priori la lgende  utiliser
          
@@ -101,7 +107,7 @@ public class HealpixKeyCat extends HealpixKey {
 //         if( leg==null  ) ((PlanBGCat)planBG).setLegende( ((Source)pcat.iterator().next()).leg );
          if(  !((PlanBGCat)planBG).hasGenericPcat() )  ((PlanBGCat)planBG).setGenericPcat(pcat);
 
-         // Dans le cas o l'poque aurait-t modifi
+         // Dans le cas o l'poque aurait-t modifi, ou les colonnes de positions mal dtectes
          recomputePosition(((PlanBGCat)planBG).getFirstLegende(),pcat);
       } finally { if( in!=null ) in.close(); }
    }
@@ -112,20 +118,21 @@ public class HealpixKeyCat extends HealpixKey {
    }
    
    /** Recalcule toutes les positions internes dans le cas o l'poque
-    * aurait t modifie au pralable */ 
+    * aurait t modifie au pralable, ou bien si la dtection des colonnes de position
+    * n'aurait pas t concluante => le refaire avec metadata.xml */ 
    public void recomputePosition(Legende leg,Pcat pcat) {
-      if( planBG.epoch==null || planBG.getEpoch().toString("J").equals("J2000") ) return;
+//      if( planBG.epoch==null || planBG.getEpoch().toString("J").equals("J2000") ) return;
 //      System.out.println("Adaptation  l'poque "+planBG.getEpoch());
       int npmra = leg.getPmRa();
       int npmde = leg.getPmDe();
-      if( npmra<=0 || npmde<=0 ) return;  // Inutile, pas de PM
+//      if( npmra<=0 || npmde<=0 ) return;  // Inutile, pas de PM
       int nra   = leg.getRa();
       int nde   = leg.getDe();
       planBG.recomputePosition(pcat.iterator(),leg,nra,nde,npmra,npmde);
    }
 
-   static final private char [] NLOADED = { '#',' ','n','L','o','a','d','e','d',':',' ' };
-   static final private char [] COMPLETENESS = { '#',' ','C','o','m','p','l','e','t','e','n','e','s','s',' ','=' };
+//   static final private char [] NLOADED = { '#',' ','n','L','o','a','d','e','d',':',' ' };
+   static final private char [] COMPLETENESS = { '#',' ','C','o','m','p','l','e','t','e','n','e','s','s',' ','=',' ' };
   
    // Postionne le flag last selon mthode "Completeness", retourne true si on a trouv ce commentaire
    // # Completeness = 903 / 90811
@@ -135,7 +142,7 @@ public class HealpixKeyCat extends HealpixKey {
       
       // En dbut de fichier
       rep = testLast(stream,0,COMPLETENESS);
-      if( !rep ) testLast(stream,0,NLOADED);    // A virer lorsque FX aura fait la modif sur son serveur
+//      if( !rep ) testLast(stream,0,NLOADED);    // A virer lorsque FX aura fait la modif sur son serveur
       
       // Parmi des commentaires ?
       if( !rep ) {
@@ -143,7 +150,7 @@ public class HealpixKeyCat extends HealpixKey {
             if( stream[i]=='\n' || stream[i]=='\r' ) {  
                if( stream[i+1]=='#' ) {
                   rep=testLast(stream,i+1,COMPLETENESS);    
-                  if( !rep ) rep=testLast(stream,i+1,NLOADED);    // A virer lorsque FX aura fait la modif sur son serveur
+//                  if( !rep ) rep=testLast(stream,i+1,NLOADED);    // A virer lorsque FX aura fait la modif sur son serveur
                }
                else if( stream[i+1]!='\n' && stream[i+1]!='\r' ) break;  // fin des commentaires ?
             }
@@ -160,7 +167,7 @@ public class HealpixKeyCat extends HealpixKey {
       int fin;
       int slash=0;
       for( fin=offset+signature.length; fin<stream.length 
-         && stream[fin]!='\n' && stream[fin]!='\r' && stream[fin]!=' '; fin++ ) {
+         && stream[fin]!='\n' && stream[fin]!='\r' ; fin++ ) {
          if( stream[fin]=='/' ) slash=fin;
       }
       if( slash==0 ) return false;
@@ -175,29 +182,6 @@ public class HealpixKeyCat extends HealpixKey {
    }
    
    
-//   // Postionne le flag last selon mthode "Completeness", retourne true si on a trouv ce commentaire
-//   // # Completeness = 903 / 90811
-//   private boolean testCompleteness(byte [] stream) {
-//      if( stream.length<COMPLETENESS.length ) return false;
-//      for( int i=0; i<COMPLETENESS.length; i++ ) if( COMPLETENESS[i]!=stream[i] ) return false;
-//      int deb=COMPLETENESS.length;
-//      int fin;
-//      int slash=0;
-//      for( fin=COMPLETENESS.length; fin<stream.length 
-//         && stream[fin]!='\n' && stream[fin]!='\r'; fin++ ) {
-//         if( stream[fin]=='/' ) slash=fin;
-//      }
-//      if( slash==0 ) return false;
-//      if( fin==stream.length ) return false;
-//      try {
-//         nLoaded = Integer.parseInt((new String(stream,deb,slash-deb)).trim());
-//         nTotal = Integer.parseInt((new String(stream,slash+1,fin-(slash+1))).trim());
-//         last = nLoaded==nTotal;
-////         System.out.println("Trouve ["+new String(stream,0,fin)+"] pour "+this);
-//      } catch( Exception e ) { nLoaded = 1; nTotal = 2; last=false; }
-//      return true;
-//   }
-
   /** Retourne true s'il n'y a pas de descendant */
    protected boolean isLast() { return last; }
    
