@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -142,7 +142,7 @@ public class ImageMaker {
       p.drawBackground(g, vs);
 
       // Dessin de l'image de fond
-      p.drawLosangesNow(g, vs);
+      p.drawLosangesNow(g, vs, img);
       
       // Les ventuels overlays
       if( overlays!=null ) {
@@ -545,7 +545,7 @@ public class ImageMaker {
    public static void checkPixelLimit(int width, int height, PlanBG planBG) throws Exception {
 	// TODO Auto-generated method stub
 	   int bitpix= planBG.getBitpix()==-64 ? -64 : -32;
-	      long limit = (long) width * (long)height * (long) (Math.abs(bitpix)/8);
+	      long limit = (long) width * (long)height * (Math.abs(bitpix)/8);
 	      if (limit < Integer.MIN_VALUE || limit >Integer.MAX_VALUE) {
 	    	  throw new Exception("Unable to process large request. Please consider retrying with smaller field of view or lower order/resolution");
 		}
