@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -633,7 +633,7 @@ public final class Mesure extends JPanel implements Runnable,Iterable<Source>,Wi
    synchronized private void rmAllSrc() {
       try {
          if( nbSrc>MAXBLOC ) src = new Source[DEFAULTBLOC];
-         else for( int i=0; i<nbSrc; i++ ) src[i]=null;	// Pour le GC
+         else for( int i=0; i<src.length; i++ ) src[i]=null;	// Pour le GC
          nbSrc=0;
          mcanvas.unselect();
          aladin.calque.zoom.zoomView.stopHist();
@@ -760,6 +760,42 @@ public final class Mesure extends JPanel implements Runnable,Iterable<Source>,Wi
          return getWordLine(src[i],i);
       }
    }
+   
+   // Retourne la prcision d'un champ, et si inconnue, essaye de le dterminer en fonction des valeurs 
+   private int getPrecision(Source o, int field ) {
+      Legende leg = o.getLeg();
+      int p = leg.getPrecision(field);
+      if( p>=0 ) return p;
+      
+      if( !leg.isNumField(field) ) return -1;
+
+      p = leg.getAlternatePrecision(field);
+      if( p>=0 ) return p;
+
+      int i=0;
+      Iterator<Obj> it = o.plan.iterator();
+      int max=0;
+      while( it.hasNext() ) {
+         if( ++i>10000 ) break;
+         Obj x  = it.next();
+         if( !(x instanceof Source) || ((Source)x).getLeg()!=leg ) continue;
+         String s = ((Source)x).getValue(field);
+         int dot = s.indexOf('.');
+         if( dot==-1 ) continue;
+         int prec = s.length()-dot-1;
+         if( max<prec ) max=prec;
+      }
+      leg.setAlternatePrecision(field,max);
+      return max;
+   }
+
+   
+   // Retourne la largeur d'affichage d'un champ, et si inconnu, essaye de le dterminer en fonction des valeurs 
+   private int getWidth(Source o, int field ) {
+      Legende leg = o.getLeg();
+      return leg.getWidth(field);
+   }
+
 
    /** Gnration de la HeadLine associe  la source passe en paramtre */
    protected Vector getHeadLine(Source o) {
@@ -773,7 +809,7 @@ public final class Mesure extends JPanel implements Runnable,Iterable<Source>,Wi
       for( int i=0; i<leg.field.length; i++ )  {
          int nField = leg.fieldAt[i];
          if( !leg.isVisible(nField) ) continue;
-         Words w = new Words(leg.field[nField].name,null,o.getLeg().getWidth(nField),o.getLeg().getPrecision(nField),
+         Words w = new Words(leg.field[nField].name,null,getWidth(o,nField),getPrecision(o,nField),
                Words.CENTER,o.getLeg().computed.length==0?false:o.getLeg().computed[nField],
                      leg.field[nField].sort,-1);
          w.pin = i==0;
@@ -837,14 +873,14 @@ public final class Mesure extends JPanel implements Runnable,Iterable<Source>,Wi
 
             // Creation d'un mot dans le cas d'un footprint associ (Thomas, VOTech)
             if( indexFootPrint==nField ) {
-               w = new Words("  FoV",o.getLeg().getWidth(i-1),o.getLeg().getPrecision(nField),Words.LEFT,
+               w = new Words("  FoV",getWidth(o,nField),getPrecision(o,nField),Words.LEFT,
                      false,true,num);
             }
             // Creation du nouveau mot
             else {
                if( o.getLeg().isNullValue(tag, i-1) ) tag="";
-               w = new Words(tag,o.getLeg().getRefText(nField),o.getLeg().getWidth(nField),
-                     o.getLeg().getPrecision(nField),align,
+               w = new Words(tag,o.getLeg().getRefText(nField),getWidth(o,nField),
+                     getPrecision(o,nField),align,
                      o.getLeg().computed.length==0?false:o.getLeg().computed[nField],Field.UNSORT,num);
             }
          }
