@@ -2358,7 +2358,7 @@ public class MetaDataTree extends BasicTree implements SwingWidgetFinder, KeyLis
         if( text.indexOf(repl)<0 ) return text;
         int n = repl.length();
 
-        StringBuffer buf = new StringBuffer(text.length());
+        StringBuilder buf = new StringBuilder(text.length());
         int start = 0, end = 0;
         while ((end = text.indexOf(repl, start)) != -1) {
             buf.append(text.substring(start, end)).append(with);
