@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -72,7 +72,8 @@ class MyAnchor extends JLabel {
          if( (text.startsWith("http://") || text.startsWith("ftp://")) && text.length()>width ) text=text.substring(0,width)+"...";
          else {
             if( url!=null ) text = Util.fold(text,width,true);
-            text = Util.fold(text,width);
+            else if( more==null && text.length()>width ) { more=text; text=text.substring(0,width); }
+            else text = Util.fold(text,width);
          }
       }
       if( url!=null ) {
@@ -117,9 +118,48 @@ class MyAnchor extends JLabel {
     * si on clique sur le "..." ou le texte
     * @param aladin
     * @param text
+    * @param flagMore true si on veut un "...", false pour avoir un lien soulign directement (les caractres
+    *          non alphanumriques ne sont pas souligns)
     * @param action
     */
-   MyAnchor(Aladin aladin,String text, final ActionListener action) {
+   MyAnchor(Aladin aladin,String text, final ActionListener action) { this(aladin,text,true,action); }
+   MyAnchor(Aladin aladin,String text, boolean flagMore, final ActionListener action) {
+      super();
+      if( flagMore ) {
+         text =  "<html>"+text+" <A HREF=\"\">...</A></html>";
+      } else {
+         int i=0;
+         int n = text.length();
+         while( !Character.isLetterOrDigit( text.charAt(i) ) && i<n) i++;
+         int j=n-1;
+         while( !Character.isLetterOrDigit( text.charAt(j) ) && j>0) j--;
+         j++;
+         if( i>=j ) text = "<html> <A HREF=\"\">"+text+"</A></html>";
+         else text = "<html>"+text.substring(0,i)+"<A HREF=\"\">"+text.substring(i,j)+"</A>"+text.substring(j)+"</html>";
+      }
+      setText(text);
+      setFont(getFont().deriveFont(Font.ITALIC));
+      final Component c = this;
+      addMouseMotionListener(new MouseMotionListener() {
+         public void mouseMoved(MouseEvent e) { Aladin.makeCursor(c,Aladin.HANDCURSOR); }
+         public void mouseDragged(MouseEvent e) { }
+      });
+      addMouseListener(new MouseListener() {
+         public void mouseReleased(MouseEvent e) {
+            if( (e.getModifiers() & java.awt.event.InputEvent.BUTTON3_MASK) !=0 ) return;
+            action.actionPerformed(null);
+         }
+         public void mousePressed(MouseEvent e)  { }
+         public void mouseExited(MouseEvent e)   { Aladin.makeCursor(c,Aladin.DEFAULTCURSOR); }
+         public void mouseEntered(MouseEvent e)  { }
+         public void mouseClicked(MouseEvent e) { }
+      });
+   }
+   
+   /**
+    * Texte sous forme de lien auquel on a associ une action qui sera effectu si on clique dessus
+    */
+   MyAnchor(String text, final ActionListener action) {
       super();
       text = "<html>"+text+" <A HREF=\"\">...</A></html>";
       setText(text);
@@ -142,6 +182,7 @@ class MyAnchor extends JLabel {
    }
    
 
+
    
    // Affiche dans un navigateur Web
    private void showDocument(String url) { aladin.glu.showDocument(url); }
