@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -26,7 +26,6 @@ import java.awt.BorderLayout;
 import java.awt.CardLayout;
 import java.awt.Color;
 import java.awt.Cursor;
-import java.awt.Font;
 import java.awt.Graphics;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
@@ -66,10 +65,6 @@ public abstract class MyBox extends JPanel {
    static private final String LABEL_SAISIE    = "SAISIE";
    static private final String LABEL_AFFICHAGE = "AFFICHAGE";
 
-   // Les fontes associees a la classe
-   static protected final int DF = Aladin.SIZE;
-   static protected final Font F = Aladin.PLAIN;
-
    // Le mot affiche lorsque la position n'est pas disponible
    static protected String UNDEF = "";
 
@@ -83,27 +78,24 @@ public abstract class MyBox extends JPanel {
    protected JComboBox c;
    protected JLabel label;
 
-   static final Font FONT = new Font("Sans serif",Font.BOLD,12);
-
    protected MyBox() { super(); }
 
    protected MyBox(Aladin aladin,String titre) {
 
       this.aladin = aladin;
-
+      
       // Creation du selecteur du repere
       c = createChoice();
-//      c.setFont(c.getFont().deriveFont((float)c.getFont().getSize()-1));
 
       // Creation du label contenant la valeur de la position courant
       pos = new Text("",30);
-      pos.setFont(FONT);
+      pos.setFont(Aladin.PLAIN);
       pos.setBackground( Aladin.COLOR_TEXT_BACKGROUND );
       pos.setForeground( Aladin.COLOR_TEXT_FOREGROUND_INFO);
 
       // Creation d'un champ de saisie
       text = new Text("",30);
-      text.setFont(FONT);
+      text.setFont(Aladin.PLAIN);
       text.setBackground( Aladin.COLOR_TEXT_BACKGROUND );
       text.setForeground( Aladin.COLOR_TEXT_FOREGROUND );
 
@@ -234,7 +226,7 @@ public abstract class MyBox extends JPanel {
       }
    }
    
-   static final private int POSCROSS=30;
+   static private int POSCROSS;
    
    /** Classe pour un JTextField avec reset en bout de champ (petite croix rouge) */
    class Text extends JTextField implements MouseMotionListener, MouseListener {
@@ -242,11 +234,15 @@ public abstract class MyBox extends JPanel {
       private Rectangle region=null;
       private Rectangle regionCross=null;
       private Color colorTriangle = Color.darkGray;
+      
+      int w;
 
       Text(String t,int width) {
          super(t,width);
          setUI( new BasicTextFieldUI() );
          addMouseMotionListener(this);
+         w = Math.round( 10*aladin.getUIScale());
+         POSCROSS = 25+w;
          addMouseListener(this);
          
          // Pour ne pas passer sous la petite croix et le triangle
@@ -266,7 +262,7 @@ public abstract class MyBox extends JPanel {
             if( hasCross() ) {
                g.setColor( getBackground() );
                g.fillRect(getWidth()-POSCROSS,0,getWidth()-16,getHeight());
-               drawCross(g,getWidth()-(POSCROSS-2),8);
+               drawCross(g,getWidth()-(POSCROSS-2),getHeight()/2-4);
             }
             if( hasTriangle() ) {
                g.setColor( getBackground() );
@@ -278,14 +274,15 @@ public abstract class MyBox extends JPanel {
 
       private void drawCross(Graphics g, int x, int y) {
          g.setColor( colorTriangle );
-         Util.drawCross(g,x,y,6);
-         regionCross = new Rectangle(x-2,y-2,10,10);
+         Util.drawCross(g,x,y,w-4);
+         regionCross = new Rectangle(x-2,y-2,w,w);
       }
 
       private void drawTriangle(Graphics g, int x, int y) {
          g.setColor( colorTriangle );
-         Util.fillTriangle7(g, x, y);
-         region = new Rectangle(x-2,y-2,10,10);
+         if( aladin.getUIScale()<1.25 ) Util.fillTriangle7(g, x, y);
+         else Util.fillTriangle8(g, x, y);
+         region = new Rectangle(x-2,y-2,w,w);
       }
       
       protected void processComponentKeyEvent(KeyEvent e) {
