@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -33,8 +33,6 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.TimeZone;
 
-import cds.mocmulti.MultiMoc;
-
 /**
  * Gestion avance d'une liste de proprits
  * - conserve les lignes blanches et les commentaires si ncessaire
@@ -58,13 +56,20 @@ public class MyProperties {
    private StringBuilder propOriginal = null;   // Strings des properties originales (telles que) si demand dans load()
 
    public MyProperties() {
-      prop = new ArrayList<PropItem>();
-      hash = new HashMap<String, PropItem>();
+      prop = new ArrayList<>();
+      hash = new HashMap<>();
+   }
+   
+   public MyProperties clone() {
+      MyProperties p = new MyProperties();
+      for( PropItem i : prop ) p.add( i.key, i.value);
+      p.propOriginal = propOriginal==null ? null : new StringBuilder(propOriginal );
+      return p;
    }
    
    /** Retourne la liste ordonne des cls */
    public ArrayList<String> getKeys() {
-      ArrayList<String> a = new ArrayList<String>();
+      ArrayList<String> a = new ArrayList<>();
       for( PropItem ci : prop ) a.add(ci.key);
       return a;
    }
@@ -105,13 +110,25 @@ public class MyProperties {
          
          // Deux valeurs simples ?
          if( v1.indexOf('\t')<0 && v.indexOf('\t')<0 ) {
-            if( !v1.equals(v) ) return false;
+            
+            // Cas particulier de la popularite VizieR
+            // On estime diffrent si variation d'au moins 10%
+//            if( k.equals("vizier_popularity") ) {
+//               try {
+//                  int pop  = Integer.parseInt(v);
+//                  int pop1 = Integer.parseInt(v1);
+//                  double var = (double)pop/pop1;
+//                  if( var<0.9 || var>1.1 ) return false;
+//               } catch( Exception e ) { return false; }
+//               
+//            } else 
+               if( !v1.equals(v) ) return false;
             
          // Des valeurs multiples => il faut comparer chaque possibilit de valeur
          } else if( !v1.equals(v) ) {
             int n=0,n1=0;
             Tok tok = new Tok(v,"\t");
-            HashMap<String, String> hash = new HashMap<String, String>(100);
+            HashMap<String, String> hash = new HashMap<>(100);
             while( tok.hasMoreTokens() ) { hash.put(tok.nextToken(),""); n++; }
 
             tok = new Tok(v1,"\t");
@@ -131,7 +148,7 @@ public class MyProperties {
     */
    public ArrayList<String> getModVal(MyProperties p) { return getModVal(p,null); }
    public ArrayList<String> getModVal(MyProperties p, String exceptKey) {
-      ArrayList<String> a = new ArrayList<String>();
+      ArrayList<String> a = new ArrayList<>();
       if( p==null ) return a;
       for( String k : getKeys() ) {
          if( k.equals(" ") || k.equals("#") ) continue;
@@ -149,7 +166,7 @@ public class MyProperties {
 
             int n=0,n1=0;
             Tok tok = new Tok(v,"\t");
-            HashMap<String, String> hash = new HashMap<String, String>(100);
+            HashMap<String, String> hash = new HashMap<>(100);
             while( tok.hasMoreTokens() ) { hash.put(tok.nextToken(),""); n++; }
 
             tok = new Tok(v1,"\t");
@@ -174,7 +191,7 @@ public class MyProperties {
     * @return Une liste des cls supprimes
     */
    public ArrayList<String> getDelKey(MyProperties p) {
-      ArrayList<String> a = new ArrayList<String>();
+      ArrayList<String> a = new ArrayList<>();
 
       for( String k : getKeys() ) {
          if( k.equals(" ") || k.equals("#") ) continue;
@@ -194,7 +211,7 @@ public class MyProperties {
     * @return Une liste des cls ajoutes
     */
    public ArrayList<String> getAddKey(MyProperties p) {
-      ArrayList<String> a = new ArrayList<String>();
+      ArrayList<String> a = new ArrayList<>();
       if( p==null ) return a;
       for( String k1 : p.getKeys() ) {
          if( k1.equals(" ") || k1.equals("#") ) continue;
@@ -317,11 +334,12 @@ public class MyProperties {
    }
    
    /** Remplacement de la valeur associe  une cl
-    * Ajout simple en fin de liste si inexistant au pralable
+    * Ajout simple en fin de liste si inexistant au pralable. Suppression si valeur==null
     * @param key
     * @param value
     */
    public void replaceValue(String key, String value) {
+      if( value==null ) { remove(key); return; }
       PropItem item = getItem(key);
       if( item == null ) {
          item = new PropItem(key, value);
@@ -406,8 +424,8 @@ public class MyProperties {
       // Pour conserver le flux original
       if( flagKeepOriginal ) propOriginal = new StringBuilder();
 
-      prop = new ArrayList<PropItem>();
-      hash = new HashMap<String, PropItem>();
+      prop = new ArrayList<>();
+      hash = new HashMap<>();
       
 
       // Je lis les proprits de la configuration
@@ -456,7 +474,7 @@ public class MyProperties {
 
          // ajout normal de la proprit
          if( s.indexOf('=')<0 ) {
-            String id = MultiMoc.getID(this);
+//            String id = MultiMoc.getID(this);
 //            System.out.println("propertie file line syntax error (missing '=')"+(id!=null?" in "+id:"")+" ignored: "+s);
             continue;
          }
@@ -870,8 +888,8 @@ public class MyProperties {
        }
 
        public String toString() {
-          if( key.equals("#")) return value; // Commentaire unique (pour compatibilit)
           if( key==null || value==null ) return "";
+          if( key.equals("#")) return value; // Commentaire unique (pour compatibilit)
           if( value.indexOf('\t')==-1 ) return align(key, 20) +" = "+ value; // Proprit simple
           StringBuilder s = new StringBuilder();
           Tok tok = new Tok(value,"\t");
