@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -46,7 +46,7 @@ import cds.aladin.prop.Propable;
  * @version 1.0 : (5 mai 99) Toilettage du code
  * @version 0.9 : (??) creation
  */
-public abstract class Obj implements Propable{
+public abstract class Obj implements Propable {
    
    // Les diffrentes formes (pour les Sources uniquement)
    public static final int OVAL     = 0;
@@ -98,7 +98,7 @@ public abstract class Obj implements Propable{
    
    public boolean hasProp() { return plan!=null && plan.type!=Plan.APERTURE; }
    public Vector<Prop> getProp() {
-      Vector<Prop> propList = new Vector<Prop>();
+      Vector<Prop> propList = new Vector<>();
       JLabel l = new JLabel("\""+getObjType()+"\" object in plane: \""+plan.getLabel()+"\"");
       l.setFont(l.getFont().deriveFont(Font.BOLD));
       l.setFont(l.getFont().deriveFont(14f));
@@ -157,10 +157,19 @@ public abstract class Obj implements Propable{
    /** Retourne true si l'objet contient des informations de photomtrie  */
    public boolean hasPhot() { return false; }
    public boolean hasPhot(ViewSimple v) { return false; }
-
+   
    /** Retourne true si la source a le flag slect positionn  */
    final public boolean isSelected() { return (flags & SELECT) !=0; }
    
+   /** Positionne le flag VISIBLE */
+   public final void setVisible(boolean visible) {
+      if( visible ) flags |= VISIBLE;
+      else flags &= ~VISIBLE;
+   }
+
+   /** Retourne true si la source a le flag VISIBLE positionn */
+   final public boolean isVisible() { return (flags & VISIBLE) !=0; /* == VISIBLE;*/ }
+   
    
    /** Provide JD time (if available) */
    public double getJD() { return jdtime;}
@@ -183,21 +192,47 @@ public abstract class Obj implements Propable{
    /** Return true if this object can be used for getting photometrical statistics (first segment of a polygon, or circle) */
    public boolean hasSurface() { return false; }
    
-   /** Provide photometric statistics for the area described by the object (only for circle and polygon)
-    * @param ad AladinData describing an image with valid pixels
-    * @return { cnt,sum,sigma,surface_in_square_deg,min,max }
-    * @throws Exception
-    */
-   public double[] getStatistics(AladinData ad) throws Exception {
-      return getStatistics(ad.plan);
-   }
+   
+   /** Retourne une cl unique associ aux statistiques courantes (si l'objet en a) */
+   public int getStatsHashcode(AladinData ad) { return getStatsHashcode(ad.plan,-1); }
+   public int getStatsHashcode(AladinData ad, int z) { return getStatsHashcode( ad.plan,z); }
+   protected int getStatsHashcode(Plan p, int z) { return 0; }
    
    /** Provide photometric statistics for the area described by the object (only for circle and polygon)
-    * @param p Plan describing an image with valid pixels
+    * @param ad AladinData describing an image or cube with valid pixels
+    * @param z frame index in case of cube
+    * @return { cnt,sum,sigma,surface_in_square_deg,min,max,median }
+    * @throws Exception
+    */
+   public double[] getStatistics(AladinData ad) throws Exception { return getStatistics(ad.plan,-1); }
+   public double[] getStatistics(AladinData ad, int z) throws Exception { return getStatistics(ad.plan,z); }
+   
+   /** Provide photometric statistics for the area described by the object (only for circle and polygon)
+    * @param p Plan describing an image or cube with valid pixels
+    * @param z frame index in case of cube
     * @return { cnt,sum,sigma,surface_in_square_deg }
     * @throws Exception
     */
-   protected double[] getStatistics(Plan p) throws Exception { throw new Exception("no statistics available"); }
+   protected double[] getStatistics(Plan p) throws Exception { return getStatistics(p,-1); }
+   protected double[] getStatistics(Plan p,int z) throws Exception { throw new Exception("no statistics available"); }
+   
+   /** Retourne la liste des triplets associes aux pixels des statistiques (raj,dej,val)
+    * @param p Le plan de base concerne
+    * @param z l'index de la tranche du cube s'il s'agit d'un cube
+    * @return le tableau des triplets
+    * @throws Exception
+    */
+   public double [] getStatisticsRaDecPix(AladinData ad) throws Exception { return getStatisticsRaDecPix(ad.plan,-1); }
+   public double [] getStatisticsRaDecPix(AladinData ad, int z) throws Exception { return getStatisticsRaDecPix(ad.plan,z); }
+
+   /** Retourne la liste des triplets associes aux pixels des statistiques (raj,dej,val)
+    * @param p Le plan de base concerne
+    * @param z l'index de la tranche du cube s'il s'agit d'un cube
+    * @return le tableau des triplets
+    * @throws Exception
+    */
+   protected double [] getStatisticsRaDecPix(Plan p) throws Exception { return getStatisticsRaDecPix(p,-1); }
+   protected double [] getStatisticsRaDecPix(Plan p, int z) throws Exception { throw new Exception("no statistics available"); }
    
    /** Provide radius (in degrees) for photometry measure tags */
    public double getRadius() { return 0.; }
@@ -351,7 +386,7 @@ public abstract class Obj implements Propable{
    protected void setSpecificAJInfo(String s) { id = s==null || s.length()==0 ? null : s; }
    protected abstract void setVisibleGenerique(boolean flag);
    protected abstract void switchSelect();
-   protected abstract Plan getPlan();
+   public Plan getPlan() { return plan; }
    protected abstract boolean cutOn();
 
    // Carr de la distance entre souris et objet
@@ -404,6 +439,9 @@ public abstract class Obj implements Propable{
    // Pour du debuging
    public String toString() { return "("+raj+","+dej+") -> "+id; }
    
-
+   /** Retourne vrai si l'objet doit tre considr comme une Source, et par consquent repris
+    * dans la tables des mesures, dans les VOTables exports, etc...
+    */
+   protected boolean asSource() { return false; }
 
 }
