@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -227,6 +227,7 @@ public final class PlanContour extends PlanTool {
        p = pimg==null ? calque.getPlanBase() : pimg;
        if ( p == null ) return false;
        objet = p.objet;
+       body = p.body;
 
        orgWidth = ((PlanImage)p).width;
        orgHeight = ((PlanImage)p).height;
