@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -124,7 +124,7 @@ public class PlanFolder extends Plan {
    /** Dans le cas d'un folder, le pourcent sert  indiquer le nombre de plans en cours
     * de chargement dans le folder (Fits extension)
     */
-   protected String getLabel() {
+   public String getLabel() {
       int p = (int)getPourcent();
       if( p>0 ) return Util.align(label,7,"..")+p;
       return super.getLabel();
@@ -142,10 +142,23 @@ public class PlanFolder extends Plan {
    /** Positionne le niveau d'opacit [0..1] (0: entirement transparent, 1: entirement opaque) */
    public void setOpacityLevel(float opacityLevel) {
       super.setOpacityLevel(opacityLevel);
-      Plan [] list = aladin.calque.getFolderPlan(this,false);
-      for( Plan p : list ) {
+      for( Plan p : aladin.calque.getFolderPlan(this,false) ) {
          if( aladin.calque.canBeTransparent(p) ) p.setOpacityLevel(opacityLevel);
       }
    }
+   
+   /** Retourne le body si tous les plans internes ont le mme, sinon null (inconnu) */
+   public String getBody() {
+      String body=null;
+      boolean first=true;
+      for( Plan p : aladin.calque.getFolderPlan(this,false) ) {
+         if( first ) {
+            body=p.getBody();
+            if( body==null ) return null;  // Premier plan sans body connu => pas de body connu
+            first = false;
+         } else if( !body.equals(p.getBody()) ) return null;   // Panachage ? => pas de body connu
+      }
+      return body;
+   }
 
 }   
