@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -144,7 +144,7 @@ public class PlanFov extends Plan {
 		//System.out.println("le barycentre a pour coordonnes : "+ra+"  "+de);
 		double radius = max( max( diff[0], diff[1] ), max( diff[2], diff[3] ) );
 		//System.out.println("radius vaut : "+radius);
-		return new Projection(null,Projection.SIMPLE,ra,de,radius*60*2,250.0,250.0,500.0,0.0,false,Calib.TAN,Calib.FK5);
+		return new Projection(null,Projection.SIMPLE,ra,de,radius*60*2,250.0,250.0,500.0,0.0,false,Calib.TAN,Calib.FK5,null);
 	}
 
 	/**
@@ -188,7 +188,7 @@ public class PlanFov extends Plan {
 
             }
 
-            ArrayList<PointD[]> polygons = new ArrayList<PointD[]>();
+            ArrayList<PointD[]> polygons = new ArrayList<>();
             if (curFov.getStcObjects() != null) {
                 Iterator<STCObj> itStcObjs = curFov.getStcObjects().iterator();
                 while (itStcObjs.hasNext()) {
