@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -38,5 +38,15 @@ public final class PlanFree extends Plan {
       this.aladin= aladin;
       init();
    }
+   
+   /** Creation d'un plan bidon pour grer le paramtre "body" pour les Projections
+    * @param aladin reference
+    * @param body le body associ  ce plan
+    */
+    protected PlanFree(Aladin aladin, String body) {
+       this(aladin);
+       this.body=body;
+    }
+
 }
 
