@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -294,7 +294,7 @@ public class PlanImageBlink extends PlanImage {
          String originalHeaderFits = headerFits.getOriginalHeaderFits();
          if( m==PERM1 ) originalHeaderFits = modifCalib(originalHeaderFits,new String[] { "2-3","3-2" });
          else if( m==PERM2 ) originalHeaderFits = modifCalib(originalHeaderFits,new String[] { "1-3","3-1" });
-         Projection proj = new Projection(Projection.WCS,new Calib( new HeaderFits(originalHeaderFits) ));
+         Projection proj = new Projection(Projection.WCS,new Calib( new HeaderFits(originalHeaderFits) ),this);
          setNewProjD(proj);
          setHasSpecificCalib();
       } catch( Exception e ) {
@@ -492,6 +492,7 @@ public class PlanImageBlink extends PlanImage {
       if( min==-1 && max==-1 ) { min=dataMinFits; max=dataMaxFits; }
       _min=min; _max=max; _autocut=autocut; flagRecut=true; _restart=false;
 
+      
       ViewSimple vc = aladin.view.getCurrentView();
       int frame = vc.cubeControl.lastFrame;
       activePixelsOrigin(frame);
@@ -626,6 +627,7 @@ public class PlanImageBlink extends PlanImage {
       if( oLastFrame!=-1 ) {
          PlanImageBlinkItem pbi = vFrames.elementAt(oLastFrame);
          if( pbi.pixelsOrigin!=null ) { pixelsOrigin = pbi.pixelsOrigin; return true; }
+         
       }
       return super.getFromCache();
    }
@@ -650,7 +652,10 @@ public class PlanImageBlink extends PlanImage {
          pbi.pixelsOrigin=null;
          if( askMem!=-1 && mem>askMem ) break;
       }
-      if( mem>0 ) aladin.trace(4,"PlanImageBlink.freeRam("+askMem+") ["+label+"] (free "+mem/(1024.*1024)+"MB) ...");
+      if( mem>0 ) {
+         aladin.trace(4,"PlanImageBlink.freeRam("+askMem+") ["+label+"] (free "+mem/(1024.*1024)+"MB) ...");
+         aladin.gc();
+      }
       return mem;
    }
 
@@ -721,7 +726,6 @@ public class PlanImageBlink extends PlanImage {
 
    /** Retourne 1 pixel depuis le disque (sert pour les plugins) */
    protected double getPixel(int x, int y, int z) throws Exception {
-      //      loadInRam();
       PlanImageBlinkItem pbi = vFrames.elementAt(z);
       byte [] pixelsOrigin;
       if( (pixelsOrigin=pbi.pixelsOrigin)!=null ) return getPixVal(pixelsOrigin,bitpix,y*width+x)*bScale+bZero;
@@ -732,10 +736,11 @@ public class PlanImageBlink extends PlanImage {
       }
       if( bufCache==null ) bufCache=new byte[npix];
       seekAndRead(fCacheBis,pbi.cacheOffset + npix*(y*width+x),bufCache,0,bufCache.length);
-      return getPixVal(bufCache,bitpix,x)*bScale+bZero;
+//      return getPixVal(bufCache,bitpix,x)*bScale+bZero;
+      return getPixVal(bufCache,bitpix,0)*bScale+bZero;
    }
 
-   long t,t1;
+//   long t,t1;
 
 
    /** Dplacement et lecture atomique pour viter les problmes en cas de threading */
@@ -836,8 +841,6 @@ public class PlanImageBlink extends PlanImage {
       PlanImageBlinkItem pbi = vFrames.elementAt(oLastFrame);
       setBufPixels8(pbi.pixels);
       pixelsOrigin=pbi.pixelsOrigin;
-      //      if( type==IMAGECUBERGB ) ((PlanRGBInterface)this).calculPixelsZoomRGB();
-      //      else calculPixelsZoom();
       aladin.calque.zoom.zoomView.resetImgID();
       aladin.calque.zoom.zoomView.repaint();
    }
@@ -850,7 +853,7 @@ public class PlanImageBlink extends PlanImage {
       PlanImageBlinkItem pbi = vFrames.elementAt(oLastFrame);
       setBufPixels8(pbi.pixels);
       pixelsOrigin=pbi.pixelsOrigin;
-      aladin.view.resumeSourceStatOnCube();
+      aladin.view.resumeStatOnCube();
       return true;
    }
    
