@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -605,6 +605,7 @@ public class PlanImageRGB extends PlanImage implements PlanRGBInterface {
       status = "Re-sampling (at the nearest pixel):";
       progress = "computing...";
       objet = p.objet;
+      body = p.body;
       if( label==null ) label= "RGB img";
       setLabel(label);
       co = p.co;
@@ -1086,7 +1087,7 @@ public class PlanImageRGB extends PlanImage implements PlanRGBInterface {
    /** Retournement de l'image
     * @param methode 0-N/S, 1-D/G, 2-N/S+D/G
     */
-   protected void flip(int methode) {
+   protected void flip(int methode)  throws Exception {
       createRGB();
       if( methode==0 || methode==2 ) invImageLine(width,height,pixelsRGB);
       if( methode==1 || methode==2 ) invImageRow(width,height,pixelsRGB);
