@@ -33,6 +33,7 @@ import cds.moc.Moc1D;
 import cds.moc.MocCell;
 import cds.moc.SMoc;
 import cds.moc.STMoc;
+import cds.moc.TMoc;
 import cds.tools.Util;
 import cds.tools.pixtools.CDSHealpix;
 import cds.tools.pixtools.Hpix;
@@ -67,6 +68,11 @@ public class PlanMoc extends PlanBGCat {
    
    protected int getTimeStackIndex() { return 0; }
 
+   /** Cration d'un Plan MOC  partir d'un MOC pr-xistant */
+   protected PlanMoc(Aladin aladin, SMoc moc, String label) {
+      this(aladin,null,moc,label,null,-1,null);
+   }
+   
    /** Cration d'un Plan MOC  partir d'un MOC pr-xistant */
    protected PlanMoc(Aladin aladin, SMoc moc, String label, Coord c, double radius,String url) {
       this(aladin,null,moc,label,c,radius,url);
@@ -122,8 +128,9 @@ public class PlanMoc extends PlanBGCat {
       boolean isEmpty = m.isEmpty();
       double cov = m.getCoverage();
       String body = getBody();
-      if( body==null ) body="?";
-      ADD( buf, "\n* Space: ",isEmpty?"--empty--": Coord.getUnit(Healpix.SKYAREA*cov, false, true)+"^2, "+Util.round(cov*100, 3)+"% of "+body);
+      if( body==null || body.equals("?") ) body="";
+      else body=" of "+body;
+      ADD( buf, "\n* Space: ",isEmpty?"--empty--": Coord.getUnit(Healpix.SKYAREA*cov, false, true)+"^2, "+Util.round(cov*100, 3)+"%"+body);
       ADD( buf, "\n* Resolution: ",Coord.getUnit(m.getAngularRes()));
       
       int order = m.getMocOrder();
@@ -233,9 +240,7 @@ public class PlanMoc extends PlanBGCat {
       int maxOrder = getRealMaxOrder(moc);
       ArrayList<double[]> a = new ArrayList<>();
       if( maxOrder==-1 || moc.isFull() ) return a;
-//      SMoc done = new SMoc( moc.getSys(), moc.getMinOrder(),maxOrder );
       SMoc done = moc.dup();
-//      long nside = CDSHealpix.pow2( maxOrder );
 
       Iterator<Long> it = moc.valIterator();
       while( it.hasNext() ) {
@@ -293,29 +298,10 @@ public class PlanMoc extends PlanBGCat {
    static private double [][] getCorners(int order,long pix) throws Exception {
       double [][] radec =  CDSHealpix.borders(order,pix,1);
       double [][] corners = new double[radec.length][2];
-      for (int i=0; i<radec.length; ++i) {
-         int j=A[i];
-         corners[j] = CDSHealpix.polarToRadec( radec[i] );
-      }
+      for (int i=0; i<radec.length; ++i) corners[A[i]] = radec[i];
       return corners;
    }
 
-//   static private double [][] getCorners(long nside,long pix) throws Exception {
-//      Vec3[] tvec = hpx.boundaries(pix,1);   // N W S E
-//      double [][] corners = new double[tvec.length][2];
-//      for (int i=0; i<tvec.length; ++i) {
-//         Pointing pt = new Pointing(tvec[i]);
-//         int j=A[i];
-//         corners[j][0] = ra(pt);
-//         corners[j][1] = dec(pt);
-//      }
-//      return corners;
-//   }
-//   
-//   public static final double cPr = Math.PI / 180;
-//   static private double dec(Pointing ptg) { return (Math.PI*0.5 - ptg.theta) / cPr; }
-//   static private double ra(Pointing ptg) { return ptg.phi / cPr; }
-
    // Retourne la liste des numros HEALPix des 4 voisins directs ou -1 s'ils sont en dehors du MOC   
    // Ordre des voisins => W, N, E, S
    static private long [] getVoisins(int order, SMoc moc, int maxOrder,long npix) throws Exception {
@@ -607,9 +593,11 @@ public class PlanMoc extends PlanBGCat {
       
       lastLowMoc=null;
       
+      boolean mocEquatorial = "C".equals( moc.getSpaceSys());
+      
       // Pour les petits champs, on travaille sans cache, en dcoupant le MOC  la bonne
       // rsolution et  la bonne taille.
-      if( v.getTaille()<20 ) {
+      if( mocEquatorial && v.getTaille()<20 ) {
          try {
             // On amliore un peu la rsolution
 //            if( order<moc.getSpaceOrder() ) order++;
@@ -622,7 +610,7 @@ public class PlanMoc extends PlanBGCat {
             Moc1D mv = v.getMoc();
             
             // POUR LE MOMENT ON NE PREND PAS EN COMPTE LE SYSTEME DE REFERENCE
-            mocP.setSpaceSys( mv.getSpaceSys());
+//            mocP.setSpaceSys( mv.getSpaceSys());
             
             // On dcoupe la zone concerne
             Moc moclow = mocP.intersection( mv );
@@ -808,7 +796,7 @@ public class PlanMoc extends PlanBGCat {
             if( drawingOrder==-1 ) return;
 //            System.out.println("Rcupration Hpix drawingOrder="+drawingOrder+" myOrder="+myOrder+" gapOrder="+gapOrder
 //                  +" lowMoc.getMocOrder="+((SMoc)lowMoc).getMocOrder());
-            //            long drawingNside = CDSHealpix.pow2(drawingOrder);
+//            long drawingNside = CDSHealpix.pow2(drawingOrder);
 
             Moc x = v.getMoc();
             if( !(x instanceof SMoc) ) {
@@ -830,6 +818,12 @@ public class PlanMoc extends PlanBGCat {
             
             
             Iterator<MocCell> it = lowMoc.iterator();
+            
+            // Si vide, on le fera au prochain affichage
+            if( !it.hasNext() ) {
+//               System.err.println("lowMoc empty");
+               return;
+            }
             while( it.hasNext() ) {
                MocCell c = it.next();
                if( viewMoc!=null && !viewMoc.isIntersecting(c.order, c.start)) continue;
@@ -900,5 +894,52 @@ public class PlanMoc extends PlanBGCat {
    protected float factorOpacity = 0.5f;
    protected float getFactorOpacity() { return factorOpacity; }
    
+   
+   static public void main(String []argv) {
+      int n,ncol,nlig;
+      
+      // SMOC resolutions
+      System.out.println("\nSpace Moc resolution table:");
+//      System.out.print("\\n \\n \\nSpace Moc resolution table:\\n \\n");
+      n = SMoc.MAXORD_S;
+      ncol = 4;
+      nlig = n/ncol + (n%ncol>0?1:0);
+      for( int i=0; i<nlig; i++ ) {
+         for( int j=0; j<ncol; j++ ) {
+            int order=i+j*nlig;
+            if( order>n ) continue;
+            double res = Math.sqrt( Healpix.getPixelArea(order));
+            String s = String.format("   %2d:%-10s", order, 
+                  Coord.getUnit(res));
+//            Coord.getUnit(res).replace("","deg").replace("","mu"));
+            System.out.print(s);
+         }
+         System.out.println();
+//         System.out.print("\\n");
+      }
+      
+      // SMOC resolutions
+      System.out.println("\nTime Moc resolution table:");
+//      System.out.print("\\n \\nTime Moc resolution table:\\n \\n");
+      n = TMoc.MAXORD_T;
+      ncol = 4;
+      nlig = n/ncol + (n%ncol>0?1:0);
+      for( int i=0; i<nlig; i++ ) {
+         for( int j=0; j<ncol; j++ ) {
+            int order=i+j*nlig;
+            if( order>n ) continue;
+            long res = TMoc.getDuration(order);
+            String s = String.format("  %2d:%-11s", order, 
+                  Util.getTemps(res));
+//            Util.getTemps(res).replace("","mu"));
+            System.out.print(s);
+         }
+//         System.out.print("\\n");
+         System.out.println();
+      }
+   }
+   
+   
+   
 }
 
