@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -23,7 +23,6 @@ package cds.aladin;
 
 import java.util.ArrayList;
 
-import cds.moc.Moc;
 import cds.moc.SMoc;
 import cds.moc.STMoc;
 import cds.moc.TMoc;
@@ -36,15 +35,15 @@ import cds.tools.pixtools.CDSHealpix;
  */
 public class PlanMocAlgo extends PlanMoc {
    
-   static final int UNION        = 0;
-   static final int INTERSECTION = 1;
-   static final int SUBTRACTION  = 2;
-   static final int DIFFERENCE   = 3;
-   static final int COMPLEMENT   = 4;
-   static final int TOORDER      = 5;
+   static protected final int UNION        = 0;
+   static protected final int INTERSECTION = 1;
+   static protected final int SUBTRACTION  = 2;
+   static protected final int DIFFERENCE   = 3;
+   static protected final int COMPLEMENT   = 4;
+   static protected final int COPY         = 5;
    
    
-   static protected final String [] OPERATION = { "union","inter","sub","diff","compl","ord" };
+   static protected final String [] OPERATION = { "union","inter","sub","diff","compl","copy" };
    
    /** Retourne le nom qui correspond  une opration */
    static protected String getOpName(int op) { return OPERATION[op]; }
@@ -61,10 +60,11 @@ public class PlanMocAlgo extends PlanMoc {
    /** Cration d'un Plan MOC  partir d'une opration (op) et de plans MOCs (pList) 
     * Rq : mthode synchrone (pas de threading)
     */
-   public PlanMocAlgo(Aladin aladin,String label,PlanMoc [] pList,int op,int order) {
+   public PlanMocAlgo(Aladin aladin,String label,PlanMoc [] pList,int op,int order,long maxSize) {
       super(aladin);
       PlanMoc p1 = pList[0];
       p1.copy(this);
+      type = ALLSKYMOC;
       this.c = Couleur.getNextDefault(aladin.calque);
       setOpacityLevel(1.0f);
       String s = getFonction(p1,pList,op,order);
@@ -73,44 +73,56 @@ public class PlanMocAlgo extends PlanMoc {
       
       aladin.trace(3,"MOC computation: "+Plan.Tp[type]+" => "+s);
       
-      try {
-         moc = p1.getMoc().clone();
-         
-         if( op==COMPLEMENT ) moc = ((SMoc)moc).complement();
-         else if( op==TOORDER ) moc.setMocOrder(order);
-         else {
-            for( int i=1; i<pList.length; i++ ) {
-               Moc m1=moc;
-               SMoc m2=pList[i].toReferenceFrame(m1.getSys());
-               switch(op) {
-                  case UNION :        moc = m1.union(        m2); break;
-                  case INTERSECTION : moc = m1.intersection( m2 ); break;
-                  case SUBTRACTION :  moc = m1.subtraction(  m2 ); break;
-                  case DIFFERENCE  :  moc = ((SMoc)m1).difference(   m2 ); break;
+//      for( int j=0; j<3; j++ ) {
+//         long t0 = System.currentTimeMillis();
+         try {
+            moc = p1.getMoc().getSpaceMoc().clone();
+
+            if( op==COMPLEMENT ) moc = ((SMoc)moc).complement();
+            else if( op==COPY ) ((SMoc)moc).setMocOrder(order);
+            else {
+               for( int i=1; i<pList.length; i++ ) {
+                  SMoc m1= (SMoc)moc;
+                  SMoc m2= pList[i].getMoc().getSpaceMoc();
+                  if( !m1.isCompatible( m2 ) ) throw new Exception("Uncompatible MOCs");
+                  m2 = Util.convertTo(m2,m1.getSpaceSys());
+                  
+                  if( order>=0  ) { m1.setMocOrder( order ); m2.setMocOrder( order );}  
+
+                  switch(op) {
+                     case UNION :        moc = m1.union(        m2);  break;
+                     case INTERSECTION : moc = m1.intersection( m2 ); break;
+                     case SUBTRACTION :  moc = m1.subtraction(  m2 ); break;
+                     case DIFFERENCE  :  moc = m1.difference(   m2 ); break;
+                  }
                }
             }
+            ((SMoc)moc).setMinOrder(3);
+            if( maxSize!=-1L ) moc.reduction(maxSize);
+
+         } catch( Exception e ) {
+            if( aladin.levelTrace>=3 ) e.printStackTrace();
+            moc.clear();
+            aladin.error = error = e.getMessage();
+            flagOk=false;
          }
-         ((SMoc)moc).setMinOrder(3);
-         if( order!=-1 ) moc.setMocOrder( order);
+
+         copyright = "Computed by Aladin";
+         flagProcessing=false;
          
-      } catch( Exception e ) {
-         if( aladin.levelTrace>=3 ) e.printStackTrace();
-         moc.clear();
-         aladin.error = error = e.getMessage();
-         flagOk=false;
-      }
-      
-      copyright = "Computed by Aladin";
-      flagProcessing=false;
+//         long t1 = System.currentTimeMillis();
+//         System.out.println("Operation done in "+(t1-t0)+"ms");
+//
+//      }
       flagOk=true;
       setActivated(flagOk);
-      if( moc.getSize()==0 ) error="Empty MOC";
+//      if( moc.isEmpty() ) error="Empty MOC";
       aladin.calque.repaintAll();
 
       sendLog("Compute"," [" + this + " = "+s+"]");
    }
    
-   /** Cration d'un Plan MOC par un "crop" polygone convexe sur un MOC existant (mocSource)
+   /** Cration d'un Plan MOC par un "crop" polygone sur un MOC existant (mocSource)
     * @param aladin
     * Rq : mthode synchrone (pas de threading)
     *
@@ -130,11 +142,12 @@ public class PlanMocAlgo extends PlanMoc {
       aladin.trace(3,"MOC cropping: "+Plan.Tp[type]+" => "+s);
       
       try {
-         int order = mocSource.moc.getMaxUsedOrder();
+         int order = ((SMoc)mocSource.moc).getDeepestOrder();
          ArrayList<double[]> a = new ArrayList<>();
          for( Coord c : cooPolygon ) a.add(new double[]{c.al,c.del});
          
          SMoc m1 = CDSHealpix.createSMoc(a, order);
+         m1.setSpaceSys( mocSource.moc.getSpaceSys() );
          moc = m1.intersection(mocSource.moc);
          
       } catch( Exception e ) {
@@ -146,8 +159,8 @@ public class PlanMocAlgo extends PlanMoc {
       
       copyright = "Computed by Aladin";
       flagProcessing=false;
-      if( moc.getSize()==0 ) {
-         error="Empty MOC";
+      if( moc.isEmpty() ) {
+//         error="Empty MOC";
          flagOk=true;
       } else flagOk=true;
       setActivated(flagOk);
@@ -190,8 +203,8 @@ public class PlanMocAlgo extends PlanMoc {
       
       copyright = "Computed by Aladin";
       flagProcessing=false;
-      if( moc.getSize()==0 ) {
-         error="Empty MOC";
+      if( moc.isEmpty() ) {
+//         error="Empty MOC";
          flagOk=true;
       } else flagOk=true;
       setActivated(flagOk);
@@ -203,8 +216,8 @@ public class PlanMocAlgo extends PlanMoc {
    protected void launchLoading() { }
    
    // Retourne le label associ  l'opration
-   private String getFonction(PlanMoc p1,PlanMoc [] pList,int op,int order) {
-      if( op==TOORDER ) return p1.label+":"+order;
+   static protected String getFonction(PlanMoc p1,PlanMoc [] pList,int op,int order) {
+      if( op==COPY ) return p1.label+":"+order;
       String lab2= pList.length>1 ? pList[1].label : null;
       String lab3= pList.length>2 ? pList[2].label : null;
       return p1.label + " "+ getOpName(op) + (lab2==null ? " " : lab2 + (lab3==null?"":" ..."));
