@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -30,6 +30,7 @@ import java.util.TreeSet;
 import cds.aladin.stc.STCObj;
 import cds.moc.Healpix;
 import cds.moc.SMoc;
+import cds.tools.Util;
 import cds.tools.pixtools.CDSHealpix;
 
 /** Generation d'un plan MOC  partir d'une liste de plans (Image, Catalogue ou map HEALPix) 
@@ -52,7 +53,7 @@ public class PlanMocGen extends PlanMoc {
    
    protected PlanMocGen(Aladin aladin,String label,Plan[] p,int order,double radius,
          double pixMin,double pixMax,double threshold,boolean fov) {
-      super(aladin,null,null,label,p[0].co,30);
+      super(aladin,null,null,label,p[0].co,30,null);
       this.p = p;
       this.order=order;
       this.radius=radius;
@@ -78,70 +79,67 @@ public class PlanMocGen extends PlanMoc {
    
    private boolean stop;
    
-   private void addMocFromCatFov(Plan p1,int order) throws Exception {
-      Iterator<Obj> it = p1.iterator();
-      int m= p1.getCounts();
-      double incrPourcent = gapPourcent/m;
-      int n=0;
-      stop=false;
-      
-      while( it.hasNext() ) {
-         n++;
-         Obj o = it.next();
-         if( !(o instanceof Source) ) continue;
-         
-         if( m<100 || n%100==0 ) {
-            pourcent+=incrPourcent;
-            if( stop ) throw new Exception("Abort");
-         }
-         
-         pourcent+=incrPourcent;
-         Source s = (Source)o;
-         SourceFootprint sf = s.getFootprint();
-         if( sf==null ) continue;
-         List<STCObj> listStcs = sf.getStcObjects();
-         if( listStcs==null || listStcs.size()==0 ) continue;
-         try {
-            SMoc m1 = aladin.createMocRegion(listStcs,order);
-            if( m1!=null ) moc.add(m1);
-         } catch( Exception e ) {
-            if( aladin.levelTrace>=3 ) e.printStackTrace();
-         }
-      }
-   }
-      
    // Ajout d'un plan catalogue au moc en cours de construction
-   private void addMocFromCatalog(Plan p1,double radius,int order) throws Exception {
-      Iterator<Obj> it = p1.iterator();
-      Healpix hpx = new Healpix();
-      int o1 = order;
-      Coord coo = new Coord();
-      int n=0;
+   private void addMocFromCatalog(Plan p1,double radius,int order,boolean fov) throws Exception {
+      
+      
+      long t0,t1;
+      t0=System.currentTimeMillis();
       stop=false;
-      int m= p1.getCounts();
-      double incrPourcent = gapPourcent/m;
+      ((SMoc)moc).setMocOrder(order);
+      SMoc m2 = new SMoc(order);
+      m2.bufferOn(10000);
+      Iterator<Obj> it = p1.iterator();
+      int m= 0;
+      Healpix hpx = new Healpix();
+      double incrPourcent = gapPourcent/p1.getCounts();
       while( it.hasNext() ) {
          Obj o = it.next();
          if( !(o instanceof Position) ) continue;
-         
-         if( m<100 || n%100==0 ) {
-            pourcent+=incrPourcent;
+         pourcent+=incrPourcent;
+         m++;
+
+         if( m%10000==0 ) {
             if( stop ) throw new Exception("Abort");
+            try { moc = moc.union( m2 ); } catch( Exception e ) { if( aladin.levelTrace>=3 ) e.printStackTrace(); }
+            m2.clear();
          }
+
          try {
-            coo.al = ((Position)o).raj;
-            coo.del = ((Position)o).dej;
-            long [] npix ;
-            if( radius==0 ) npix = new long[] { hpx.ang2pix(o1, coo.al, coo.del) };
-            else npix = hpx.queryDisc(o1, coo.al, coo.del, radius);
+
+            // Ajout simple d'une cellule
+            if( !fov && radius==0 ) {
+               long npix = hpx.ang2pix(order, ((Position)o).raj,((Position)o).dej);
+               m2.add(order,npix);
+               continue;
+            }
+
+            // Ajouts par formes
+            SMoc m1=null;
+            // Par FoV ?
+            if( fov ) {
+               Source s = (Source)o;
+               SourceFootprint sf = s.getFootprint();
+               if( sf==null ) continue;
+               List<STCObj> listStcs = sf.getStcObjects();
+               if( listStcs==null ) continue;
+               m1 = aladin.createMocRegion(listStcs,order,true);
+
+               // Par Cones ?
+            } else {
+               m1 = aladin.createMocRegionCircle(((Position)o).raj, ((Position)o).dej, radius, order, true);
+            }
+            m2.setRangeList( m2.seeRangeList().union( m1.seeRangeList() ) );
             
-            for( long pix : npix ) ((SMoc)moc).add(o1,pix);
-            n+=npix.length;
-            if( n>100000 ) { ((SMoc)moc).checkAndFix(); n=0; }
          } catch( Exception e ) {
-            if( aladin.levelTrace>=3 ) e.printStackTrace();
+            if( aladin.levelTrace>=3) e.printStackTrace();
          }
       }
+      try {  moc = moc.union( m2 ); } catch( Exception e ) {
+         if( aladin.levelTrace>=3 ) e.printStackTrace();
+      }
+      t1 =System.currentTimeMillis();
+      aladin.trace(4,"SMOC created in "+Util.getTemps((t1-t0)*1000L)+" ("+m+" sources)");
    }
 
    // Ajout d'un plan Image au MOC en cours de construction
@@ -157,7 +155,6 @@ public class PlanMocGen extends PlanMoc {
          gapA = Math.min(p1.projd.getPixResAlpha(),p1.projd.getPixResDelta());
          for( o1=order; CDSHealpix.pixRes( o1 )/3600. <= gapA*2; o1--);
       } catch( Exception e1 ) {
-         e1.printStackTrace();
       }
 //      if( gap<1 || Double.isNaN(gap) ) gap=1;
 //      
@@ -168,7 +165,7 @@ public class PlanMocGen extends PlanMoc {
       pimg.setLockCacheFree(true);
       pimg.pixelsOriginFromCache();
 
-      int n=0;
+      ((SMoc)moc).bufferOn();
 
       double incrPourcent = gapPourcent/pimg.naxis2;
       long oNpix=-1;  
@@ -195,15 +192,15 @@ public class PlanMocGen extends PlanMoc {
 
                // Juste pour viter d'insrer 2x de suite le mme npix
                if( npix==oNpix ) continue;
-
                ((SMoc)moc).add(o1,npix);
-               if( n>100000 ) { ((SMoc)moc).checkAndFix(); n=0; }
+
                oNpix=npix;
             } catch( Exception e ) {
                if( aladin.levelTrace>=3 ) e.printStackTrace();
             }
          }
       }
+      ((SMoc)moc).bufferOff();
 
       // Les pixels peuvent dsormais tre librs
       pimg.setLockCacheFree(false);
@@ -249,12 +246,12 @@ public class PlanMocGen extends PlanMoc {
       
       // On gnre d'abord un MOC dans le systme de rfrence de la map HEALPix
       // on fera la conversion en ICRS  la fin du processus
-      moc.setMocOrder(order);
-      ((SMoc)moc).setSys( p.frameOrigin==Localisation.GAL ? "G" : 
+      ((SMoc)moc).setMocOrder(order);
+      ((SMoc)moc).setSpaceSys( p.frameOrigin==Localisation.GAL ? "G" : 
                                p.frameOrigin==Localisation.ECLIPTIC ? "E" : "C");
-      frameOrigin = p.frameOrigin;
-      try { moc.setCheckConsistencyFlag(false); } catch(Exception e) {}
+      ((SMoc)moc).bufferOn();
       
+      frameOrigin = p.frameOrigin;
       // Nombre de losanges  traiter
       int n = (int)CDSHealpix.pow2(hipsOrder); 
       n=12*n*n;
@@ -290,7 +287,6 @@ public class PlanMocGen extends PlanMoc {
          
          long min = virtualTileWidth *virtualTileWidth * npixFile;
          try {
-            int nb=0;
             
             // Parcours des blocs
             for( int yCell=0; yCell<nbCell; yCell++ ) {
@@ -322,29 +318,30 @@ public class PlanMocGen extends PlanMoc {
                      if( !Double.isNaN(pixMax) && average>pixMax ) continue;
                   }
                   
-                  
                   long npixMoc = min + xy2hpx(yCell*virtualTileWidth + xCell);
                   ((SMoc)moc).add(order,npixMoc);
-                  nb++;
               }
             }
             
-            // On remet immdiatement au propre le MOC uniquement si on a insr
-            // au-moins 100000 cellules (histoire de ne pas exploser la mmoire)
-            if( nb>100000 ) { ((SMoc)moc).checkAndFix(); nb=0; }
-            
          } catch( Exception e ) {
             e.printStackTrace();
          }
       }
       
-      // Conversion en ICRS si ncessaire
-      if( frameOrigin!=Localisation.ICRS ) {
-         try {
-            moc.setCheckConsistencyFlag(true);
-            moc=toReferenceFrame("C");
-            frameOrigin=Localisation.ICRS;
-         } catch( Exception e ) { e.printStackTrace(); }
+      ((SMoc)moc).bufferOff();
+      
+      try {
+         // Affectation du systme de rfrence planto le cas chant
+         String sys = p.body;
+         if( sys!=null ) moc.setSpaceSys( sys );
+
+         // Conversion en ICRS si ncessaire
+         else moc=toReferenceFrame("C");
+
+         frameOrigin=Localisation.ICRS;
+
+      } catch( Exception e ) {
+         e.printStackTrace();
       }
    }
 
@@ -377,6 +374,15 @@ public class PlanMocGen extends PlanMoc {
          aladin.warning("MOC order greater than HiPS resolution. Assuming MOC order "+order);
       }
       
+      // Cas particuliers o le threshold est nul => rien  ajouter
+      if( threshold==0 ) return;   // Rien a ajouter
+      
+      // Cas particulier o le threashold est 100%, on ajoute la totalit
+      else if( threshold>=1 ) {
+         moc = moc.union(p.moc);
+         return;
+      }
+      
       // Quel est l'ordre des tuiles requis
       int requiredHipsOrder = order-tileOrder;
       
@@ -396,16 +402,15 @@ public class PlanMocGen extends PlanMoc {
       
       // On gnre d'abord un MOC dans le systme de rfrence de la map HEALPix
       // on fera la conversion en ICRS  la fin du processus
-      ((SMoc)moc).setSys( p.frameOrigin==Localisation.GAL ? "G" : 
+      ((SMoc)moc).setSpaceSys( p.frameOrigin==Localisation.GAL ? "G" : 
                                p.frameOrigin==Localisation.ECLIPTIC ? "E" : "C");
       frameOrigin = p.frameOrigin;
-      try { moc.setCheckConsistencyFlag(false); } catch(Exception e) {}
       
       // Nombre de losanges  traiter
       int n = (int)CDSHealpix.pow2(hipsOrder); 
       n=12*n*n;
       
-      System.out.println("Nombre de losanges  traiter (order="+hipsOrder+") : "+n);
+//      System.out.println("Nombre de losanges  traiter (order="+hipsOrder+") : "+n);
       
       try { createHealpixOrder(tileOrder-cellOrder); }
       catch( Exception e1 ) { }
@@ -474,7 +479,6 @@ public class PlanMocGen extends PlanMoc {
             // valeur de queue, on peut tout de suite carter cette tuile
             if( step==1 && queue.size()>0 ) {
                PixCum last = queue.last();
-//               if( last.val>(tile.max/somme) ) {
                if( last.val*somme>tile.max ) {
 //                  System.out.println(" tilemax="+(tile.max/somme)+" less that the min of queue="+last.val+" => rejected");
                   continue;
@@ -540,11 +544,10 @@ public class PlanMocGen extends PlanMoc {
          }
       }
 
+      ((SMoc)moc).bufferOn();
       somme=0;
       try {
          // Remplissage du Moc
-         moc.setCheckConsistencyFlag(false);
-         int nb=0;
          Iterator<PixCum> it = queue.iterator();
          while( it.hasNext() ) {
             PixCum pc = it.next();
@@ -552,13 +555,16 @@ public class PlanMocGen extends PlanMoc {
             somme += pc.val;
             if( somme>threshold ) break;
             ((SMoc)moc).add(order,npix);
-            nb++;
-            if( nb>100000 ) { ((SMoc)moc).checkAndFix(); nb=0; }
          }
+         ((SMoc)moc).bufferOff();
 
+         // Affectation du systme de rfrence planto le cas chant
+         String sys = p.body;
+         if( sys!=null ) moc.setSpaceSys( sys );
+         
          // Conversion en ICRS si ncessaire
-         moc.setCheckConsistencyFlag(true);
-         moc=toReferenceFrame("C");
+         else moc=toReferenceFrame("C");
+         
          frameOrigin=Localisation.ICRS;
          
       } catch( Exception e ) {
@@ -847,36 +853,61 @@ public class PlanMocGen extends PlanMoc {
 //   }
    
    protected boolean waitForPlan() {
+
+      // Pour des benchs
+//      for( int order=6; order<=20; order+=2 ) {
+//         long t0 = System.currentTimeMillis();
+
       try {
          moc = new SMoc();
          ((SMoc)moc).setMinOrder(3);
-         if( order!=-1) moc.setMocOrder(order);
-         ((SMoc)moc).setSys("C");
+         if( order!=-1) ((SMoc)moc).setMocOrder(order);
          frameOrigin=Localisation.ICRS;
-         moc.setCheckConsistencyFlag(false);
+         
+         // Initialisation du body de rfrence
+         String body = p[0].getBody();
+         setBody(body);
+         if( body!=null && body.equals(Plan.BODYSKY) ) body="C";
+         moc.setSpaceSys(body);
+         
          for( Plan p1 : p ) {
-            if( p1.isCatalog() ) {
-               if( fov ) addMocFromCatFov(p1,order);
-               else addMocFromCatalog(p1,radius,order);
-            }
+            if( p1.isCatalog() )    addMocFromCatalog(p1,radius,order,fov);
             else if( p1.isImage() ) addMocFromImage(p1,pixMin,pixMax);
             else if( p1 instanceof PlanBG && !Double.isNaN(threshold) ) addMocFromPlanBG(p1,order,threshold);
             else if( p1 instanceof PlanBG ) addMocFromPlanBG(p1,order,pixMin,pixMax);
          }
-         moc.setCheckConsistencyFlag(true);
       } catch( Exception e ) {
          error=e.getMessage();
          if( aladin.levelTrace>=3 ) e.printStackTrace();
          flagProcessing=false;
          return false;
       }
-      flagProcessing=false;
-      if( moc.getSize()==0 ) error="Empty MOC";
+
+
+//         long t1 = System.currentTimeMillis();
+//         try {
+//            File f = File.createTempFile("toto", "titi");
+//            FileOutputStream fo = new FileOutputStream(f);
+//            moc.writeFITS(fo);
+//            fo.close();
+//            long sizeFits = f.length();
+//            Aladin.trace(3,"SMOC 'order="+((SMoc)moc).getMocOrder()
+//                  +" built in "+(t1-t0)+"ms"
+//                  +" nbRanges="+moc.getNbRanges()
+//                  +" RAM="+Util.getUnitDisk( moc.getMem())
+//                  +" FITS="+Util.getUnitDisk(sizeFits )
+//                  );
+//         } catch( Exception e ) {}
+//
+//      }
+
+     flagProcessing=false;
+//      if( moc.isEmpty() ) error="Empty MOC";
       flagOk=true;
       return true;
    }
-   
 
-      
+
+
 }
 
