@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -191,11 +191,11 @@ public class PlanMultiCCD extends PlanImage {
             SMoc m = buildMoc(p.projd,order);
             if( moc==null ) { 
                moc=m;
-               marge = (long)( moc.getNbCells()*0.2 );
+               marge = (long)( moc.getNbValues()*0.2 );
             }
             else {
                SMoc inter = (SMoc)moc.intersection(m);
-               if( inter.getNbCells() > marge ) return false;
+               if( inter.getNbValues() > marge ) return false;
                moc = (SMoc)moc.union(m);
             }
          }
