@@ -443,13 +443,13 @@ public class Plot {
    
    private void setTimePlot( boolean flag ) {
       flagTime = flag;
-      if( !flag ) {
-      try {
-         throw new Exception();
-      } catch( Exception e ) {
-         e.printStackTrace();
-      }
-      }
+//      if( !flag ) {
+//      try {
+//         throw new Exception();
+//      } catch( Exception e ) {
+//         e.printStackTrace();
+//      }
+//      }
       
    }
    
