@@ -312,14 +312,14 @@ public class Plugins extends ClassLoader implements Runnable,ListModel,Comparato
           b.setToolTipText(aladin.chaine.getString("PLUGDOWNLOADTIP"));
           b.addActionListener(new ActionListener() {
              public void actionPerformed(ActionEvent e) {
-                aladin.glu.showDocument("Http", "http://aladin.u-strasbg.fr/java/nph-aladin.pl?frame=plugRep", true);
+                aladin.glu.showDocument("Http", "http://aladin.cds.unistra.fr/java/nph-aladin.pl?frame=plugRep", true);
              }
           });
           p1.add(b=new JButton(aladin.chaine.getString("PLUGUPLOAD")));
           b.setToolTipText(aladin.chaine.getString("PLUGUPLOADTIP"));
           b.addActionListener(new ActionListener() {
              public void actionPerformed(ActionEvent e) {
-                aladin.glu.showDocument("mailto:plugin@aladin.u-strasbg.fr?" +
+                aladin.glu.showDocument("mailto:plugin@aladin.cds.unistra.fr?" +
                       "Subject=Aladin plugin&Body=%0A%0ADear Aladin team,%0A%0A" +
                       "You will find, joined to this mail, my Aladin plugin source code%0A%0A" +
                       "By this letter, I certify that this code does not content any spyware " +
@@ -345,7 +345,7 @@ public class Plugins extends ClassLoader implements Runnable,ListModel,Comparato
           b.setToolTipText(aladin.chaine.getString("PLUGMOREINFOTIP"));
           b.addActionListener(new ActionListener() {
              public void actionPerformed(ActionEvent e) {
-                 aladin.glu.showDocument("Http", "http://aladin.u-strasbg.fr/java/nph-aladin.pl?frame=plugins", true);
+                 aladin.glu.showDocument("Http", "http://aladin.cds.unistra.fr/java/nph-aladin.pl?frame=plugins", true);
              }
           });
           p1.add(b=new JButton(aladin.chaine.getString("CLOSE")));
