@@ -1,10 +1,10 @@
-// Copyright 1999-2018 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
 //
-//This file is part of Aladin.
+//This file is part of Aladin Desktop.
 //
 //    Aladin Desktop is free software: you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 //    GNU General Public License for more details.
 //
 //    The GNU General Public License is available in COPYING file
-//    along with Aladin.
+//    along with Aladin Desktop.
 //
 
 package cds.aladin;
@@ -50,8 +50,9 @@ public final class Projection {
    static final String [] NAME = { "-", "Aladin reduction",
       "WCS reduction",
       "Simple reduction","Matching star red.","Squattered plot" };
-
+   
    // Les parametres de la projection
+   protected Plan plan = null;      // Plan associ
    protected int frame = Localisation.ICRS;
    protected String label=null;		// Label de la projection
    protected double raj,dej;		// Centre de l'image (J2000)
@@ -77,13 +78,46 @@ public final class Projection {
    protected Coord coo[];			// Liste de quadruplets pour methode QUADRUPLET de recalibration
 
    // Liste des projections comme elles apparaissent dans Aladin, et correspondances dans Calib
-   static String [] alaProj            = {"Spheric", "Tangential", "Aitoff", "Zenital equal area", "Stereographic", "Cartesian", "Mollweide", "Arc" };
-   static String [] alaProjToType      = {"SIN",     "TAN",        "AIT",    "ZEA",                "STG",           "CAR",       "MOL",       "ARC" };
+   static String [] alaProj            = null;
+   static String [] alaProjToType      = null;
 
+   static String [] alaProj1            = {"Spheric", "Tangential", "Aitoff", "Zenital equal area", "Stereographic", "Cartesian", "Mercator", "Mollweide", "Arc", };
+   static String [] alaProjToType1      = {"SIN",     "TAN",        "AIT",    "ZEA",                "STG",           "CAR",       "MER",      "MOL",       "ARC", };
 
+   static String [] alaProjBeta         = {"HEALPix" };
+   static String [] alaProjToTypeBeta   = {"HPX" };
+
+   
+   // Initialisation des projections supportes (en fonction du mode Bta ou non
+   static private void initAlaProj() {
+      if( alaProj!=null ) return;  // dj fait
+      
+      if( !Aladin.BETA )  {
+         alaProj=alaProj1;
+         alaProjToType=alaProjToType1;
+         
+      } else {
+         int n1 = alaProj1.length;
+         int nBeta = alaProjBeta.length;
+         alaProj = new String[ n1+nBeta ];
+         alaProjToType = new String[ n1+nBeta ];
+         System.arraycopy(alaProj1, 0, alaProj, 0, n1);
+         System.arraycopy(alaProjBeta, 0, alaProj, n1, nBeta);
+         System.arraycopy(alaProjToType1, 0, alaProjToType, 0, n1);
+         System.arraycopy(alaProjToTypeBeta, 0, alaProjToType, n1, nBeta);
+      }
+   }
+   
+   /** Retourne la signature en fonction de l'indice de la projection */
+   static public String getProjType(int i) {
+      initAlaProj();
+      return alaProjToType[i];
+   }
+   
    /** Retourne l'indice de la signature de la projection (case insensitive, qu'il s'agisse de son nom complet
     * apparaissant dans Aladin, ou sa signature */
    static public int getProjType(String projectionName) {
+      initAlaProj();
       int i = Util.indexInArrayOf(projectionName,alaProj,true);
       if( i>= 0 ) projectionName = alaProjToType[i];
       return Util.indexInArrayOf(projectionName,Calib.projType,true);
@@ -92,16 +126,23 @@ public final class Projection {
    /** Retourne l'indice de la projection passe en paramtre (case insensitive)
     * dans le tableau des projections compatibles Aladin, -1 si non trouve */
    static public int getAlaProjIndex(String projectionName) {
+      initAlaProj();
       int i = Util.indexInArrayOf(projectionName,alaProj,true);
       if( i>=0 ) return i;
       return Util.indexInArrayOf(projectionName,alaProjToType,true);
    }
 
    /** Retourne la liste des projections supportes par Aladin */
-   static public String[] getAlaProj() { return alaProj ; }
+   static public String[] getAlaProj() {       
+      initAlaProj();
+      return alaProj ; 
+   }
 
    /** Retourne la projection correspondante  l'index */
-   static public String getAlaProj(int i) { return alaProj[i]; }
+   static public String getAlaProj(int i) { 
+      initAlaProj();
+      return alaProj[i]; 
+   }
 
 
    /** Aucune projection */
@@ -110,6 +151,7 @@ public final class Projection {
    /** Creation d'une projection  partir d'une autre projection */
    protected Projection(Projection p) {
       c=p.c;
+      plan=p.plan;
       adjustParamByCalib(c);
    }
 
@@ -119,26 +161,32 @@ public final class Projection {
    }
 
    protected double getDeMax() {
-      return t==Calib.SIN || t==Calib.TAN || t==Calib.SIP || t==Calib.AIT || t==Calib.CAR || t==Calib.MOL
-            || t==Calib.ZEA /*|| t==Calib.ARC */ ? 180 : 360;
+      return t==Calib.SIN ||  t==Calib.TAN || t==Calib.SIP || t==Calib.AIT || t==Calib.CAR || t==Calib.MER || t==Calib.MOL
+            || t==Calib.ZEA || t==Calib.ARC ? 180 : 360;
    }
 
    protected Projection(double refX,double refY,double x, double y, double refW, double refH, double w, double h,
-         boolean flipX, boolean flipY,boolean logX, boolean logY) {
+         boolean flipX, boolean flipY,boolean logX, boolean logY, Plan plan) {
       modeCalib=PLOT;
       raj=alphai = refX;
       dej=deltai = refY;
-      cx = x; cy = y;
-      rm = refW; rm1 = refH;
+      cx = x; 
+      cy = y;
+      rm = refW; 
+      rm1 = refH;
       //       r = w; r1 = h;
-      r = w; r1 = w;
+      r = w; 
+      r1 = h;
       flipPlotX = flipX ? -1 : 1;
       flipPlotY = flipY ? -1 : 1;
       logPlotX = logX;
       logPlotY = logY;
-      //       t=Calib.XYLINEAR;
-   }
+      this.plan = plan;
+      
+//      Aladin.trace(3,"Projection centre:Mesure=("+alphai+","+deltai+") Pixel=("+cx+","+cy+" taille:Mesure="+rm+"x"+rm1+" pixel="+r+"x"+r1);
 
+   }
+   
    private double log(double x) { return Math.log(x)/Math.log(10); }
    private double exp(double x) { return Math.exp(x * Math.log(10) ); }
 
@@ -216,19 +264,20 @@ public final class Projection {
    protected Projection(String label,int type,
          double alphai, double deltai, double rm,
          double cx, double cy,double r,
-         double rot,boolean sym,int t,int system) {
-      this(label,type,alphai,deltai,rm,rm,cx,cy,r,r,rot,sym,t,system);
+         double rot,boolean sym,int t,int system,Plan plan) {
+      this(label,type,alphai,deltai,rm,rm,cx,cy,r,r,rot,sym,t,system,plan);
    }
    protected Projection(String label,int type,
          double alphai, double deltai, double rm,double rm1,
          double cx, double cy,double r, double r1,
-         double rot,boolean sym,int t,int system) {
-
+         double rot,boolean sym,int t,int system, Plan plan) {
+      
       c=new Calib(alphai,deltai,cx,cy,r,r1,rm,rm1,rot,t,sym,system);
       adjustParamByCalib(c);
       this.modeCalib=type;
       this.label=label;
       if( this.label==null ) this.label = getName(type,t);
+      this.plan = plan;
    }
 
    /*
@@ -236,11 +285,12 @@ public final class Projection {
     * @param type type de la projection (mode ALADIN|WCS...)
     * @param c    Calibration
     */
-   public Projection(int type,Calib c) {
+   public Projection(int type,Calib c, Plan plan) {
       this.c=c;
       adjustParamByCalib(c);
       this.modeCalib=type;
       label = getName(type,0);
+      this.plan = plan;
    }
 
    /** Cre un clone de la projection (calibration comprise) */
@@ -260,6 +310,7 @@ public final class Projection {
          System.arraycopy(coo,0,p.coo,0,coo.length);
       }
       p.c = c==null ? null : Calib.copy(c);
+      p.plan = plan;
 
       return  p;
    }
@@ -411,6 +462,9 @@ public final class Projection {
       this.coo = null;
       adjustParamByCalib(c);
    }
+   
+   
+   static private boolean flagUN=true;
 
    /** Recupere les parametres de la projection a partir de la calib passee
     * en parametre
@@ -423,6 +477,7 @@ public final class Projection {
          cy = co.y;
          alphai = co.al;
          deltai = co.del;
+         
          co = c.getImgCenter();
          co = Localisation.frameToFrame(co, frame,Localisation.ICRS);
          //         co.x = c.xnpix/2.;
@@ -485,7 +540,7 @@ public final class Projection {
    @Override
    public String toString() {
       return (label==null?"":label+" ")+getName(modeCalib,t)+" "+
-            round(alphai)+","+round(deltai)+"=>"+((int)cx)+","+((int)cy)+" "+
+             alphai+","+deltai+"=>"+cx+","+cy+" "+
             "("+rm+"x"+rm1+")/("+r+"x"+r1+") "+
             (rot!=0.?"rot="+rot+"deg ":"")+
             (sym?"RA_symetry ":"")+
@@ -616,6 +671,52 @@ public final class Projection {
     * @param c La calibration aladin qu'il faut associe a la projection
    protected void setCalib(Calib c) { this.c = c; }
     */
+   
+   /** Teste si les projections ne concerneraient pas des corps clestes incompatibles
+    * Affiche un warning en cas de suspicion d'incompatiblit
+    * Retourne false que si on est sr de l'incompatibilit.
+    */
+   protected boolean isUncompatibleBody( Projection p ) {
+
+      int r = isUncompatibleBody1( p );
+      if( r!=1 ) {
+         Plan plan = p.plan;
+         if( !Aladin.aladin.isFullScreen() ) {
+            Aladin.aladin.uncompatibleFrameWarning(getBody(), p.getBody());
+         }
+      }
+         
+      return r==0;
+   }
+   
+   /** Teste si les projections ne concerneraient pas des corps clestes incompatibles
+    * @param p
+    * @return 0-incompatible, 1-compatible, -1 ne peut savoir
+    */
+   protected int isUncompatibleBody1( Projection p ) {
+      if( !isOk(p) ) return 0;
+      
+      // Pas d'affichage des donnes plantaires => jamais d'incompatibilit sur les corps
+      if( !Aladin.aladin.configuration.isPlanet() ) return 1;
+      
+      // Planet mais sans test de compatibilit de projection ?
+      else if( Aladin.aladin.configuration.isPlanetNotCheck() ) return 1;
+      
+      String body = getBody();
+      String pbody= p.getBody();
+      
+      // Toujours compatible pour un plot (time ou scatterplot)
+      if( Plot.PROJBODY.equalsIgnoreCase(body) || Plot.PROJBODY.equalsIgnoreCase(pbody) ) return 1;
+
+      // Inconnu => on ne sait pas la compatibilit
+      if( body==null || pbody==null ) return -1;
+      
+      // compatible que si les bodies sont gaux
+      return body.equals(pbody) ? 1 : 0;
+   }
+   
+   /** Retourne le body associ  la projection, ou null si inconnu */
+   protected String getBody() { return plan==null ? null : plan.body; }
 
    /** Test de ``superposabilite'' de deux projections.
     * Retourne vrai si la projection passee en parametre est compatible
@@ -631,8 +732,11 @@ public final class Projection {
 
       if( p==null ) return false;
 
-      // La meme projection
+      // La mme projection
       if( this==p ) return true;
+      
+      // Le mme corps ?
+      if( isUncompatibleBody( p ) ) return false;
 
       // Concerne un champ trs large => toujours compatible
       if( p.rm>30*60 ) return true;
