@@ -1076,8 +1076,9 @@ public class Properties extends JFrame implements ActionListener, ChangeListener
             double degrad = Math.toDegrees(1.0);
             double skyArea = 4.*Math.PI*degrad*degrad;
             String body = plan.getBody();
-            if( body==null ) body="?";
-            PropPanel.addCouple(p,"Coverage: ",new JLabel(Util.round(cov*100, 3)+"% of "+body+" => "+Coord.getUnit(skyArea*cov, false, true)+"^2"),g,c);
+            if( body==null || body.equals("?") ) body="";
+            else body=" of "+body;
+            PropPanel.addCouple(p,"Coverage: ",new JLabel(Util.round(cov*100, 3)+"%"+body+" => "+Coord.getUnit(skyArea*cov, false, true)+"^2"),g,c);
             PropPanel.addCouple(p,"Best ang.res: ",new JLabel(Coord.getUnit(((SMoc)pmoc.getMoc()).getAngularRes())
                   +" (order="+((SMoc)pmoc.getMoc()).getMocOrder()+")"),g,c);
 
