@@ -378,7 +378,7 @@ public final class ServerAladin extends Server implements Runnable, MyListener {
 
          // Particularit pour allsky
          if( isAllSky(criteria) ) {
-            aladin.calque.newPlan("http://aladin.u-strasbg.fr/java/AllSky.fits","AllSky","Aladin image server");
+            aladin.calque.newPlan("http://aladin.cds.unistra.fr/java/AllSky.fits","AllSky","Aladin image server");
 
             // Le cas gnral
          } else {
