@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -1361,6 +1361,7 @@ public class ServerGlu extends Server implements Runnable {
             if( !s.startsWith("http://") && !s.startsWith("https://") ) {
                String urlList = aladin.directory.resolveServiceUrl(gluTag,s);
                if( urlList!=null ) {
+                  resourceId = s;   // mmorisation au cas de redo (cf. PlanCatalog.redo..)
                   tokUrlList = new Tok(urlList,"\t");
                   v.setElementAt( tokUrlList.nextToken(), baseUrlIndex);
                }
@@ -1468,7 +1469,7 @@ public class ServerGlu extends Server implements Runnable {
                         in = Util.openStream(u);
                      } else throw e1;
                   }
-                  n = aladin.calque.newPlanMOC( in, label);
+                  n = aladin.calque.newPlanMOC( in, label, u.toString());
 
                } catch( Exception e1 ) {
                   if( aladin.levelTrace>=3 ) e1.printStackTrace(); 
@@ -1535,7 +1536,7 @@ public class ServerGlu extends Server implements Runnable {
             	if (this.posBounds == null) {
             		STCStringParser parser = new STCStringParser();
 					List<STCObj> stcObjects = parser.parse(this.boundaryAreaStcs);
-					this.posBounds = aladin.createMocRegion(stcObjects,-1);
+					this.posBounds = aladin.createMocRegion(stcObjects,-1, true);
 				}
                 String error = isWithinBounds(this.posBounds, rectVertices);
                 if( error != null ) {
@@ -1801,12 +1802,19 @@ public class ServerGlu extends Server implements Runnable {
          if (showSyncAsync > -1 && this.sync_async != null && this.sync_async.getSelectedItem().equals("ASYNC")) {
             this.fireASync(label, u);
          } else {
-            lastPlan = aladin.calque.createPlan(u + "", label, "provided by " + institute, this);
+            lastPlan = callCreatePlan(u + "", label, "provided by " + institute, this);
+//            lastPlan = aladin.calque.createPlan(u + "", label, "provided by " + institute, this);
          }
       }
 
       if( code!=null && lastPlan!=null ) lastPlan.setBookmarkCode(code+" $TARGET $RADIUS");
    }
+   
+   /** Appel effectif pour la cration du plan.
+    * Cette mthode est surcharg dans le cas d'un service utilisant un POST multipart => ex: ServerSextractor */
+   protected Plan callCreatePlan(String u,String label, String orig, Server server) {
+      return aladin.calque.createPlan(u, label, orig, server);
+   }
 
    /**
     * Method shows fov from the stc string
