@@ -99,7 +99,7 @@ public final class ServerVizieR extends Server implements CDSConstants,Runnable
       createChaine();
       type = CATALOG;
       aladinLogo = "VizieRLogo.gif";
-      docUser="http://vizier.u-strasbg.fr";
+      docUser="http://vizier.cds.unistra.fr";
       gluTag = "VizieRXML++1";
       aladinLabel="VizieR";
       
