@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -113,6 +113,12 @@ MouseMotionListener,MouseListener,Widget {
       addMouseWheelListener(this);
       this.wheelIncr=wheelIncr;
    }
+   
+   public Dimension getPreferredSize() {
+      Dimension dim = super.getPreferredSize();
+      double scale = (Aladin.getUIScale()-1)/1.25 +1;
+      return new Dimension( dim.width, (int)( dim.height*scale) );
+   }
 
    public void mouseWheelMoved(MouseWheelEvent e) {
       if( !enable ) return;
