@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -87,17 +87,13 @@ public class SourcePhot extends SourceTag {
    /** (Re)nration de la ligne des infos (dtermine les mesures associes) */
    protected void resumeMesures() {
       Coord c = new Coord(raj,dej);
-      info = "<_A Phots>\t"+raj+"\t"+dej+"\t"+id+"\t"+planBase.label+"\t"+"\t"+c.getRA()+"\t"+c.getDE()
+      info = "<&_A|Phots>\t"+raj+"\t"+dej+"\t"+id+"\t"+planBase.label+"\t"+"\t"+c.getRA()+"\t"+c.getDE()
              +"\t"+iqe[0]+"\t"+iqe[2]+"\t"+iqe[1]+"\t"+iqe[3]+"\t"+iqe[4]+"\t"+iqe[5]+"\t"+iqe[6];
    }
 
    /** Retourne le type d'objet */
    public String getObjType() { return "Phot"; }
 
-   /** Positionne l'id par defaut */
-   void setId() {
-      if( id==null ) id="Phot "+ nextIndice();
-   }
-   
    protected int getL() { return super.getL()*3; }
+   
 }
