@@ -263,7 +263,7 @@ public class SourceStat extends SourceInfo {
 
       int D=l;
       clip = unionRect(clip, p.x-D,p.y-D,D*2,D*2);
-      if( isSelected() )  clip = unionRect(clip, p.x-l-DS,p.y-l-DS,l*2+DDS,l*2+DDS);
+      if( isSelected() )  clip = unionRect(clip, p.x-l-DS,p.y-l-DS,l*2+DDS+2,l*2+DDS+2);
       if( isWithLabel() ) clip = unionRect(clip, p.x-dw/2,p.y-L-1-dh-1,dw,dh);
       if( isWithStat() )  clip = unionRect(clip,getStatPosition(v));
       return clip;
