@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -119,9 +119,18 @@ public class Tag extends Position {
       setWH();
    }
 
-  /** Creation d'un tag pour les backups */
+   /** Creation d'un tag pour les backups */
    protected Tag(Plan plan) { super(plan); }
    
+   /** Creation d'un tag String centr ddi  un PlanField */
+   protected Tag(PlanField plan, String content, double ra, double dec ) { 
+      this( plan);
+      setText(content);
+      setXYTan(Util.tand(ra), Util.tand(dec));
+      distAngulaireOrig=1000;   // Pour effacement automatique au dessus de qq deg de largeur de champ
+      accroche=0; dist=1;       // Subtilit pour forcer le centrage => BEURK
+   }
+   
    /** Fournit une copie du Tag */
    protected Tag copy() {
       Tag t = new Tag();
@@ -722,11 +731,14 @@ public class Tag extends Position {
       
       FontMetrics m = Toolkit.getDefaultToolkit().getFontMetrics( getFont() );
       boolean aDroite =angle>Math.PI/2 && angle<3*Math.PI/2;
+      boolean centre = accroche==0 && dist==1;
       int y1 = p.y - dim.height/2 + m.getAscent();
       StringTokenizer st = new StringTokenizer(id,"\n");
       while( st.hasMoreTokens() ) {
          String s = st.nextToken();
-         int x1 = p.x + (aDroite ? dim.width/2 - m.stringWidth(s) : -dim.width/2);
+         int x1 = p.x + (centre  ? -m.stringWidth(s) : 
+                         aDroite ? dim.width/2 - m.stringWidth(s) : 
+                         -dim.width/2);
          g.drawString(s,x+x1,y+y1);
          if( fond==0 ) Util.drawStringOutline(g, s,x+x1,y+y1, null, Color.black);
          else g.drawString(s,x+x1,y+y1);
