@@ -65,6 +65,9 @@ import cds.tools.pixtools.CDSHealpix;
  */
 public class TreeObjDir extends TreeObj implements Propable {
    
+   public final static int DEFAULTRADIUS = 3;
+   public final static String DIRECT = "DIRECT/"; // prfixe ajout  l'ID dans le cas d'un accs direct par URL explicite
+   
    public String internalId;    // Alternative  l'ID de l'identificateur GLU
    private String url;          // L'url ou le path du survey
    public String description;   // Courte description (une ligne max)
@@ -108,7 +111,6 @@ public class TreeObjDir extends TreeObj implements Propable {
    
    protected MyProperties prop=null; // Ensemble des proprits associes au HiPS (via son fichier de properties ou MocServer)
 
-   public final static String DIRECT = "DIRECT/"; // prfixe ajout  l'ID dans le cas d'un accs direct par URL explicite
    
    
    /** Retourne le titre long de la ressource, et si c'est une table VizieR, un nom compos du titre du catalogue,
@@ -686,24 +688,24 @@ public class TreeObjDir extends TreeObj implements Propable {
    }
    
    private boolean getIsColorByPath(String path,boolean local) {
-      String ext = inPNG ? ".png" : ".jpg";
+      String ext = inPNG ? "png" : "jpg";
       MyInputStream in = null;
       try {
-         if( local ) return Util.isJPEGColored(path+Util.FS+"Norder3"+Util.FS+"Allsky"+ext);
-         in = new MyInputStream( Util.openStream(path+"/Norder3/Allsky"+ext) );
+         if( local ) return Util.isJPEGColored( Context.findOneNpixFile(path,ext) );
+         in = new MyInputStream( Util.openStream(path+"/Norder3/Allsky."+ext) );
          byte [] buf = in.readFully();
          return Util.isColoredImage(buf);
       } catch( Exception e) {
-         aladin.trace(3,"Allsky"+ext+" not found => assume B&W survey");
+         aladin.trace(3,"Allsky."+ext+" not found => assume B&W survey");
          return false;
       }
       finally { try { if( in!=null ) in.close(); } catch( Exception e1 ) {} }
    }
 
    private boolean getFormatByPath(String path,boolean local,int fmt) {
-      String ext = fmt==0 ? ".fits" : fmt==1 ? ".jpg" : fmt==3 ? ".png" : ".xml";
-      return local && (new File(path+Util.FS+"Norder3"+Util.FS+"Allsky"+ext)).exists() ||
-            !local && Util.isUrlResponding(path+"/Norder3/Allsky"+ext);
+      String ext = fmt==0 ? "fits" : fmt==1 ? "jpg" : fmt==3 ? "png" : "xml";
+      return local && Context.findOneNpixFile(path,ext)!=null ||
+            !local && Util.isUrlResponding(path+"/Norder3/Allsky."+ext);
    }
 
    private int getMaxOrderByPath(String urlOrPath,boolean local) {
@@ -712,14 +714,6 @@ public class TreeObjDir extends TreeObj implements Propable {
                || !local && Util.isUrlResponding(urlOrPath+"/Norder"+n)) return n;
       }
       return -1;
-
-      //      int maxOrder=-1;
-      //      for( int n=3; n<100; n++ ) {
-      //         if( local && !(new File(urlOrPath+Util.FS+"Norder"+n).isDirectory()) ||
-      //            !local && !Util.isUrlResponding(urlOrPath+"/Norder"+n)) break;
-      //         maxOrder=n;
-      //      }
-      //      return maxOrder;
    }
    
    protected JPanel createPanel() {
@@ -1204,7 +1198,7 @@ public class TreeObjDir extends TreeObj implements Propable {
    }
  
    /** Gnration et excution de la requte script correspondant au protocole SSA */
-   protected void loadSSA() { loadSSA( getDefaultTarget()+" "+getDefaultRadius(1) ); }
+   protected void loadSSA() { loadSSA( getDefaultTarget()+" "+getDefaultRadius(DEFAULTRADIUS) ); }
    protected void loadSSA( String cone ) {
       if( cone==null ) { loadSSA(); return; }
      exec( addBrowse( getSSACmd()+" "+cone) );
@@ -1223,11 +1217,11 @@ public class TreeObjDir extends TreeObj implements Propable {
    }
    
    /** Gnration et excution de la requte script correspondant  la requte TAp AssocData */
-   protected void loadAssoc() { loadAssoc( getDefaultTarget()+" "+getDefaultRadius(1)); }
+   protected void loadAssoc() { loadAssoc( getDefaultTarget()+" "+getDefaultRadius(DEFAULTRADIUS)); }
    protected void loadAssoc( String cone ) { 
       if( cone==null ) { loadAssoc(); return; }
       String ident = "\"AD "+internalId+"\"";
-     exec( ident+" = "+getAssocCmd()+" "+cone+"; select "+ident );
+      exec( ident+" = "+getAssocCmd()+" "+cone+"; select "+ident );
    }
    protected String getAssocCmd() {
       String cat = Directory.getCatParent( internalId.substring(internalId.indexOf('/')+1) );
@@ -1235,7 +1229,7 @@ public class TreeObjDir extends TreeObj implements Propable {
    }
    
    /** Gnration et excution de la requte script correspondant au protocole SIA ou SIA2 */
-   protected void loadSIA() { loadSIA( getDefaultTarget()+" "+getDefaultRadius(1)); }
+   protected void loadSIA() { loadSIA( getDefaultTarget()+" "+getDefaultRadius(DEFAULTRADIUS)); }
    protected void loadSIA( String cone ) { 
       if( cone==null ) { loadSIA(); return; }
      exec( addBrowse( getSIACmd()+" "+cone) );
@@ -1283,7 +1277,7 @@ public class TreeObjDir extends TreeObj implements Propable {
    }
    
    /** Du sur-mesure pour le live Simbad */
-   protected void loadLiveSimbad() { loadLiveSimbad(getDefaultTarget()+" "+getDefaultRadius(15)); }
+   protected void loadLiveSimbad() { loadLiveSimbad(getDefaultTarget()+" "+getDefaultRadius(DEFAULTRADIUS)); }
    protected void loadLiveSimbad( String cone ) {
       if( cone==null ) { loadLiveSimbad(); return; }
      exec( addBrowse(  getLiveSimbadCmd()+" "+cone));
@@ -1295,7 +1289,7 @@ public class TreeObjDir extends TreeObj implements Propable {
    }
    
    /** Gnration et excution de la requte script correspondant au protocole CS ou assimil ASU */
-   protected void loadCS() { loadCS(getDefaultTarget()+" "+getDefaultRadius(15)); }
+   protected void loadCS() { loadCS(getDefaultTarget()+" "+getDefaultRadius(DEFAULTRADIUS)); }
    protected void loadCS(Coord c,double radius) {
       loadCS( aladin.localisation.ICRSToFrame( c ).getDeg()+" "+Coord.getUnit( radius ) );
    }
