@@ -369,11 +369,11 @@ public final class TreeView extends JFrame implements WindowListener, ActionList
       double radiusDeg = Server.getAngleInArcmin(radius,Server.RADIUS)/60.0;
       try {
         if( server instanceof ServerAladin ) {
-			url = new URL("http://aladin.u-strasbg.fr/cgi-bin/nph-HTTP.cgi?out=qualifier&position="+URLEncoder.encode(getDeciCoord(target))+"&radius="+radiusDeg+"&mode=xml_votable");
+			url = new URL("http://aladin.cds.unistra.fr/cgi-bin/nph-HTTP.cgi?out=qualifier&position="+URLEncoder.encode(getDeciCoord(target))+"&radius="+radiusDeg+"&mode=xml_votable");
 
 		}
 		else if( server instanceof ServerVizieR) {
-			url = new URL("http://vizier.u-strasbg.fr/cgi-bin/votable/-w?-meta&-c="+URLEncoder.encode(target)+"&-c.r="+radiusDeg+"&-c.u=degree&-c.eq=J2000");
+			url = new URL("http://vizier.cds.unistra.fr/cgi-bin/votable/-w?-meta&-c="+URLEncoder.encode(target)+"&-c.r="+radiusDeg+"&-c.u=degree&-c.eq=J2000");
 		}
 
 		else
