@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -605,7 +605,8 @@ public class UWSJob implements ActionListener{
 	}
 	
 	public static Font getErrorFont() {
-		Font font = new Font("PLAIN", Font.PLAIN, 15);
+//		Font font = new Font("PLAIN", Font.PLAIN, 15);
+		Font font = Aladin.LPLAIN;
 		Map fontAttri = font.getAttributes();
 		fontAttri.put(TextAttribute.STRIKETHROUGH, TextAttribute.STRIKETHROUGH_ON);
 		return new Font(fontAttri);
