@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -29,6 +29,7 @@ import java.awt.Color;
 import java.awt.FontMetrics;
 import java.awt.Graphics;
 import java.awt.Polygon;
+import java.awt.Rectangle;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseWheelEvent;
 import java.util.HashMap;
@@ -38,6 +39,9 @@ import java.util.StringTokenizer;
 import cds.tools.Util;
 
 class ZoomHist implements Runnable {
+   
+   static private String KEEPHELP;
+   static private String KEEP;
 
    int MARGE = 8;
    int NBHIST = 12;
@@ -59,13 +63,17 @@ class ZoomHist implements Runnable {
    String texte=null;       // Texte en surcharge, ou null (retour  la ligne par "/")
 
    // Paramtres pour un histogramme de pixels
-   static final int MAX = 200000;   // nombre max de pixels pris en compte
-   private double [] pixelList;    // liste des valeurs des pixels (lors de la construction)
-   private int nPix;               // nombre de pixels
-   protected boolean flagHistPixel;  // true s'il s'agit d'un histogramme de pixels
+   boolean flagHistPixel;   // true s'il s'agit d'un histogramme de pixels
+   StatPixels pixelStats;   // Statistisques et valeur des pixels
+   Obj obj;                 // l'objet concern par les stats pixels (cf startHistPixel())
+   IconKeep keep;           // Le bouton pour capturer les stats courantes
 
    ZoomHist(Aladin aladin) {
       this.aladin=aladin;
+      pixelStats = new StatPixels();
+      KEEP = aladin.chaine.getString("KEEP");
+      KEEPHELP = aladin.chaine.getString("KEEPHELP");
+      keep = new IconKeep();
    }
 
    /** Positionnement d'un texte en surcharge de l'histogramme, null si aucun */
@@ -75,30 +83,27 @@ class ZoomHist implements Runnable {
    protected String getCopier() { return texte; }
 
    /** Commence ou recommence la mmorisation des pixels d'un histogramme de pixels */
-   protected void startHistPixel() {
-      if( pixelList==null ) pixelList = new double[MAX];
-      nPix=0;
+   protected void startHistPixel(Obj obj) {
+      this.obj = obj;
       flagHistPixel=true;
       texte=null;
+      pixelStats.reinit();
    }
 
-   protected boolean isOverFlow() { return nPix==MAX; }
+   protected boolean isOverFlow() { return false; }
 
    /** Ajoute une valeur pour un future histogramme de pixels */
    protected boolean addPixel(double pix) {
-      if( nPix==MAX ) return false;
-      pixelList[nPix++] = pix;
+      pixelStats.addPix(0, 0, pix);
       return true;
    }
 
    /** Construction de l'histogramme de pixels en fonction de la liste des valeurs passes */
-   protected void createHistPixel(String titre) { {
-      //      titre="Pixels";
+   protected void createHistPixel(String titre) {
       this.titre = titre;
-      setHist(pixelList); }
+      setHist(pixelStats);
    }
 
-
    class HistItem {
       int nb;              // Nombre d'lment
       double prop;         // proportion
@@ -111,7 +116,7 @@ class ZoomHist implements Runnable {
 
       /** Positionne le flag onMouse : true si le point pass en paramtre se trouve dans la case */
       boolean in(int xc,int yc) {
-         return xc>=x && xc<=x+larg;
+         return xc>=x && xc<=x+larg + GAP;
       }
 
       /** Retourne true si la valeur du pixel se trouve entre les bornes */
@@ -125,6 +130,7 @@ class ZoomHist implements Runnable {
     * @return true si l'histogramme a pu tre gnr
     */
    protected boolean init(Source o,int nField) {
+      obj=null;                               // si jamais le prcdent Hist tait associ  une mesure photomtrique
       if( thread!=null ) return false;        // Pour le moment, un thread aprs l'autre uniquement
       flagHistPixel=false;
       texte=null;
@@ -139,7 +145,7 @@ class ZoomHist implements Runnable {
 
    /** Si trop de sources, on va threader */
    protected boolean init() {
-      if( flagHistPixel ) { setHist(pixelList); return true; }
+      if( flagHistPixel ) { setHist(pixelStats); return true; }
       else {
          if( aladin.mesure.getNbSrc()>10000 ) {
             thread = new Thread(this,"Histo");
@@ -160,8 +166,12 @@ class ZoomHist implements Runnable {
    protected boolean initThread() {
       if( o.getLeg().isNumField(nField) ) {
          double [] xHist = aladin.mesure.getFieldNumericValues(o, nField);
-         nb=xHist.length;
-         setHist(xHist);
+         pixelStats.reinit();
+         for( double x : xHist) pixelStats.addPix(0, 0, x);
+         flagHistPixel=true;
+
+         setHist(pixelStats);
+         
       } else {
          String [] sHist=aladin.mesure.getFieldStringValues(o, nField);
          nb=sHist.length;
@@ -199,13 +209,16 @@ class ZoomHist implements Runnable {
       setNbHist(n);
       return true;
    }
+   
+   protected void setHist(StatPixels pixelStats) { setHist( pixelStats.getStatisticPix() ); }
 
    /**
     * Initialisation de l'histogramme avec une liste de valeurs numriques
     */
-   protected void setHist(double [] x) {
+   protected void setHist(double [] x) { setHist(x,x.length); }
+   protected void setHist(double [] x, int length) {
 
-      int length = flagHistPixel ? nPix : x.length;
+//      int length = flagHistPixel ? nPix : x.length;
 
       // Recherche du min et max
       double min=Double.MAX_VALUE;
@@ -327,6 +340,30 @@ class ZoomHist implements Runnable {
       }
    }
 
+   /** True si la souris est sur le bouton GetIt */
+   protected boolean isInGetIt(int x, int y) { 
+      boolean rep= keep.checkInside(x, y);
+      
+      // Si on est dans le bouton, on n'est pas dans une case de l'histogramme
+      if( rep ) onMouse=null;
+      return rep;
+   }
+   
+   /** Action du bouton getIt */
+   protected void getIt() { 
+      SourceInfo s=null;
+      
+      if( obj instanceof SourceStat )  s = new SourceInfo( ((SourceStat)obj ));
+      else if( obj instanceof Ligne )  s = new SourceInfo( ((Ligne)obj ));
+      else return;  // Bizarre
+      
+      // Insertion et slection de la SourceInfo nouvellement cre
+      obj.plan.pcat.insertSource( s );
+      aladin.view.setSelected(s, true);
+      
+      aladin.view.newView(1);
+      aladin.view.repaintAll();
+   }
 
    /** Slection de toutes les sources highlightes */
    protected void selectHighlightSource() {
@@ -399,6 +436,7 @@ class ZoomHist implements Runnable {
       }
       boolean rep = onMouse!=null;
       onMouse=null;
+      keep.inside=false;
       return rep;
    }
 
@@ -462,7 +500,8 @@ class ZoomHist implements Runnable {
          } else {
             g.setColor( hist[i]==onMouse ? Aladin.COLOR_GREEN : Aladin.COLOR_CONTROL_FOREGROUND_UNAVAILABLE );
             g.fillRect((int)x+dx, y-hist[i].haut+dy, (int)larg, hist[i].haut);
-            g.setColor( Aladin.COLOR_CONTROL_FOREGROUND ); //Color.black );
+//            g.setColor( Aladin.COLOR_CONTROL_FOREGROUND ); 
+            g.setColor( Aladin.COLOR_MEASUREMENT_FOREGROUND_SELECTED_LINE );
             g.drawRect((int)x+dx, y-hist[i].haut+dy, (int)larg, hist[i].haut);
             hist[i].x=(int)x; hist[i].y=y-hist[i].haut; hist[i].larg=(int)larg; // voir setIn()
             x+=larg+gap;
@@ -507,9 +546,7 @@ class ZoomHist implements Runnable {
          // Gnral
       } else {
          s=titre;
-         if( nbCategorie>0 ) {
-            s=s+" ("+nbCategorie+" item"+(nbCategorie>1?"s)":")");
-         }
+         if( nbCategorie>0 ) s=s+" ("+nbCategorie+" item"+(nbCategorie>1?"s)":")");
          if( s!=null ) g.drawString(s,5,14);
       }
 
@@ -541,24 +578,87 @@ class ZoomHist implements Runnable {
       }
 
       // Des informations textuelles en surcharge (on carte Stat.. qui concerne les cercles)
-      if( texte!=null && !texte.startsWith("Stat")) {
+      if( flagHistPixel ) {
          g.setFont(Aladin.BOLD);
          fm = g.getFontMetrics();
-         g.setColor( aladin.COLOR_RED );
-         StringTokenizer st = new StringTokenizer(texte,"/");
+         g.setColor( Aladin.COLOR_ICON_ACTIVATED );
+         StringTokenizer st = new StringTokenizer(getStringStat(),"/");
          y = 17;
          int h= fm.getHeight();
          int h1 = fm.getAscent();
-//                  Util.drawArea(aladin, g, width/2, y-10, width/2-5, st.countTokens()*15, Color.white, 0.7f, false);
-//         g.setColor(Color.black);
          while( st.hasMoreTokens() ) {
             s = st.nextToken().trim();
             int len = fm.stringWidth(s);
             int x1 = width - len-5;
-//            Util.drawCartouche(g, x1, y, len, h, 0.8f, null, aladin.DARK_THEME ? Color.gray : Color.white);
+//            Util.drawStringOutline(g, s, x1, y+h1, aladin.COLOR_RED, Color.white);
             g.drawString(s, x1, y+h1);
             y+=h;
          }
+         
+         // Le bouton de capture
+         if( obj!=null ) keep.draw(g,width-40,y+15);
+         else keep.inside=false;
       }
    }
+         
+   // Retourne une chaine reprenant les infos statistiques  afficher en superposition
+   String getStringStat() {
+      // nb, sum, sigma, surface, min, max, median
+      double x [] = pixelStats.getStatistics(true);
+      return "Cnt "+Util.myRound(x[0])
+            +" / Sum "+Util.myRound(x[1])
+            +" / Sigma "+Util.myRound(x[2])
+//            +" / Min "+Util.myRound(x[4])
+            +" / Avg "+Util.myRound((x[1]/x[0]))
+            +(Double.isNaN(x[6])?"":" / Med "+Util.myRound(x[6]))
+//            +" / Max "+Util.myRound(x[5])
+            ;
+
+   }
+   
+   // Barres horizontales du dessin (cadre et une flche pointant  l'intrieur)
+   static final private int KEEP_LOGO[][] = {
+         {0,0,13},
+         {1,0,0},             {1,13,13},
+         {2,0,0},             {2,13,13},
+         {3,0,0},             {3,13,13},
+         {4,0,0},             {4,13,13},
+         {5,0,0},  {5,6,6},   {5,13,13},
+         {6,0,0},  {6,5,7},   {6,13,13},
+         {7,0,0},  {7,4,8},   {7,13,13},
+         {8,0,0},  {8,5,7},   {8,13,13},
+         {9,0,2},  {9,5,7},   {9,11,13},
+                  {10,5,7},  
+                  {11,5,7},  
+         };
+   
+   /** Permet la gestion d'une petite icone qui apparait sous les statistiques des pixels afin de pouvoir les mmoriser
+    * en tant qu'entre indpendante dans le Plan Drawing d'o est issu l'outil de photomtrie (Cercle ou Polygone) qui a fourni
+    * ces statistiques */
+   public class IconKeep {
+      int width=32;         // Largeur de l'icone
+      int height=24;        // Hauteur de l'icone
+      int heightLogo=10;    // Bas du logo (car on va dessiner le logo en miroir horizontal
+      Rectangle rpos=null;  // Rectangle mmorisant l'emplacement de l'icone
+      boolean inside;       // true si la souris est suppos tre sur l'icone
+
+      // Affichage du logo et du label juste en dessous
+      void draw(Graphics g, int x, int y) {
+         g.setColor( !inside ? Aladin.COLOR_CONTROL_FOREGROUND : Aladin.COLOR_CONTROL_FOREGROUND_HIGHLIGHT);
+         for( int i=0; i<KEEP_LOGO.length; i++ ) g.drawLine(KEEP_LOGO[i][1]+x,heightLogo-KEEP_LOGO[i][0]+y,KEEP_LOGO[i][2]+x,heightLogo-KEEP_LOGO[i][0]+y);
+         g.setFont(Aladin.SPLAIN);
+         g.drawString(KEEP,x-10+ width/2-g.getFontMetrics().stringWidth(KEEP)/2,y+height-2);
+         rpos = new Rectangle(x,y,width,height);
+      }
+      
+      // Retourne vrai si la coordonne se trouve dans l'icone. 
+      boolean checkInside(int x, int y) {
+         boolean before=inside;
+         inside=rpos!=null && rpos.contains(x,y);
+         if( before!=inside ) Util.toolTip(aladin.calque.zoom.zoomView, inside ? KEEPHELP : null, true);
+         return inside;
+      }
+      
+   }
+
 }
