@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -29,6 +29,7 @@ public interface PropAction {
    static final int NOTHING = -1;
    static final int FAILED  = 0;
    static final int SUCCESS = 1;
+   static final int SUCCESSCLOSE = 2;
    
    public int action();
 }
