@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -65,8 +65,9 @@ public class PropPanel extends JPanel {
       for( Prop p : propList ) {
          int a = p.apply();
          if( a==PropAction.FAILED ) rep = a;
-         else if( rep==PropAction.NOTHING && a==PropAction.SUCCESS ) rep = a;
+         else if( rep==PropAction.NOTHING && (a==PropAction.SUCCESS || a==PropAction.SUCCESSCLOSE) ) rep = a;
       }
+      if( rep==PropAction.SUCCESSCLOSE && frame!=null ) frame.setVisible(false);
       return rep;
    }
    
