@@ -29,6 +29,7 @@ import java.nio.file.Files;
 import java.util.HashMap;
 import java.util.Iterator;
 
+import cds.aladin.Calib;
 import cds.aladin.MyProperties;
 import cds.aladin.Tok;
 import cds.fits.Fits;
@@ -43,6 +44,12 @@ import cds.tools.pixtools.Util;
  *
  */
 public abstract class Builder {
+   
+   static public final boolean GAUSS = false;
+   static final boolean NEWCUBE = false;
+//   static final boolean TRIMBORDER = false;
+   static final boolean TESTALLSKY = true;
+//   static final boolean GZIPBYDEFAULT = false;
 
    protected Builder b=null;                 // Subtilit pour faire afficher des statistiques
 
@@ -76,10 +83,13 @@ public abstract class Builder {
          case CHECKCODE: return new BuilderCheckCode(context);
          case UPDATEDATASUM: return new BuilderUpdateDataSum(context);
          case CHECK:     return new BuilderCheck(context);
-         case CHECKDATASUM: return new BuilderCheckFits(context);
+         case CHECKDATASUM: return new BuilderCheckDataSum(context);
+         case CHECKFAST: return new BuilderCheckFast(context);
          case LINT:      return new BuilderLint(context);
-//         case GZIP:      return new BuilderGzip(context);
+         case GZIP:      return new BuilderGzip(context);
          case GUNZIP:    return new BuilderGunzip(context);
+         case TRIM:      return new BuilderTrim(context);
+         case UNTRIM:    return new BuilderUntrim(context);
          case RGB:       return new BuilderRgb(context);
          case TREE:      return new BuilderTree(context);
          case CONCAT:    return new BuilderConcat(context);
@@ -93,6 +103,8 @@ public abstract class Builder {
          case SMOC:      return new BuilderSMoc(context);
          case TMOC:      return new BuilderTMoc(context);
          case STMOC:     return new BuilderSTMoc(context);
+         case VALIDATOR: return new BuilderValidator(context);
+         case CUT:       return new BuilderCut(context);
 //         case ZIP:       return new BuilderZip(context);
          default: break;
       }
@@ -123,6 +135,10 @@ public abstract class Builder {
       context.warning("Action "+getAction()+" not run due to the -n option");
       return true;
    }
+   
+   /** Retourne le temps d'execution (ms) si connue, -1 sinon */
+   protected long execTime=-1L;
+   public long getExecTime() { return execTime; }
 
    // Quelques validateurs gnriques utiliss par les diffrents Builders.
 
@@ -136,6 +152,20 @@ public abstract class Builder {
       if( f.isFile() ) {
          context.info("Unique input image detected");
          context.setFlagInputFile(true);
+         if( !input.endsWith(".hhh") ) {
+            try {
+               Fits f1 = new Fits();
+               f1.loadHeaderFITS(input, false);
+               new Calib(f1.headerFits);
+            } catch( Exception e ) {
+               String hhh = Fits.getHHHName(input);
+               if( (new File(hhh).exists()) ) {
+                  context.setInputPath(hhh);
+                  context.info("Switch input file to "+hhh);
+               }
+            } 
+         }
+
       }
       if( context.isExistingAllskyDir(input) && context.hasPropertyFile(input) ) {
          throw new Exception("The input directory must be a image collection, not a HiPS => aborted");
@@ -143,6 +173,21 @@ public abstract class Builder {
       context.setValidateInput(true);
    }
    
+//   // dans le cas o ce n'est pas un fichier hhh, peut tre est-ce un fichier image avec un fichier hhh associ ?
+//   if( !rootPath.endsWith(".hhh") ) {
+//      try {
+//         Fits f = new Fits();
+//         f.loadHeaderFITS(rootPath, false);
+//         new Calib(f.headerFits);
+//
+//      }catch( Exception e ) {
+//         String hhh = Fits.getHHHName(rootPath);
+//         if( (new File(hhh).exists()) ) rootPath=hhh;
+//      } 
+//   }
+//   return rootPath;
+
+   
    
    static private String FS = cds.tools.Util.FS;
    
@@ -208,7 +253,8 @@ public abstract class Builder {
 
       File f = new File(output);
       if( f.exists() && (!f.isDirectory()  || !f.canRead())) throw new Exception("Ouput directory not available ["+output+"]");
-      context.info("the output directory is "+output);
+      
+      context.info("Output directory: "+output);
       
       
       context.setValidateOutput(true);
@@ -256,7 +302,7 @@ public abstract class Builder {
          String img = context.getImgEtalon();
          if( img==null && context.getInputPath()!=null) {
             img = context.justFindImgEtalon( context.getInputPath() );
-            if( img!=null ) context.info("Use this reference image => "+img);
+            if( img!=null ) context.info("Reference image => "+img);
          }
          if( img!=null ) {
             try { context.setImgEtalon(img); }
@@ -295,21 +341,21 @@ public abstract class Builder {
       double [] pixelGood = context.pixelGood;
       boolean missingGood = pixelGood!=null && context.good!=null;
 
-      boolean missingCut   = cut==null || cut[0]==0 && cut[1]==0;
-      boolean missingRange = cut==null || cut[2]==0 && cut[3]==0;
+      boolean missingCut   = !Context.hasCut(cut);
+      boolean missingRange = !Context.hasRange(cut);
 
       // S'il y a des pixelRange et/ou pixelCut indiqus sur la ligne de commande, il faut les convertir
-      // en cut[]  rcuprant le bzero et le bscale depuis le fichier Allsky.fits ou depuis une image talon
+      // en cut[]  rcuprant le bzero et le bscale depuis une tuile ou depuis une image talon
       double [] pixelRangeCut = context.getPixelRangeCut();
       if( (missingCut  || missingRange ) && pixelRangeCut!=null || missingGood ) {
          try {
-            setBzeroBscaleFromPreviousAllsky(context.getOutputPath()+Util.FS+"Norder3"+Util.FS+"Allsky.fits");
+            setBzeroBscaleFromPreviousAllsky( context.findOneNpixFile(context.getOutputPath(), "fits"));
          } catch( Exception e ) {
 
             String img = context.getImgEtalon();
             if( img==null && context.getInputPath()!=null) {
                img = context.justFindImgEtalon( context.getInputPath() );
-               if( img!=null ) context.info("Use this reference image => "+img);
+               if( img!=null ) context.info("Reference image => "+img);
             }
             if( img!=null ) {
                try { context.setImgEtalon(img); }
@@ -318,7 +364,7 @@ public abstract class Builder {
          }
 
          try {
-            if( cut==null ) cut = new double[5];
+            if( cut==null ) cut = new double[7];
             for( int i=0; i<4; i++ ) {
                if( Double.isNaN(pixelRangeCut[i]) ) continue;
                cut[i] = (pixelRangeCut[i] - context.bzero)/context.bscale;
@@ -339,12 +385,12 @@ public abstract class Builder {
 
       // S'il me manque le cut du pixelCut ou du pixelRange, il faut que je rcupre une image talon
       // que j'en dduise les cutOrig, bzeroOrig, bscaleOrig, puis que j'en calcule le bzero, bscale et donc les cut
-      missingCut   = cut==null || cut[0]==0 && cut[1]==0;
+      missingCut   = !Context.hasCut(cut);
       if( missingCut ) {
          String img = context.getImgEtalon();
          if( img==null && context.getInputPath()!=null) {
             img = context.justFindImgEtalon( context.getInputPath() );
-            if( img!=null ) context.info("Use this reference image => "+img);
+            if( img!=null ) context.info("Reference image => "+img);
          }
          if( img!=null ) {
             try { context.setImgEtalon(img); }
@@ -354,25 +400,31 @@ public abstract class Builder {
          context.initParameters();
 
          double [] imgCut = context.getCut();
-         if( cut==null ) cut = new double[5];
+         if( cut==null ) cut = new double[7];
          if( missingCut )   {
-            cut[0]= imgCut[0];
-            cut[1]= imgCut[1];
-            if( cut[0]!=cut[1] ) context.info("Estimating pixel cut from the reference image => ["+cut[0]+" .. "+cut[1]+"]");
+            cut[Context.CUTMIN]= imgCut[Context.CUTMIN];
+            cut[Context.CUTMAX]= imgCut[Context.CUTMAX];
+            if( cut[Context.CUTMIN]!=cut[Context.CUTMAX] ) context.info("Estimating pixel cut from the reference image => ["
+                     +cut[Context.CUTMIN]+" .. "+cut[Context.CUTMAX]+"]");
          }
       }
 
       // S'il me manque toujours le pixelCut, je vais tenter de les rcuprer par le fichier des properties
-      missingCut   = cut==null || cut[0]==0 && cut[1]==0;
+      missingCut   = !Context.hasCut(cut);
       if( missingCut ) updateCutByProperties(cut);
 
       context.setCut(cut);
 
       double bz=context.bzero;
       double bs=context.bscale;
-      if( cut==null || cut[0]==0 && cut[1]==0 ) throw new Exception("Argument \"pixelCut\" required");
-      if( !( cut[0] < cut[1] ) ) throw new Exception("pixelCut error ["+ip(cut[0],bz,bs)+" .. "+ip(cut[1],bz,bs)+"]");
-      context.info("pixel cut ["+ip(cut[0],bz,bs)+" .. "+ip(cut[1],bz,bs)+"]");
+      if( !context.cutByRegion ) {
+         if( cut==null || cut[Context.CUTMIN]==0 && cut[Context.CUTMAX]==0 ) throw new Exception("Argument \"pixelCut\" required");
+         if( !( cut[Context.CUTMIN] < cut[Context.CUTMAX] ) ) 
+            throw new Exception("pixelCut error ["+ip(cut[Context.CUTMIN],bz,bs)+" .. "+ip(cut[Context.CUTMAX],bz,bs)+"]");
+         context.info("pixel cut ["+ip(cut[Context.CUTMIN],bz,bs)+" .. "+ip(cut[Context.CUTMAX],bz,bs)+"]");
+      } else {
+         context.info("pixel cut by regions");
+      }
       context.setValidateCut(true);
    }
 
@@ -394,8 +446,9 @@ public abstract class Builder {
 
             // Il me faut alors BZERO  et BSCALE
             try {
-               setBzeroBscaleFromPreviousAllsky(context.getOutputPath()+Util.FS+"Norder3"+Util.FS+"Allsky.fits");
-               if( cut==null ) cut = new double[5];
+//               setBzeroBscaleFromPreviousAllsky(context.getOutputPath()+Util.FS+"Norder3"+Util.FS+"Allsky.fits");
+               setBzeroBscaleFromPreviousAllsky( context.findOneNpixFile(context.getOutputPath(), "fits") );
+               if( cut==null ) cut = new double[7];
                for( int i=0; i<4; i++ ) {
                   if( Double.isNaN(pixelRangeCut[i]) ) continue;
                   cut[i] = (pixelRangeCut[i] - context.bzero)/context.bscale;
@@ -406,18 +459,18 @@ public abstract class Builder {
       } catch( Exception e ) {}
    }
 
-
    protected void validateBitpix() {
       if( context.bitpix!=-1 ) return;
       try {
-         setBzeroBscaleFromPreviousAllsky(context.getOutputPath()+Util.FS+"Norder3"+Util.FS+"Allsky.fits");
+//         setBzeroBscaleFromPreviousAllsky(context.getOutputPath()+Util.FS+"Norder3"+Util.FS+"Allsky.fits");
+         setBzeroBscaleFromPreviousAllsky( context.findOneNpixFile(context.getOutputPath(), "fits") );
       } catch( Exception e ) { }
    }
 
    protected void validateLabel() {
-      if( context.label!=null ) return;
+      if( context.title!=null ) return;
       String label = getALabel(context.getOutputPath(),context.getInputPath());
-      if( label!=null && label.length()>0 ) context.label=label;
+      if( label!=null && label.length()>0 ) context.title=label;
    }
 
    protected String getALabel(String outputPath,String inputPath) {
@@ -433,15 +486,9 @@ public abstract class Builder {
             prop.load(in);
             in.close();
             
-            String s =  MultiMoc.getID(prop);
-            s=context.getLabelFromHipsId(s);
-            if( s==null ) {
-               s = prop.getProperty(Constante.KEY_OBS_TITLE);
-            }
-//            String s = prop.getProperty(Constante.KEY_OBS_COLLECTION);
-            if( s==null ) {
-               s = prop.getProperty(Constante.OLD_OBS_COLLECTION);
-            }
+            String s=prop.getProperty(Constante.KEY_OBS_TITLE);
+            if( s==null ) s=prop.getProperty(Constante.OLD_OBS_COLLECTION);
+            if( s==null ) s=context.getLabelFromHipsId( MultiMoc.getID(prop) );
             if( s!=null && s.length()>0 ) label=s;
          }
       } catch( Exception e ) { }
@@ -487,10 +534,10 @@ public abstract class Builder {
    /**
     * Initialisation des paramtres FITS  partir d'un Allsky.fits prcdent
     */
-   protected void setFitsParamFromPreviousAllsky(String allskyFile) throws Exception {
+   protected void setFitsParamFromPreviousAllsky(String aFitsTile) throws Exception {
       Fits f = new Fits();
 
-      f.loadFITS(allskyFile);
+      f.loadFITS(aFitsTile);
       double [] cut = f.findAutocutRange(0,0,true);
 
       context.setBitpix(f.bitpix);
@@ -510,9 +557,9 @@ public abstract class Builder {
 
    }
 
-   protected void setBzeroBscaleFromPreviousAllsky(String allskyFile) throws Exception {
+   protected void setBzeroBscaleFromPreviousAllsky(String aFitsTile) throws Exception {
       Fits f = new Fits();
-      f.loadHeaderFITS(allskyFile);
+      f.loadHeaderFITS(aFitsTile);
       try {
          double bzero = f.headerFits.getDoubleFromHeader("BZERO");
          context.bzero=bzero;
@@ -532,6 +579,15 @@ public abstract class Builder {
       }
    }
    
+   protected void setTileWidthFromPreviousAllsky(String aFitsTile) throws Exception {
+      Fits f = new Fits();
+      f.loadHeaderFITS(aFitsTile);
+      try {
+         int tileWidth = f.headerFits.getIntFromHeader("NAXIS1");
+         context.setTileOrder( (int)CDSHealpix.log2(tileWidth));
+      } catch( Exception e ) { }
+   }     
+   
    
    // Gestion des paramtres pour le stockage dans une partition alternative
    private class Part {
@@ -599,7 +655,7 @@ public abstract class Builder {
          return;   // tout tient dans la premire partition
       }
       for( int n=0; tok.hasMoreTokens(); n++ ) {
-         if( n==MAXPART ) throw new Exception("Too many slitting partitions");
+         if( n==MAXPART ) throw new Exception("Too many splitting partitions");
          part[n] = new Part();
          String s1 = tok.nextToken();
          int i = s1.lastIndexOf(' ');
@@ -671,5 +727,80 @@ public abstract class Builder {
    }
    
 
+   /**
+    * Sauvegarde des poids des pixels d'une tuile sous la forme d'une FITS
+    * La nomenclature suit la mme que pour les tuiles classiques, avec le suffixe "_w"
+    * @param file    Le nom de fichier (sans le suffixe "_w" ni l'extension ".fits)
+    * @param weight  La matrice des poids
+    * @param w       La largeur de la tuile
+    * @throws Exception
+    */
+   public void writeWeight(String file, double [] weight, int w,int order,long npix) throws Exception {
+      if( weight==null ) return;
+      Fits fits = new Fits(w,w,-32);
+      context.updateHeader(fits,order,npix);
+      int i=0;
+      for( int y=0; y<fits.height; y++ ) {
+         for( int x=0; x<fits.width; x++ ) {
+            fits.setPixelDouble(x,y,weight[i++]);
+         }
+      }
+      fits.addDataSum();
+      fits.writeFITS(file+"_w.fits");
+   }
+
+   /**
+    *  Chargement des poids des pixels d'une tuile sous la forme d'une FITS
+    * La nomenclature suit la mme que pour les tuiles classiques, avec le suffixe "_w"
+    * @param file    Le nom de fichier (sans le suffixe "_w" ni l'extension ".fits)
+    * @return        La matrice des poids - remplie de la valeur par dfaut si le fichier n'existe pas
+    * @throws Exception
+    */
+   public double [] loadWeight(String file,int w,double defaultWeight) throws Exception {
+      double [] weight = new double[ w *w ];
+      String filename = file+"_w.fits";
+      if( !(new File(filename)).exists() ) {
+         for( int i=0; i<weight.length; i++ ) weight[i]=defaultWeight;
+         return weight;
+      }
+      
+      Fits fits = new Fits();
+      fits.loadFITS(filename);
+      int i=0;
+      for( int y=0; y<fits.height; y++ ) {
+         for( int x=0; x<fits.width; x++ ) {
+            weight[i++] = fits.getPixelDouble(x,y);
+         }
+      }
+      return weight;
+   }
+
+   /** Charge une valeur d'un mot cl d'un fichier de properties pour un rpertoire particulier, null sinon */
+   protected String loadProperty(String path,String key) throws Exception {
+      MyProperties prop = loadProperties(path);
+      if( prop==null ) return null;
+      return prop.getProperty(key);
+   }
    
+   /** Charge les proprits d'un fichier properties, retourne null si problme */
+   protected MyProperties loadProperties(String path) {
+      InputStreamReader in = null;
+      try {
+         String propFile = path+Util.FS+Constante.FILE_PROPERTIES;
+         MyProperties prop = new MyProperties();
+         File f = new File( propFile );
+         if( f.exists() ) {
+            in = new InputStreamReader( new BufferedInputStream( new FileInputStream(propFile) ), "UTF-8");
+            prop.load(in);
+            in.close();
+            in=null;
+            return prop;
+         }
+      } 
+      catch( Exception e ) {}
+      finally { if( in!=null ) try { in.close(); } catch( Exception e ) {} }
+      return null;
+   }
+   
+
 }
