@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -30,6 +30,8 @@ public class BuilderCleanAll extends BuilderClean {
    
    public BuilderCleanAll(Context context) { super(context); }
    
-   public boolean mustBeDeleted(File f) { return true; }
+   public void resetCheckCode() { context.resetCheckCode(); };
+   
+   public boolean mustBeDeleted(File f) { return true; }   
 
 }
