@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -39,5 +39,7 @@ public class BuilderCleanPng extends BuilderCleanFits {
       if( !name.startsWith("Npix") ) return false;
       return true;
    }
+   
+   public void resetCheckCode() { context.resetCheckCode("png"); };
 
 }
