@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -32,7 +32,6 @@ import cds.aladin.Localisation;
 import cds.aladin.MyInputStream;
 import cds.aladin.MyProperties;
 import cds.fits.Fits;
-import cds.moc.Array;
 import cds.moc.SMoc;
 import cds.mocmulti.MultiMoc;
 import cds.tools.Util;
@@ -41,17 +40,22 @@ import cds.tools.pixtools.CDSHealpix;
 /**
  * Vrification de la conformit IVOA 1.0 HiPS
  * @author Pierre Fernique [CDS]
+ * @version 1.2 - 15 novembre 2021 - getProperties()
  * @version 1.1 - 23 avril 2019 - ajustement pour les Norder0  2
  * @version 1.0 - 23 avril 2017
  */
 public class BuilderLint extends Builder {
    
-   public static int TIMEOUT = 20000;   // timeout de 20s sur les connections rseaux
+   public static int TIMEOUT = 60000;   // timeout de 20s sur les connections rseaux
    
    private String path;         // path (ou prfixe URL) du HiPS  valider
    private boolean flagRemote;  // true s'il s'agit d'un HiPS distant
    private String FS;           // "\" ou "/" suivant le cas
    
+   
+   // Les proprits (charge par lintProperties)
+   private MyProperties prop=null;
+   
    // Informations  rcuprer depuis le fichier properties
    private String id;           // Identificateur du HiPS
    private boolean flagImage;   // true pour un HiPS image
@@ -138,12 +142,20 @@ public class BuilderLint extends Builder {
    
    public void validateContext() throws Exception { }
    
-   public void run() throws Exception {
-      lint();
+   public void run() throws Exception { lint( ); }
+   
+   /**
+    * Provide the MyProperties objects used for lint check
+    * @throws Exception
+    */
+   protected MyProperties getProperties() throws Exception {
+      if( prop==null ) throw new Exception("Properties not loaded yet. Use lin() before !");
+      return prop;
    }
    
    /**
     * Check IVOA HiPS 1.0 compatibility
+    * @param flagDeep true pour test profond (test random des tuiles)
     * @return 1 ok, -1 ok but with warning, 0 uncompatible
     * @throws Exception
     */
@@ -184,7 +196,7 @@ public class BuilderLint extends Builder {
       lintMoc();
       
       // Test sur une tuile au hasard
-      lintTile( 3 );
+      if( context.hipslintTileTest ) lintTile( 3 );
       
       // Test allsky
       lintAllsky();
@@ -195,8 +207,8 @@ public class BuilderLint extends Builder {
       // Test des autres fichiers optionels
       lintMiscFiles();
       
-      if( flagError ) context.error("*** HiPS "+id+" is not IVOA HiPS 1.0 compatible");
-      else if( flagWarning ) context.warning("!!! HiPS "+id+" is IVOA HiPS 1.0 compatible but with warnings");
+      if( flagError ) context.info("*** HiPS "+id+" is not IVOA HiPS 1.0 compatible");
+      else if( flagWarning ) context.info("!!! HiPS "+id+" is IVOA HiPS 1.0 compatible but with warnings");
       else context.info("HiPS "+id+" is fully IVOA HiPS 1.0 compatible");
       
       return flagError ? 0 : flagWarning ? -1 : 1;
@@ -207,8 +219,9 @@ public class BuilderLint extends Builder {
       boolean flagError=false,flagWarning=false;
       
       String f = path+FS+"metadata.xml";
+      MyInputStream in=null;
       try {
-         MyInputStream in = Util.openAnyStream( f,false,false,TIMEOUT );
+         in = Util.openAnyStream( f,false,false,TIMEOUT );
          long type=in.getType();
          if( (type&MyInputStream.VOTABLE)==0 ) {
             context.error("Lint[4.4.3] \"metadata.xml\" format error (expecting \"votable\", found ["+MyInputStream.decodeType(type)+"])");
@@ -218,6 +231,8 @@ public class BuilderLint extends Builder {
       } catch( Exception e) {
          context.error("Lint[4.4.3] \"metadata.xml\" is missing");
          flagError=true;
+      } finally {
+         if( in!=null ) try { in.close(); } catch( Exception e ) {}
       }
       
       if( !flagError ) context.info("Lint: \"metadata.xml\" ok");
@@ -230,53 +245,62 @@ public class BuilderLint extends Builder {
       
       // preview.jpg
       String f = path+FS+"preview.jpg";
+      MyInputStream in=null;
       try {
-         MyInputStream in = Util.openAnyStream( f,false,false,TIMEOUT );
-         long type=in.getType();
-         if( type!=MyInputStream.JPEG ) {
-            context.error("Lint[4.4.4] \"preview.jpg\" format error (expecting \"jpeg\", found ["+MyInputStream.decodeType(type)+"])");
-            flagError=true;
+         try {
+            in = Util.openAnyStream( f,false,false,TIMEOUT );
+            long type=in.getType();
+            if( type!=MyInputStream.JPEG ) {
+               context.error("Lint[4.4.4] \"preview.jpg\" format error (expecting \"jpeg\", found ["+MyInputStream.decodeType(type)+"])");
+               flagError=true;
+            }
+            in.close();
+            in=null;
+         } catch( Exception e) {
+            context.info("Lint[4.4.4] no \"preview.jpg\" file");
          }
-         in.close();
-      } catch( Exception e) {
-         context.info("Lint[4.4.4] no \"preview.jpg\" file");
-      }
-      
-      // index.html
-      f = path+FS+"index.html";
-      try {
-         MyInputStream in = Util.openAnyStream( f,false,false,TIMEOUT );
-         in.close();
-      } catch( Exception e) {
-         context.info("Lint[4.4.5] no \"index.html\" file");
+
+         // index.html
+         f = path+FS+"index.html";
+         try {
+            in = Util.openAnyStream( f,false,false,TIMEOUT );
+            in.close();
+            in=null;
+         } catch( Exception e) {
+            context.info("Lint[4.4.5] no \"index.html\" file");
+         }
+      } finally {
+         if( in!=null ) try { in.close(); } catch( Exception e ) {}
       }
    }
    
    /** Test des allsky */
    private void lintAllsky( ) throws Exception {
-      for( String ext : extensions ) {
-         boolean found=false;
-         for( int o=0; o<=3; o++ ) {
-            String suffix = "Norder"+o+FS+"Allsky"+ext;
-            String f = path+FS+suffix;
-            try {
-               MyInputStream in = Util.openAnyStream(f,false,false,TIMEOUT);
-               long type = in.getType();
-               if(   ext.equals(".jpg") && type!=MyInputStream.JPEG
-                     ||  ext.equals(".png") && type!=MyInputStream.PNG
-                     ||  ext.equals(".fits") && (type&MyInputStream.FITS)!=MyInputStream.FITS
-                     ||  ext.equals(".tsv") && (type&MyInputStream.CSV)!=MyInputStream.CSV
-                     ) {
-                  context.error("Lint[4.2.1.3] Allsky format error (expecting \""+ext+"\", found ["+MyInputStream.decodeType(type)+"])");
-                  flagError=true;
-               }
-               
-               if( ext.equals(".fits") &&  (type&MyInputStream.GZ)!=0 ) {
-                  context.warning("Lint[4.2.1.3] Allsky.fits gzipped (deprecated method)");
-               }
-
-               Fits fits = null;
+      MyInputStream in=null;
+      try {
+         for( String ext : extensions ) {
+            boolean found=false;
+            for( int o=0; o<=3; o++ ) {
+               String suffix = "Norder"+o+FS+"Allsky"+ext;
+               String f = path+FS+suffix;
                try {
+                  if( in!=null ) try { in.close(); } catch( Exception e ) {}
+                  in = Util.openAnyStream(f,false,false,TIMEOUT);
+                  long type = in.getType();
+                  if(   ext.equals(".jpg") && type!=MyInputStream.JPEG
+                        ||  ext.equals(".png") && type!=MyInputStream.PNG
+                        ||  ext.equals(".fits") && (type&MyInputStream.FITS)!=MyInputStream.FITS
+                        ||  ext.equals(".tsv") && (type&MyInputStream.CSV)!=MyInputStream.CSV
+                        ) {
+                     context.error("Lint[4.2.1.3] Allsky format error (expecting \""+ext+"\", found ["+MyInputStream.decodeType(type)+"])");
+                     flagError=true;
+                  }
+
+                  if( ext.equals(".fits") &&  (type&MyInputStream.GZ)!=0 ) {
+                     context.warning("Lint[4.2.1.3] Allsky.fits gzipped (deprecated method)");
+                  }
+
+                  Fits fits = null;
                   if( !flagRemote ) {
                      if( ext.equals(".fits") ) {
                         fits = new Fits();
@@ -288,48 +312,47 @@ public class BuilderLint extends Builder {
                   }
                   context.info("Lint: Allsky found ["+suffix+"] ok");
                   found=true;
-               }finally { in.close(); in=null; }
-            } catch( Exception e ) { }
-         }
-         if( !found ) {
-            context.info("Lint[4.3.2] Allsky not found (order 0 to 3)");
+               } catch( Exception e ) { }
+            }
+            if( !found ) {
+               context.info("Lint[4.3.2] Allsky not found (order 0 to 3)");
+            }
          }
+         if( in!=null ) in.close();
+         in=null;
+      } finally {
+         if( in!=null ) try { in.close(); } catch( Exception e ) {}
       }
+
    }
 
    /** Retourne au hasard un indice HEALPix se situant dans le HiPS  la profondeur max */
    private long getOneNpix() throws Exception {
-      
+
       // Mthode 1: On prend au hasard une cellule du MOC de couverture
-      // On va partir des tuiles les plus grandes du Moc pour tre sr qu'on ne va pas
-      // tester sur un bord.
-      if( moc!=null && moc.getSize()!=0 ) {
-         
-         int orderMoc = moc.getMinOrder();
-         int orderMax = moc.getMaxUsedOrder();
-         while( orderMoc<orderMax && moc.getArray( orderMoc ).getSize()<3 ) orderMoc++;
-         Array a = moc.getArray( orderMoc );
-         if( a==null || a.getSize()==0) return -1;
-         int nb = a.getSize();
+      if( moc!=null && !moc.isEmpty() ) {
+
+         // On prend l'lment central d'un intervalle au hasard
+         int nb = moc.getNbRanges();
          int i = (int)( Math.random()*nb);
-         if( i>=nb ) i=nb-1;
-         long npix = a.get( i );
-         
+         long npix = (moc.seeRangeList().begins(i)+ (moc.seeRangeList().ends(i)-1))/2L;
+
          // On prend le npix central ramen  la rsolution du HiPS
+         int orderMoc = moc.getMocOrder();
          if( orderMoc<order ) {
             int shift = (order - orderMoc)*2;
             long npix1 = npix<<shift ;
             long npix2 = (npix+1)<<shift;
             npix = (npix1+npix2)/2;
-            
-         // On prend la tuile qui le contient
+
+            // On prend la tuile qui le contient
          } else if( orderMoc>order ) {
             int shift = (orderMoc - order)*2;
             npix = npix>>shift;
          }
-         
+
          // Attention, le Hips et le MOC n'ont pas le mme systme de coord
-         int frameMoc = context.getFrameVal( moc.getSys() );
+         int frameMoc = context.getFrameVal( moc.getSpaceSys() );
          if( frame!=frameMoc ) {
             double radec[] = CDSHealpix.pix2ang_nest( order, npix);
             radec = CDSHealpix.polarToRadec(new double[] { radec[0], radec[1] });
@@ -338,7 +361,7 @@ public class BuilderLint extends Builder {
             radec = CDSHealpix.radecToPolar(new double[] {co.al, co.del});
             npix = CDSHealpix.ang2pix_nest(order, radec[0], radec[1]);
          }
-         
+
          return npix;
       }
 
@@ -370,54 +393,56 @@ public class BuilderLint extends Builder {
       int lowOrder=-1;
       HashSet<String> dejaTeste = new HashSet<>();  // pour viter de tester 2x la mme tuile
 
-      for( int j=0; j<n; j++ ) {
-         long npix1 = getOneNpix();
-         if( npix1==-1 ) {
-            context.info("Lint: tile test cancelled");
-            return;
-         }
-         
-         // Dans le cas d'un cube, on teste aussi d'autres frames que 0
-         int z=0;
-         if( j>0 ) {
-            z = (int)(Math.random()*depth);
-            if( z>=depth ) z=depth-1;
-         }
+      MyInputStream in = null;
+      try {
+         for( int j=0; j<n; j++ ) {
+            long npix1 = getOneNpix();
+            if( npix1==-1 ) {
+               context.info("Lint: tile test cancelled");
+               return;
+            }
 
-         for( String ext : extensions ) {
-            boolean found=false;
-            long npix = npix1;
-            String first=null,last=null;
-            lowOrder=-1;
+            // Dans le cas d'un cube, on teste aussi d'autres frames que 0
+            int z=0;
+            if( j>0 ) {
+               z = (int)(Math.random()*depth);
+               if( z>=depth ) z=depth-1;
+            }
+
+            for( String ext : extensions ) {
+               boolean found=false;
+               long npix = npix1;
+               String first=null,last=null;
+               lowOrder=-1;
                for( int o=order; o>=0; o--, npix/=4L) {
-               String suffix = getFilePath(o, npix, z, FS)+ext;
-               String f = path+FS+suffix;
-               if( lowOrder==-1 || o<lowOrder ) first=suffix;
-//               System.out.println("Loading "+f+"...");
-               
-               if( dejaTeste.contains(f) ) {
-                  // Conserve le plus petit ordre trouv
-                  if( lowOrder==-1 || o<lowOrder ) lowOrder=o; 
-               } else {
-                  dejaTeste.add(f);
-                  try {
-                     MyInputStream in = Util.openAnyStream(f,false,false,TIMEOUT);
-                     long type = in.getType();
-                     if(   ext.equals(".jpg") && type!=MyInputStream.JPEG
-                           ||  ext.equals(".png") && type!=MyInputStream.PNG
-                           ||  ext.equals(".fits") && (type&MyInputStream.FITS)!=MyInputStream.FITS
-                           ||  ext.equals(".tsv") && (type&MyInputStream.CSV)!=MyInputStream.CSV
-                           ) {
-                        context.error("Lint[4.2.1.3] tile format error (expecting \""+ext+"\", found ["+MyInputStream.decodeType(type)+"])");
-                        flagError=true;
-                     }
-                     if( ext.equals(".fits") &&  (type&MyInputStream.GZ)!=0 ) {
-                        context.warning("Lint[4.2.1.3] fits tile gzipped (deprecated method) ["+suffix+"]");
-                     }
+                  String suffix = getFilePath(o, npix, z, FS)+ext;
+                  String f = path+FS+suffix;
+                  if( lowOrder==-1 || o<lowOrder ) first=suffix;
+                  //               System.out.println("Loading "+f+"...");
 
-                     // On ne lit plus le contenu  distance, c'est trop long
-                     Fits fits = null;
+                  if( dejaTeste.contains(f) ) {
+                     // Conserve le plus petit ordre trouv
+                     if( lowOrder==-1 || o<lowOrder ) lowOrder=o; 
+                  } else {
+                     dejaTeste.add(f);
                      try {
+                        if( in!=null ) try { in.close(); } catch( Exception e ) {}
+                        in = Util.openAnyStream(f,false,false,TIMEOUT);
+                        long type = in.getType();
+                        if(   ext.equals(".jpg") && type!=MyInputStream.JPEG
+                              ||  ext.equals(".png") && type!=MyInputStream.PNG
+                              ||  ext.equals(".fits") && (type&MyInputStream.FITS)!=MyInputStream.FITS
+                              ||  ext.equals(".tsv") && (type&MyInputStream.CSV)!=MyInputStream.CSV
+                              ) {
+                           context.error("Lint[4.2.1.3] tile format error (expecting \""+ext+"\", found ["+MyInputStream.decodeType(type)+"])");
+                           flagError=true;
+                        }
+                        if( ext.equals(".fits") &&  (type&MyInputStream.GZ)!=0 ) {
+                           context.warning("Lint[4.2.1.3] fits tile gzipped (deprecated method) ["+suffix+"]");
+                        }
+
+                        // On ne lit plus le contenu  distance, c'est trop long
+                        Fits fits = null;
                         if( !flagRemote ) {
                            if( ext.equals(".fits") ) {
                               fits = new Fits();
@@ -427,67 +452,71 @@ public class BuilderLint extends Builder {
                               fits.loadPreview(in);
                            }
                         }
-                        
+
                         found=true;
                         if( last==null ) last=suffix;
-                     } finally { in.close(); in=null;}
 
-                     // Conserve le plus petit ordre trouv
-                     if( lowOrder==-1 || o<lowOrder ) lowOrder=o;
+                        // Conserve le plus petit ordre trouv
+                        if( lowOrder==-1 || o<lowOrder ) lowOrder=o;
 
-                     boolean ok=true;
-                     if( fits!=null ) {
-                        if( fits.width != fits.height ) {
-                           context.error("Lint[4.2.1] not square tile ["+fits.width+"x"+fits.height+"]");
-                           flagError=true;
-                        }
-                        double o1 = Math.log10(fits.width)/Math.log10(2);
-                        if( o1!=(long)o1 ) {
-                           context.error("Lint[4.2.1] tile width error ["+fits.width+"x"+fits.height+"]");
-                           ok=false;
-                        }
-                        if( tileWidth!=-1 && tileWidth!=fits.width ) {
-                           context.error("Lint[4.2.1] tile width not conform to hips_tile_width ["+fits.width+"!="+tileWidth+"]");
-                           ok=false;
-                        }
-                        if( ext.equals(".fits") ) {
-                           if( bitpix!=-1 && bitpix!=fits.bitpix ) {
-                              context.error("Lint[4.2.1] tile bitpix not conform to hips_pixel_bitpix ["+fits.bitpix+"!="+bitpix+"]");
+                        boolean ok=true;
+                        if( fits!=null ) {
+                           if( fits.width != fits.height ) {
+                              context.error("Lint[4.2.1] not square tile ["+fits.width+"x"+fits.height+"]");
+                              flagError=true;
+                           }
+                           double o1 = Math.log10(fits.width)/Math.log10(2);
+                           if( o1!=(long)o1 ) {
+                              context.error("Lint[4.2.1] tile width error ["+fits.width+"x"+fits.height+"]");
                               ok=false;
                            }
+                           if( tileWidth!=-1 && tileWidth!=fits.width ) {
+                              context.error("Lint[4.2.1] tile width not conform to hips_tile_width ["+fits.width+"!="+tileWidth+"]");
+                              ok=false;
+                           }
+                           if( ext.equals(".fits") ) {
+                              if( bitpix!=-1 && bitpix!=fits.bitpix ) {
+                                 context.error("Lint[4.2.1] tile bitpix not conform to hips_pixel_bitpix ["+fits.bitpix+"!="+bitpix+"]");
+                                 ok=false;
+                              }
+                           }
                         }
-                     }
-                     if( !ok ) flagError=true;
-                     //                  else context.info("Lint: tile test on ["+suffix+"] ok");
-                     
-//                     System.out.println("  "+f+" achieved");
+                        if( !ok ) flagError=true;
+                        //                  else context.info("Lint: tile test on ["+suffix+"] ok");
 
-                  } catch( Exception e1 ) {
-                     if( found) {
-                        String s1 = e1.getMessage()!=null ? " ("+e1.getMessage()+")":"";
-                        if( flagMinOrderSet && o>=minOrder ) {
-                           context.error("Lint[4.1] tile missing ["+o+"/"+npix+" => "+f+"]"+s1);
-                           flagError=true;
+                        //                     System.out.println("  "+f+" achieved");
+
+                     } catch( Exception e1 ) {
+                        if( found) {
+                           String s1 = e1.getMessage()!=null ? " ("+e1.getMessage()+")":"";
+                           if( flagMinOrderSet && o>=minOrder ) {
+                              context.error("Lint[4.1] tile missing ["+o+"/"+npix+" => "+f+"]"+s1);
+                              flagError=true;
+                           }
                         }
                      }
                   }
                }
-            }
-         
-            if( !found ) {
-               if( flagMinOrderSet && lowOrder>minOrder ) {
-                  context.error("Lint[4.1] tile hierarchy missing ["+first+" ... "+last+"] claiming to start at order "+minOrder);
-                  flagError=true;
+
+               if( !found ) {
+                  if( flagMinOrderSet && lowOrder>minOrder ) {
+                     context.error("Lint[4.1] tile hierarchy missing ["+first+" ... "+last+"] claiming to start at order "+minOrder);
+                     flagError=true;
+                  }
+               } else if( found ) {
+                  context.info("Lint: tile test hierarchy ["+first+" ... "+last+"] ok");
                }
-            } else if( found ) {
-               context.info("Lint: tile test hierarchy ["+first+" ... "+last+"] ok");
             }
+
+            // Si erreur on ne va pas faire un autre test
+            if( flagError ) n=j;
+            if( in!=null ) in.close();
+            in=null;
          }
-         
-         // Si erreur on ne va pas faire un autre test
-         if( flagError ) n=j;
+      } finally {
+         if( in!=null ) try { in.close(); } catch( Exception e ) {}
       }
-      
+
 //    if( !flagError ) context.info("Lint: tile tests & tile hierarchy tests ok");
       if( flagMinOrderSet && lowOrder!=-1 && lowOrder!=minOrder ) context.error("Lint[4.1] min order found in the tile hierarchy ["+lowOrder+"] not conform [hips_min_order="+minOrder+"]");
       else {
@@ -503,60 +532,68 @@ public class BuilderLint extends Builder {
    /** Vrification du MOC associ au HiPS */
    private void lintMoc( ) throws Exception {
       boolean flagError=false,flagWarning=false;
-     
+
       // Pas de MOC requis dans certains cas
       if( !flagICRS && skyFraction<1 && skyFraction>=0 ) return; 
-      
+
       MyInputStream in = null;
       try {
-         String f = path+FS+"Moc.fits";
-         in = Util.openAnyStream(f,false,false,TIMEOUT);
-      } catch( Exception e ) {
-         if( flagICRS ) {
-            context.warning("lint[4.4.2] \"Moc.fits\" file missing");
-            flagWarning=true;
-         } else {
-            context.warning("lint[4.4.2] no \"Moc.fits\" file");
+         try {
+            String f = path+FS+"Moc.fits";
+            in = Util.openAnyStream(f,false,false,TIMEOUT);
+         } catch( Exception e ) {
+            if( flagICRS ) {
+               context.warning("lint[4.4.2] \"Moc.fits\" file missing");
+               flagWarning=true;
+            } else {
+               context.warning("lint[4.4.2] no \"Moc.fits\" file");
+            }
          }
+
+         try {
+            moc = new SMoc();
+            moc.read(in);
+            in.close();
+            in=null;
+
+            String frame = moc.getSpaceSys();
+            if( !frame.equals("C") ) {
+               context.warning("Lint[4.4.2] \"Moc.fits\" coordinate system error, ICRS expecting, found ["+frame+"]");
+               flagWarning=true;
+            }
+         } catch( Exception e ) {
+            context.error("Lint[4.4.2] \"Moc.fits\" error");
+            flagError=true;
+         }
+      } finally {
+         if( in!=null ) try { in.close(); } catch( Exception e ) {}
       }
 
-      try {
-         moc = new SMoc();
-         moc.read(in);
-         in.close();
-         
-         String frame = moc.getSys();
-         if( !frame.equals("C") ) {
-            context.warning("Lint[4.4.2] \"Moc.fits\" coordinate system error, ICRS expecting, found ["+frame+"]");
-            flagWarning=true;
-         }
-      } catch( Exception e ) {
-         context.error("Lint[4.4.2] \"Moc.fits\" error");
-         flagError=true;
-      }
-      
       if( !flagError ) context.info("Lint: \"Moc.fits\" ok");
       this.flagError|=flagError;
       this.flagWarning|=flagWarning;
-}
-   
+   }
+
    /** Vrification du fichier properties */
    private void lintProperties( ) throws Exception {
       boolean flagError=false,flagWarning=false;
       int i;
       String s;
-      MyProperties prop=null;
+      MyInputStream in=null;
       try {
          String f = path+FS+"properties";
-         MyInputStream in = Util.openAnyStream(f,false,false,TIMEOUT);
+         in = Util.openAnyStream(f,false,false,TIMEOUT);
          InputStreamReader isr = new InputStreamReader( in, "UTF-8" );
          prop = new MyProperties();
          prop.load( isr );
-         isr.close();
+         in.close();
+         in=null;
       } catch( Exception e1 ) {
          context.error("Lint[4.4] \"properties\" file missing");
          flagError=true;
          return;
+      } finally {
+         if( in!=null ) try { in.close(); } catch( Exception e ) { }
       }
 
       boolean [] propReq    = new boolean[ PROP_REQ.length ];
@@ -845,6 +882,17 @@ public class BuilderLint extends Builder {
          }
       }  
       
+      // Vrification du hips_service_url et de sa cohrence avec celui 
+      if( path.startsWith("http") ) {
+         s = prop.get("hips_service_url");
+         if( s!=null ) {
+            if( !s.equals(path) ) {
+               context.error("Lint[4.2.1] hips_service_url error ["+s+"] => not coherent with HiPSlist definition");
+               flagError=true;
+            }
+         }  
+      }
+      
       // Vrification du hips_frame
       s = prop.get("hips_frame");
       if( s!=null ) {
@@ -926,7 +974,7 @@ public class BuilderLint extends Builder {
       return -1;
    }
 
-   // Example: 2016-05-09[T10:39[:00]][Z]
+   // Example: 2016-05-09[T10:39[:00.01]][Z]
    static public boolean checkDate(String s) {
       int mode=0;
       
@@ -951,11 +999,14 @@ public class BuilderLint extends Builder {
             case 4: if( ch==':' ) mode=5;
                     else if( !Character.isDigit(ch) ) return false;
                     break;
-            case 5: if( !Character.isDigit(ch) ) return false;
+            case 5: if( ch=='.' || ch==',' ) mode=6;
+                    else if( !Character.isDigit(ch) ) return false;
+                    break;
+            case 6: if( !Character.isDigit(ch) ) return false;
                     break;
          }
       }
-      return mode==2 || mode==4 || mode==5;
+      return mode==2 || mode==4 || mode==5 || mode==6;
    }
    
    // Retourne un mot cl HiPS sans son ventuel suffixe numrique "_nn"
