@@ -46,7 +46,7 @@ import cds.tools.Util;
  * @version 1.0 juin 2015 cration
  * @version 1.1 fvrier 2019 gestion du multi-partition (paramtre split=...)
  */
-public class BuilderMirror extends BuilderTiles {
+public class BuilderMirror extends BuilderRunner {
    
    static private final int TIMEOUT = 15000;    // 15 sec sans nouvelle on rinitialise la connection HTTP
    static private String USERAGENT = "Hipsgen (mirror) Aladin/"+Aladin.VERSION.substring(1);
@@ -60,8 +60,9 @@ public class BuilderMirror extends BuilderTiles {
    private String dateRelease="";       // Date of last release date of the local copy
    private boolean isLocal=false;       // true s'il s'agit d'une copie locale
    private long timeIP;
-   private boolean check=false;         // true si on redmarre une session => pas de test de taille sur les tuiles dj arrives
+   private boolean fastCheck=false;         // true si on redmarre une session => pas de test de taille sur les tuiles dj arrives
    boolean flagCat=false;               // true s'il s'agit d'un HiPS catalogue
+   private String checkCode=null;       // Le checkcode du HiPS distant, ou null si inconnue
 
    public BuilderMirror(Context context) {
       super(context);
@@ -74,10 +75,10 @@ public class BuilderMirror extends BuilderTiles {
       
       // Dtermination d'une ventuelle copie locale
       String dir = context.getInputPath();
-      check = context.getMirrorCheck();
+      fastCheck = context.getFastCheck();
       isLocal = !dir.startsWith("http://") && !dir.startsWith("https://") && !dir.startsWith("ftp://");
       if( isLocal ) context.info("Local mirror copy");
-      if( !isLocal && check ) context.info("Will check all date and size for already loaded tiles");
+      if( !isLocal && fastCheck ) context.info("Will check all date and size for already loaded tiles");
 
       // Chargement des proprits distantes
       prop = new MyProperties();
@@ -92,6 +93,9 @@ public class BuilderMirror extends BuilderTiles {
       // On valide le rpertoire de destination
       validateOutput();
       
+      // Mmorisation des checkcodes afin de pouvoir les comparer  la fin de la copie
+      checkCode = prop.getProperty("hips_check_code");
+      
       // Dtermination du statut
       String s = prop.getProperty(Constante.KEY_HIPS_STATUS);
       if( s!=null && context.testClonable && s.indexOf("unclonable")>=0 ) {
@@ -121,6 +125,7 @@ public class BuilderMirror extends BuilderTiles {
          if( o==-1 ) throw new Exception("Order unknown !");
          context.setOrder(o);
       } else {
+         if( paramO>=0 && paramO<=2 ) throw new Exception("Target HiPS order must be greater or equal to 3");
          if( o!=-1 ) {
             if( paramO>o ) throw new Exception("Order greater than the original");
             else if( o!=paramO ) isPartial=true;
@@ -245,7 +250,7 @@ public class BuilderMirror extends BuilderTiles {
       // Le Mode n'est pas paramtrable par l'utilisateur
       // KEEPTILE Obligatoire pour pouvoir tester les branches plus courtes dans le cas d'un catalogue
       // => cf findLeaf(...)
-      context.setMode( flagCat ? Mode.KEEPTILE : Mode.REPLACETILE );
+      context.setModeMerge( flagCat ? ModeMerge.mergeKeepTile : ModeMerge.mergeOverwriteTile );
    }
    
    // Rcupration des paramtres pour effectuer un split multi-partitions
@@ -370,8 +375,37 @@ public class BuilderMirror extends BuilderTiles {
          } finally {  if( out!=null ) out.close(); }
       }
       
+      // Validation des checkcodes
+      if( !context.isTaskAborting() ) validateCheckCode();
+   }
+   
+   public void validateCheckCode() {
+      try {
+         context.setCheckForce(false);
+         Builder b=Task.factoryRunner(context,Action.CHECKCODE);
+         if( context.isTaskAborting() ) throw new Exception("Aborting");
+      } catch( Exception e ) {
+         e.printStackTrace();
+      }
       
-
+      if( checkCode!=null ) {
+         if( isSmaller ) {
+            context.info("Partial mirror => checkcode not verified");
+         } else {
+            String localCheckCode = context.getCheckCode();
+            for( String fmt : context.getCheckCodeFmt(localCheckCode) ) {
+               String remoteKey = Context.getCheckCode(fmt, checkCode);
+               String localKey = Context.getCheckCode(fmt, context.hipsCheckCode);
+               if( remoteKey!=null ) {
+                  if( !remoteKey.equals(localKey)) {
+                     context.error("Checkcode not matching for ["+fmt+"] tiles => non-compliant copy");
+                  } else {
+                     context.info("Checkcode for ["+fmt+"] tiles OK => compliant copy");
+                  }
+               }
+            }
+         }
+      }
    }
 
    private int statNbFile=0;
@@ -447,15 +481,16 @@ public class BuilderMirror extends BuilderTiles {
       }
       
       context.showMirrorStat(statNbFile, statCumul, lastCumulPerSec, totalTime, nbThreads,statNbThreadRunning, lastTimeIP);
+  
    }
-
+   
    public void build() throws Exception {
       bidon = new Fits();
       initStat();
       super.build();
    }
-
-   protected Fits createLeaveHpx(ThreadBuilderTile hpx, String file,String path,int order,long npix, int z) throws Exception {
+   
+   protected Fits createLeafHpx(ThreadBuilderTile hpx, String file,String path,int order,long npix, int z) throws Exception {
     return createLeaveHpx(hpx,file,path,order,npix,z,true);
  }
 
@@ -706,7 +741,7 @@ public class BuilderMirror extends BuilderTiles {
                // reprise => pas de vrif date&size des tuiles dj arrives
                // On garde un vieux doute sur les fichiers vraiments petits
                // ON POURRAIT VERIFIER QUE LE FICHIER N'EST PAS TRONQUE EN CHARGEANT LA TUILE SANS ERREUR MAIS CA VA PRENDRE DES PLOMBES...
-               if( !check ) {
+               if( !fastCheck ) {
                   
                   // Des heuristiques simples pour ne pas recopier des tuiles
                   // visiblement dj copies et bonnes.
@@ -814,6 +849,7 @@ public class BuilderMirror extends BuilderTiles {
       int n;
 
       fIn = new File(fileIn);
+      if( !fIn.exists() ) return 0; // Fichier inexistant
       lastModified = fIn.lastModified();
       fOut = new File(fileOut);
 
