@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -44,10 +44,8 @@ public class BuilderMocIndex extends BuilderMoc {
 
       String outputFile = path + FS + Constante.FILE_MOC;
       String frame = getFrame();
-      moc.setSys(frame);
-      moc.setCheckConsistencyFlag(false);
+      moc.setSpaceSys(frame);
       generateMoc(moc,mocOrder, path);
-      moc.setCheckConsistencyFlag(true);
       moc.write(outputFile);
       
 // IL NE FAUT PAS CONVERTIR EN ICRS SI ON EST EN GAL CAR SINON LE BuilderTiles NE VA PAS
@@ -61,10 +59,10 @@ public class BuilderMocIndex extends BuilderMoc {
 //      }
       
       long time = System.currentTimeMillis() - t;
-      context.info("MOC Index done in "+cds.tools.Util.getTemps(time,true)
+      context.info("MOC Index done in "+cds.tools.Util.getTemps(time*1000L)
                         +": mocOrder="+moc.getMocOrder()
                         +"  frame="+frame
-                        +" size="+cds.tools.Util.getUnitDisk( moc.getSize()));
+                        +" size="+cds.tools.Util.getUnitDisk( moc.getMem()));
 
    }
    
