@@ -22,10 +22,7 @@
 package cds.allsky;
 
 import java.awt.image.IndexColorModel;
-import java.io.BufferedInputStream;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.InputStreamReader;
 
 import cds.aladin.CanvasColorMap;
 import cds.aladin.KernelList;
@@ -37,7 +34,7 @@ import cds.fits.Fits;
 import cds.moc.SMoc;
 import cds.tools.pixtools.Util;
 
-public class BuilderRgb extends BuilderTiles {
+public class BuilderRgb extends BuilderRunner {
 
 
    private String [] inputs;         // Les paths des HiPS red, green, blue
@@ -68,7 +65,7 @@ public class BuilderRgb extends BuilderTiles {
    
    private int statNbFile;
 
-   private Mode coaddMode=Mode.REPLACETILE;
+   private ModeMerge coaddMode=ModeMerge.mergeOverwriteTile;
    private int format;
 
    public BuilderRgb(Context context) {
@@ -81,7 +78,10 @@ public class BuilderRgb extends BuilderTiles {
       Fits.setToolKit();
       build();
       context.resetCheckCode();
-      context.setPropriete(Constante.KEY_HIPS_PROCESS_HIERARCHY, context.getJpegMethod().toString().toLowerCase());
+      context.setPropriete(Constante.KEY_HIPS_COADD, 
+               context.getModeOverlay().toString()+" "+
+               context.getModeMerge().toString()+" "+
+               context.getModeTree().toString() );
 
       if( !context.isTaskAborting() ) (new BuilderMoc(context)).createMoc(output);
       if( !context.isTaskAborting() ) { (new BuilderAllsky(context)).run(); context.done("ALLSKY file done"); }
@@ -151,10 +151,10 @@ public class BuilderRgb extends BuilderTiles {
       String path = context.getRgbOutput();
       
       format= context.getRgbFormat();
-      coaddMode = context.getMode();
-      if( coaddMode!=Mode.KEEPTILE && coaddMode!=Mode.REPLACETILE ) {
+      coaddMode = context.getModeMerge();
+      if( coaddMode!=ModeMerge.mergeKeepTile && coaddMode!=ModeMerge.mergeOverwriteTile ) {
          if( context instanceof ContextGui ) {
-            context.setMode(Mode.REPLACETILE);
+            context.setModeMerge(ModeMerge.mergeOverwriteTile);
          } else throw new Exception("Only KEEPTILE and REPLACETILE modes are supported for RGB HiPS generation");
 
       }
@@ -275,9 +275,9 @@ public class BuilderRgb extends BuilderTiles {
       // dtermination de la zone  calculer
       if( context.mocArea!=null ) context.moc = context.moc.intersection( context.mocArea );
       
-      // Faut-il un filtre gaussien
-      if( context.gaussFilter ) context.info("Gauss filter activated...");
-      flagGauss = context.gaussFilter;
+//      // Faut-il un filtre gaussien
+//      if( context.gaussFilter ) context.info("Gauss filter activated...");
+//      flagGauss = context.gaussFilter;
 
       context.writeMetaFile();
    }
@@ -372,21 +372,6 @@ public class BuilderRgb extends BuilderTiles {
       return order;
    }
 
-   // Chargement d'un fichier de proprits
-   private MyProperties loadProperties(String path) throws Exception {
-      MyProperties prop;
-      String propFile = path+Util.FS+Constante.FILE_PROPERTIES;
-      prop = new MyProperties();
-      File f = new File( propFile );
-      if( f.exists() ) {
-         if( !f.canRead() ) throw new Exception("Propertie file not available ! ["+propFile+"]");
-         InputStreamReader in = new InputStreamReader( new BufferedInputStream( new FileInputStream(propFile) ), "UTF-8");
-         prop.load(in);
-         in.close();
-      }
-      return prop;
-   }
-
    /** Prparation de la table des couleurs pour la composante c
     * @param s : format: min [med] max [fct]  (reprsente les valeurs physiques des pixels comme reprsentes sur l'histogramme des pixels)
     */
@@ -440,9 +425,12 @@ public class BuilderRgb extends BuilderTiles {
       // rcupration du bzero et bscale
       double bzero=0,bscale=1;
       Fits f = new Fits();
-      String name = inputs[c]+Util.FS+"Norder3"+Util.FS+"Allsky.fits";
-      File file = new File( name );
-      if( !file.canRead() ) throw new Exception("Cannot determine BZERO and BSCALE for component "+c+" => missing Allsky.fits");
+      
+//      String name = inputs[c]+Util.FS+"Norder3"+Util.FS+"Allsky.fits";
+//      if( !file.canRead() ) throw new Exception("Cannot determine BZERO and BSCALE for component "+c+" => missing Allsky.fits");
+      String name = context.findOneNpixFile(inputs[c],"fits");
+      if( name==null ) throw new Exception("Cannot determine BZERO and BSCALE for component "+c+" => no fits tile");
+
       f.loadHeaderFITS( name );
       try { bzero = f.headerFits.getDoubleFromHeader("BZERO"); } catch( Exception e ) { }
       try { bscale = f.headerFits.getDoubleFromHeader("BSCALE"); } catch( Exception e ) { }
@@ -469,7 +457,7 @@ public class BuilderRgb extends BuilderTiles {
 
    private String L(int c) { return c==0?"red":c==1?"green":"blue"; }
 
-   protected Fits createLeaveHpx(ThreadBuilderTile hpx, String file,String path,int order,long npix, int z) throws Exception {
+   protected Fits createLeafHpx(ThreadBuilderTile hpx, String file,String path,int order,long npix, int z) throws Exception {
       long t = System.currentTimeMillis();
       Fits [] in = getLeaves(order, npix);
       Fits rgb = in==null ? null : createLeaveRGB(in);
@@ -606,14 +594,15 @@ public class BuilderRgb extends BuilderTiles {
                   tot += pix[c];
                }
             }
-            if( missing!=-1 ) pix[missing] = tot/2;
+//            if( missing!=-1 ) pix[missing] = tot/2;
             
             int pixel;
             double[] pix8 = new double[3];
             if( tot==0 ) pixel=0x00;
             else {
-               pixel = 0xFF;
+               tot=0;
                for( int c=0; c<3; c++ ) { 
+                  if( c==missing ) continue;
                   int itcm =  (int)Math.floor( pix[c] );
                   if( tcm[c]==null ) pix8[c] = itcm;
                   else if( itcm>=255 ) pix8[c] = tcm[c][255];
@@ -628,6 +617,12 @@ public class BuilderRgb extends BuilderTiles {
                         pix8[c] = (int)Math.round( v1*d2  + v2*d1 );
                      }
                   }
+                  tot += pix8[c];
+               }
+               
+               if( missing!=-1 ) pix8[missing]=tot/2.;
+               pixel = 0xFF;
+               for( int c=0; c<3; c++ ) { 
                   pixel = (pixel<<8) | ((int)pix8[c] & 0xFF);
                }
             }
