@@ -70,7 +70,6 @@ import cds.aladin.Plan;
 import cds.aladin.PlanBG;
 import cds.aladin.PlanBGRgb;
 import cds.aladin.prop.PropPanel;
-import cds.allsky.Context.JpegMethod;
 import cds.tools.Util;
 
 public class TabRgb extends JPanel implements ActionListener {
@@ -252,9 +251,9 @@ public class TabRgb extends JPanel implements ActionListener {
    private void seeCmd() {
       String s = getCmdLine();
       aladin.copyToClipBoard( s );
-      aladin.console.printInPad(s);
+      aladin.console.printInPad(s+"\n");
       aladin.console.show();
-      aladin.info(this, getString("CMDLINEINFO"));
+      aladin.info(this, getString("CMDLINEINFO")+"\n=> "+s);
    }
    
    // Gnre le JPanel ddi aux paramtres
@@ -325,15 +324,15 @@ public class TabRgb extends JPanel implements ActionListener {
             getString("METHODJPGH"),
             p1,g,c, GridBagConstraints.EAST);
 
-      p1 = new JPanel();
-      gauss=b1 = new JCheckBox(getString("FILTERGAUSS")+" ");  p1.add(b1); 
-      b1.addActionListener( new ActionListener() {
-         public void actionPerformed(ActionEvent e) { updatePreview(); }
-      });
-      b1.setSelected(true);
-      PropPanel.addCouple(f, p,getString("FILTERRGB"), 
-            getString("FILTERRGBH"),
-            p1,g,c, GridBagConstraints.EAST);
+//      p1 = new JPanel();
+//      gauss=b1 = new JCheckBox(getString("FILTERGAUSS")+" ");  p1.add(b1); 
+//      b1.addActionListener( new ActionListener() {
+//         public void actionPerformed(ActionEvent e) { updatePreview(); }
+//      });
+//      b1.setSelected(true);
+//      PropPanel.addCouple(f, p,getString("FILTERRGB"), 
+//            getString("FILTERRGBH"),
+//            p1,g,c, GridBagConstraints.EAST);
 
       bg = new ButtonGroup();
       p1 = new JPanel();
@@ -488,7 +487,17 @@ public class TabRgb extends JPanel implements ActionListener {
    // Cre/remplace le plan de prvisualisation montrant immdiatement le rsultat du HiPS couleur qui sera gnr
    // en fonction des paramtres slectionns.
    private void createPreview() {
-      planPreview = aladin.calque.createPlanBGRgb( this, getSelectedPlan(0), getSelectedPlan(1), getSelectedPlan(2) );
+      aladin.view.autoViewGenerator();
+      final TabRgb ici = this;
+      try {
+         SwingUtilities.invokeLater( new Runnable() {
+            public void run() {
+               Util.pause(500);
+               planPreview = aladin.calque.createPlanBGRgb( ici, getSelectedPlan(0), getSelectedPlan(1), getSelectedPlan(2) );
+               aladin.view.autoViewGenerator();
+            }
+         });
+      } catch( Exception e ) { }
    }
    
    /** Retourne le numro de la composante manquante, -1 si aucune (0-red, 1-green, 2-blue) */
@@ -508,7 +517,7 @@ public class TabRgb extends JPanel implements ActionListener {
 
    
    /** Retourne true si le filtre de rduction de bruit (gauss) est activ */
-   public boolean getGauss() { return gauss.isSelected(); }
+//   public boolean getGauss() { return gauss.isSelected(); }
 
    /** Retourne les 3 plans slectionns */
    public PlanBG [] getSelectedPlans() {
@@ -519,9 +528,9 @@ public class TabRgb extends JPanel implements ActionListener {
    public int getRGBMethod() { return classic.isSelected() ? 0 : 1; }
    
    /** Retourne la mthode qu'il faudra utiliser pour construire les JPG couleur */
-   public JpegMethod getHierarchyAlgo() {
-      if( radioMediane.isSelected() ) return Context.JpegMethod.MEDIAN;
-      return Context.JpegMethod.MEAN;
+   public ModeTree getModeTree() {
+      if( radioMediane.isSelected() ) return ModeTree.treeMedian;
+      return ModeTree.treeMean;
    }
 
    /** Retourne le format de codage pour les tuiles couleurs (JPEG ou PNG) */
@@ -544,9 +553,16 @@ public class TabRgb extends JPanel implements ActionListener {
    public String getTransfertFct(int c){ return function[c].getText(); }
    
    /** Retourne les diffrents paramtres de l'algo de Lupton pour la composante c */
-   public double getLuptonM(int c)     { return Double.parseDouble( luptonM[c].getText() ); }
-   public double getLuptonS(int c)     { return Double.parseDouble( luptonS[c].getText() ); }
-   public double getLuptonQ()          { return Double.parseDouble( luptonQ.getText() ); }
+   public double getLuptonM(int c)     { return getLuptonVal( luptonM[c]); }
+   public double getLuptonS(int c)     { return getLuptonVal( luptonS[c]); }
+   public double getLuptonQ()          { return getLuptonVal( luptonQ); }
+   
+   private double getLuptonVal(JText t) {
+      try {
+         return Double.parseDouble( t.getText() );
+      } catch( Exception e ) {}
+      return 0;
+   }
    
    // "ds'applique" le bscale et le bzero sur la valeur passe en paramtre pour la composante couleur c
    private double noScaleAndZero(int c,double val) {
@@ -620,7 +636,7 @@ public class TabRgb extends JPanel implements ActionListener {
          for( Object p : x ) {
             if( ((PlanBG)p).isColored() ) n--;
             else if( !((PlanBG)p).canbeTruePixels() ) n--;
-            else if( !Aladin.PROTO && !((PlanBG)p).isLocalAllSky() ) n--;
+            else if( !Aladin.BETA && !((PlanBG)p).isLocalAllSky() ) n--;
          }
          
          // Copie
@@ -691,8 +707,8 @@ public class TabRgb extends JPanel implements ActionListener {
          PlanBG p = getSelectedPlan(c);
          cmd.append( " in"+RGB[c]+"=\""+p.getUrl()+"\"");
       }
-      cmd.append( getFormat()==Constante.TILE_PNG ? " color=png" :" color=jpg");
-      if( getGauss() ) cmd.append(" filter=gauss");
+      cmd.append(" "+Param.color+(getFormat()==Constante.TILE_PNG ? "=png" :"=jpg"));
+//      if( getGauss() ) cmd.append(" filter=gauss");
       
       boolean flagLupton = getRGBMethod()==1;
       if( flagLupton ) {
@@ -710,9 +726,9 @@ public class TabRgb extends JPanel implements ActionListener {
             if( !Double.isNaN(os) && sx!=os ) sameS=false;
             os=sx;
          }
-         cmd.append(" luptonM="+(sameM ? mx+"" : m));
-         cmd.append(" luptonS="+(sameS ? sx+"" : s));
-         cmd.append(" luptonQ="+getLuptonQ());
+         cmd.append(" "+Param.luptonM+"="+(sameM ? mx+"" : m));
+         cmd.append(" "+Param.luptonS+"="+(sameS ? sx+"" : s));
+         cmd.append(" "+Param.luptonQ+"="+getLuptonQ());
 
          // Paramtre de la mthode RGB classique   
       } else {
@@ -727,7 +743,7 @@ public class TabRgb extends JPanel implements ActionListener {
          }
       }
       
-      cmd.append(" out=\""+outputField.getText()+"\" RGB");
+      cmd.append(" "+Param.id+"=TEST/P/hipsrgb out=\""+outputField.getText()+"\" RGB");
       return cmd.toString();
    }
    
@@ -788,14 +804,14 @@ public class TabRgb extends JPanel implements ActionListener {
 
          // Les paramtres gnraux
          context.setRgbOutput(outputField.getText());
-         context.setHierarchyAlgo(getHierarchyAlgo());
+         context.setHierarchyAlgo(getModeTree());
          context.setRgbFormat(getFormat());
-         if( getGauss() ) context.setFilter("gauss");
+//         if( getGauss() ) context.setFilter("gauss");
 
          setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
          context.setProgressBar(progressBar);
          
-         new Task(context, Action.RGB, false);
+         new Task(context, Action.RGB, true);
 
       } catch( Exception e1 ) {
          aladin.error(this, "RGB HiPS creation error");
