@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -206,17 +206,18 @@ public class Editing extends Astroformat {
     * @param  buf   the buffer to which the flags are appended
     * @param  flags    the list of flags.
     * @param  symbols  the table of symbols
+    * @return the StringBuffer parameter
     */
-   public StringBuffer editFlags(StringBuffer buf, int flags, String symbols[])
-   {
-      int i, j;
-      int n=symbols.length;
-      	for (i=j=0; i<n; i++) {
-	    if ((flags&(1<<i)) == 0) continue;
-	    if(j>0) buf.append(',');
-	    buf.append(symbols[i]);
-	    j++;
+    public StringBuffer editFlags(StringBuffer buf, int flags, String[] symbols) {
+        int flag=flags;
+        boolean need_comma=false;
+      	for (int i=0; (flag!=0)&&(i<symbols.length); i++, flag>>>=1) {
+            if((flag&1) == 0) continue;
+            if(need_comma) buf.append(',');
+            else need_comma = true;
+            buf.append(symbols[i]);
 	}
+        if(flag!=0) buf.append("0x" + Integer.toHexString(flag<<symbols.length) + "??");
 	return buf;
    }
 
@@ -225,6 +226,7 @@ public class Editing extends Astroformat {
     * Just appends the NULL string representation, right-aligned.
     * @param  buf   the buffer to which the string representation is appended
     * @param  width the total width
+    * @return the StringBuffer parameter
     */
     public StringBuffer editNaN(StringBuffer buf, int width) {
       	for (int nb = width - nulls[0].length(); nb>0; nb--)
@@ -239,6 +241,7 @@ public class Editing extends Astroformat {
     * @param  buf   the buffer to which the string representation is appended
     * @param  width the total width
     * @param  sign  positive(add +sign), negative(add -sign), or zero.
+    * @return the StringBuffer parameter
     */
    public StringBuffer editInfinite(StringBuffer buf, int width, int sign) {
       	int nb = width - inf_string.length(); 
@@ -425,7 +428,7 @@ public class Editing extends Astroformat {
     * depending on the FACTOR option.
     * @param  buf   buffer to which the string representation is appended
     * @param  value number to edit
-    * @param  ndig  number of significant digits (do the best if ndig<=0)
+    * @param  ndig  number of significant digits (do the best if ndig&leq;0)
     * @param  nexp  number of characters for the exponent value (3 recommended)
     * @param  option a combination of {@link Astroformat#EFORMAT} 
     * / {@link Astroformat#SIGN_EDIT}
