@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -31,6 +31,9 @@ package cds.astro;
  * the Earth frame.
  *  
  * @author Francois Ochsenbein (CDS)
+ * @version 1.0  12-Sep-2006 
+ * @version 1.1  04-May-2011 : added getEquinox
+ * @version 2.0  04-Feb-2019 : 1-D matrices.
  *
  */
 public abstract class Equatorial extends Astroframe {
@@ -40,7 +43,7 @@ public abstract class Equatorial extends Astroframe {
     **/
     protected double equinox = 0;	// The actual equinox in J/B year
     /* The Equatorial frame also has a matrix to precess to standard equinox*/
-    protected double[][] toBaseEquinox;
+    protected double[] toBaseEquinox;
 
     /**
      * Constructor: editions are sexagesimal time in Lon/Lat 
@@ -55,12 +58,12 @@ public abstract class Equatorial extends Astroframe {
     /**
      * Edition of Equatorial frame.
      * @return the name of the Astroframe.
-    **/
     public String toString() {
 	if ((base_epoch != epoch) || (equinox != base_epoch)) 
 	    return (super.toString(this.epoch));
 	return (super.toString());
     }
+    **/
     
     /**
      * Get the equinox
