@@ -42,109 +42,95 @@ import cds.tools.Util;
  * Classe de manipulation d'un cache de fichiers FITS/JPEG ouverts.
  * Permet d'viter les ouvertures et rouvertures inutiles lors d'un traitement ncessitant plusieurs fois
  * l'accs aux mmes images.
- * Il faut mentionner  la cration la taille max alloue au cache, en Mo (par dfaut 512Mo) et en Nb de fichiers (par dfaut 10000)
+ * 
+ * Il faut mentionner  la cration la taille max alloue au cache, en Mo et en Nb de fichiers, ainsi que la borne max en volume, resp en nombre max en cas de modification
+ * dynamique de la capacit du cache. Ainsi lorsque le cache sature, et qu'il n'arrive pas  tre purger sans virer des fichiers encore trs rcemment utiliss,
+ * la capacit du cache va automatiquement augment d'un tiers (sans dpasser les bornes indiques). Cette augmentation ne sera que temporairie dans la mesure du possible
+ * et cette capacit sera peu  peu diminuer pour reprendre les valeurs dclares au dpart.
+ * 
  * L'accs  un fichier Fits se fait par Fits getFits(filename)( ou getFits(filename,true) pour du JPEG)
  *
  * Rq: Le rajouti d'Anas sur la soustraction du skyvalName ne devrait pas tre dans cette classe (selon moi)
  * => A voir si on le dplace
  *
  * @author Pierre Fernique [CDS]
+ * @version 1.3 - novembre 2022 - ajout de la variation dynamique de la capacit du cache
  * @version 1.2 - novembre 2014
  * @version 1.1 - juillet 2012
  * @version 1.0 - sept 2011
  */
 public class CacheFits {
+   
+   static final private long DELAYINCREASE = 5 * 60000L;  // Dlai avant d'ventuellement diminuer les capacits du cache (5mn)
+   private long timeLastIncrease=0L;                      // Date de la dernire augmentation des capacits du cache
+   
+   static private final long DEFAULT_MAXMEM=512*1024*1024L;   // Taille max courante du cache par dfaut
+   static protected final int DEFAULT_MAXFILE = 500;          // Nbre max d'items du cache par dfaut
+   
+   private long LIMITMEM;           // Taille max autorise
+   private int LIMITFILE;           // Nombre max d'items autoriss
+   
+   private long maxMem;             // Taille max courante (en octets)
+   private int maxFile;             // Nombre max courant d'items
+   
+   private long initMem;             // Taille max courante souhaite au dpart (en octets)
+   private int initFile;             // Nombre max courant d'items souhait au dpart 
 
-   static private final long DEFAULT_MAXMEM=512*1024*1024L;
-   static protected final int MAXFILE = 10000;
-
-   private long maxMem;             // Taille max (en octets)
    private int nextId;              // prochain identificateur unique de fichier
    volatile private boolean cacheOutOfMem;   // En cas de dbordement mmoire, on vire totalement le cache
    protected HashMap<String, FitsFile> map;             // Table des fichiers
-   //   private TreeMap<String,FitsFile> sortedMap;        // Table tri par ordre de dernier accs
-   Context context;
+   private int nbClean;  // Nombre de purges du cache
+
+   private Context context;
    private Hashtable<String, double[]> cutCache = new Hashtable<>();
    private Hashtable<String, double[]> shapeCache = new Hashtable<>();
 
-
-   //private boolean skyvalSub = false;// condition d'application d'une soustraction du skyval au moment
-   //de la mise dans le cache
-
    protected int statNbOpen,statNbFind,statNbFree;
 
    /**
     * Cration d'un cache de fichiers Fits
     */
-   public CacheFits() { this(DEFAULT_MAXMEM); }
+   public CacheFits() { this(DEFAULT_MAXMEM,DEFAULT_MAXFILE,    DEFAULT_MAXMEM*3,DEFAULT_MAXFILE*3); }
+   public CacheFits(long maxMem) { this(maxMem,DEFAULT_MAXFILE, DEFAULT_MAXMEM*3,DEFAULT_MAXFILE*3); }
 
    /**
     * Cration d'un cache de fichiers Fits
-    * @param maxMem limite en bytes occups, ou si ngatif,
-    *          nombre de bytes  garder libre par rapport  la RAM dispo
+    * @param maxMem taille max du cache (en bytes)
+    * @param maxFile nombre max de fichier du cache
+    * @param limitMem borne max du cache en cas d'augmentation dynamique de sa taille (voir description de la classe)
+    * @param limitFile borne max en nombre de fichiers en cas d'augmentation dynamique de ses capacits
     * @param rewriteMode true si les fichiers du cache seront rcrits systmatiquement
     */
-   public CacheFits(long maxMem) {
-      this.maxMem = maxMem;
+   public CacheFits(long maxMem,int maxFile,long limitMem, int limitFile) {
+      if( maxMem>limitMem ) maxMem=limitMem;
+      if( maxFile>limitFile ) maxFile=limitFile;
+      
+      this.maxMem = this.initMem = maxMem;
+      this.maxFile = this.initFile = maxFile;
+      
+      this.LIMITMEM = limitMem;
+      this.LIMITFILE = limitFile;
+      
       cacheOutOfMem = maxMem==0;
       nextId = 0;
+      nbClean=0;
       statNbFree = statNbOpen = statNbFind = 0;
-      map = new HashMap<>(MAXFILE+MAXFILE/100);
-      //      sortedMap = new TreeMap<String, FitsFile>( new ValueComparator(map) );
+      map = new HashMap<>(maxFile+maxFile/2);
    }
-
-   /** Vrification qu'il reste assez de mmoire RAM, et sinon
-    * on va librer temporairement les blocs pixels[] non utiliss afin de rcuprer
-    * ce qui manque
-    * @param rqMem taille de la mmoire requise
-    * @return true c'est bon, false, faut attendre
-    */
-   //   public boolean needMem(long rqMem) {
-   //      if( rqMem<=0L ) return false;
-   //      long freeMem=getFreeMem();
-   //      if( getFreeMem()>rqMem ) return false;
-   //
-   //      rqMem = rqMem-freeMem;
-   //      long mem = 0L;
-   //      try {
-   //         waitLock();
-   //         for( String key : map.keySet() ) {
-   //            Fits f = map.get(key).fits;
-   //            long m = f.getMem();
-   //            try { f.releaseBitmap();
-   //            } catch( Exception e ) { } mem += m-f.getMem();
-   //            if( mem>rqMem ) break;
-   //         }
-   //      } finally { unlock(); }
-   //      gc();
-   //      return mem>rqMem;
-   //   }
+   
+   /** Retourne la limite courante en mmoire du cache (en bytes) */
+   public long getMaxMem() { return maxMem; }
+   
+   /** Retourne la limite courante en nombre de fichiers du cache */
+   public int getMaxFile() { return maxFile; }
 
    // Gestion d'un lock
    static protected final Object lockObj= new Object();
-   //   transient private boolean lock;
-   //   private void waitLock() {
-   //      while( !getLock() ) sleep(5);
-   //   }
-   //   private void unlock() { lock=false; }
-   //   private boolean getLock() {
-   //      synchronized( lockObj ) {
-   //         if( lock ) return false;
-   //         lock=true;
-   //         return true;
-   //      }
-   //   }
-   //   // Mise en pause
-   //   private void sleep(int delay) {
-   //      try { Thread.currentThread().sleep(delay); }
-   //      catch( Exception e) { }
-   //   }
 
    static public final int FITS = 0; // FITS classique
    static public final int JPEG = 1; // JPEG
    static public final int PNG  = 2; // PNG
    static public final int HHH  = 4; // HHH (combin avec JPEG ou PNG)
-   
 
    /**
     * Rcupration d'un Fits spcifi par son nom de fichier.
@@ -208,9 +194,31 @@ public class CacheFits {
    protected void remove(String name) throws Exception {
       map.remove(name);
    }
-
+   
    private boolean firstChangeOrig=true;
-
+   
+   /** Remplace une extension par une autre dans un nom de ficheir
+    * ex: toto.hhh[xxx] => toto.fits[xxx]
+    * @param filename Le nom du fichier
+    * @param orig l'extension d'origine (sans le point), ou null pour n'importe quelle extension
+    * @param ext la nouvelle extension (sans le point)
+    * @return le nom de fichier avec la nouvelle extension
+    */
+   private String replaceExt(String filename,String orig, String ext) {
+      if( orig==null ) orig="";
+      int pos = filename.lastIndexOf("."+orig);
+      if( pos==-1 ) return filename+"."+ext;
+      return filename.substring(0,pos)+"."+ext+filename.substring(pos+("."+orig).length() );
+      
+   }
+   
+   /** Positionnement du Blank alternatif */
+   private void setAltBlank(Fits f) {
+      if( context==null ) return;
+      if( context.getBlankKey()!=null ) f.setBlank(context.getBlankKey());
+      else if( context.hasAlternateBlank() ) f.setBlank( context.getBlankOrig() );
+   }
+   
    // Ouvre un fichier
    private FitsFile open(String fileName,int mode,boolean flagLoad,boolean keepHeader) throws Exception,MyInputStreamCachedException {
       boolean flagChangeOrig=false;
@@ -227,30 +235,41 @@ public class CacheFits {
 
       FitsFile f = new FitsFile();
       f.fits = new Fits();
-      if( context!=null && context.skyvalName!=null ) { flagLoad=true; f.fits.setReleasable(false); }
-      if( context!=null && context.getBlankKey()!=null ) f.fits.setBlank(context.getBlankKey());
+      if( context!=null && (context.skyvalName!=null || context.cutByImage)) { 
+         flagLoad=true; 
+         f.fits.setReleasable(false); 
+      }
 
       // Il faut lire deux fichiers, le HHH, puis le JPEG ou PNG, voire FITS suivant le cas
       if( (mode&HHH)!=0 ) {
          f.fits.loadHeaderFITS(fileName);
-         String pngFile  = fileName.replaceAll("\\.hhh",".png");
-         String jpgFile  = fileName.replaceAll("\\.hhh",".jpg");
-
+         setAltBlank(f.fits);
+//         String pngFile  = fileName.replaceAll("\\.hhh",".png");
+//         String jpgFile  = fileName.replaceAll("\\.hhh",".jpg");
+         String pngFile   = replaceExt(fileName,"hhh","png");
+         String jpgFile   = replaceExt(fileName,"hhh","jpg");
+         String fitsFile  = replaceExt(fileName,"hhh","fits");
+         
          // On ne connait pas le type de fichier pour les pixels,
          // => on va voir ce qui existe
+         boolean modeSpecialFitsHHH=false;
          if( (mode&(JPEG|PNG))==0 ) {
-            String racJpgFile = jpgFile;
-            String racPngFile = pngFile;
+            String racJpgFile  = jpgFile;
+            String racPngFile  = pngFile;
+            String racFitsFile = fitsFile;
             int i;
-            if( (i= jpgFile.indexOf(".jpg["))>0 )   racJpgFile  = jpgFile.substring(0,i+4);
-            if( (i= pngFile.indexOf(".png["))>0 )   racPngFile  = pngFile.substring(0,i+4);
+            if( (i=  jpgFile.indexOf(".jpg["))>0 )   racJpgFile  = jpgFile.substring(0,i+4);
+            if( (i=  pngFile.indexOf(".png["))>0 )   racPngFile  = pngFile.substring(0,i+4);
+            if( (i= fitsFile.indexOf(".fits["))>0 ) racFitsFile  = fitsFile.substring(0,i+5);
 
             if( (new File(racJpgFile)).exists() ) mode |= JPEG;
             else if( (new File(racPngFile)).exists() ) mode |= PNG;
+            else if( (new File(racFitsFile)).exists() ) modeSpecialFitsHHH=true;
          }
          if( (mode&PNG)!=0  ) fileName=pngFile;
          else if( (mode&JPEG)!=0 ) fileName=jpgFile;
-         else throw new Exception(".hhh file without associated .jpg, .png file");
+         else if( modeSpecialFitsHHH ) fileName=fitsFile;
+         else throw new Exception(".hhh file without associated .jpg, .png or .fits file");
       }
 
       if( (mode&(PNG|JPEG))!=0 ) {
@@ -258,9 +277,10 @@ public class CacheFits {
                : (mode&JPEG)!=0 ? Fits.PREVIEW_JPEG
                      : Fits.PREVIEW_UNKOWN;
          f.fits.loadPreview(fileName,true, (mode&HHH)==0, format);
-      }
-      else {
-         f.fits.loadFITS(fileName, false, flagLoad);
+         
+      } else {
+         f.fits.loadFITS(fileName, false, flagLoad,true);
+         setAltBlank(f.fits);
          if( context!=null ) {
             flagChangeOrig = f.fits.bzero!=context.bZeroOrig || f.fits.bscale!=context.bScaleOrig;
             if( flagChangeOrig && firstChangeOrig ) {
@@ -301,6 +321,9 @@ public class CacheFits {
          applyPostFilter(f.fits,flagChangeOrig);
       }
 
+      // passage en 8 bits ?
+      if( context!=null && context.cutByImage ) applyTo8(f.fits);
+      
       // On ne conserve pas le HeaderFits
       if( !keepHeader ) f.fits.freeHeader();
       return f;
@@ -308,11 +331,11 @@ public class CacheFits {
 
    // Retourne true si le cache est en surcapacit
    protected boolean isOver() {
-      if( map.size()>MAXFILE ) return true;
+      if( map.size()>maxFile ) return true;
       if( maxMem<0 ) {
-         //         System.out.println("Cachemem="+Util.getUnitDisk(mem)+" freeMem="+Util.getUnitDisk(getFreeMem())
-         //               +" maxMem="+Util.getUnitDisk(-maxMem)
-         //               +" isOver="+(mem>getFreeMem()+maxMem));
+//                  System.out.println("Cachemem="+Util.getUnitDisk(mem)+" freeMem="+Util.getUnitDisk(getFreeMem())
+//                        +" maxMem="+Util.getUnitDisk(-maxMem)
+//                        +" isOver="+(mem>getFreeMem()+maxMem));
          //         return mem>getFreeMem()+maxMem;
          return getFreeMem()<-maxMem;
       }
@@ -323,16 +346,7 @@ public class CacheFits {
    public long getMem() {
       long mem=0L;
       if( map==null ) return mem;
-      
-//      Enumeration<String> e = map.keys();
-//      while( e.hasMoreElements() ) {
-//         String key = e.nextElement();
-//         FitsFile f = map.get(key);
-//         mem += f.fits.getMem();
-//      }
-      
       try { for( FitsFile f: map.values() ) mem += f.fits.getMem(); } catch( Exception e ) { };
-
       return mem;
    }
 
@@ -352,7 +366,7 @@ public class CacheFits {
          long mem = getMem();
          long freeMem = getFreeMem();
          
-         boolean tooManyFile = map.size()>MAXFILE;
+         boolean tooManyFile = map.size()>maxFile;
          boolean tooManyMem = maxMem<0 && freeMem<-maxMem || maxMem>=0 && mem>maxMem;
          if( !tooManyFile && !tooManyMem ) return;
          
@@ -362,32 +376,33 @@ public class CacheFits {
          long m=0;
          int nb=0;
          boolean encore=true;
-         long now = System.currentTimeMillis();
+         long now = Util.getTime(0);
          long delay=5000;
+         boolean flagGC=false;
 
-         int i;
+         int pass;
          try {
             cacheOutOfMem=true;
 
             HashMap<String,String> libere = new  HashMap<>(map.size());
-            HashMap<String,FitsFile> map1 = new  HashMap<>(map.size());
+            HashMap<String,FitsFile> map1 = new  HashMap<>(maxFile+maxFile/2);
 
             // en premier tour, on supprime les fits non utiliss
             // depuis plus de 5s, et si pas assez de mmoire, on ne regarde plus la date
-            for( i=0; i<2 && encore; i++) {
+            for( pass=0; pass<2 && encore; pass++) {
                int mapsize=map.size();
 
                for( String key: map.keySet() ) {
                   FitsFile f = map.get(key);
                   if( f.fits.hasUsers() ) continue;
-                  if( i==0 && now-f.timeAccess<delay ) continue;
+                  if( pass==0 && now-f.timeAccess<delay ) continue;
                   m = f.getMem();
                   totMem+=m;
                   nb++;
                   statNbFree++;
 
                   libere.put(key,"");
-                  if( totMem>mem/2L && mapsize-nb < 2*MAXFILE/3 ) { encore=false; break; }
+                  if( totMem>mem/3L && mapsize-nb < 2*maxFile/3 ) { encore=false; break; }
                }
 
                for( String key: map.keySet() ) {
@@ -402,38 +417,90 @@ public class CacheFits {
                }
                
                map=map1;
-
-               //         Enumeration<String> e = map.keys();
-               //         while( e.hasMoreElements() ) {
-               //            String key = e.nextElement();
-               //            FitsFile f = map.get(key);
-               //            if( f.fits.hasUsers() ) continue;
-               //            if( i==0 && now-f.timeAccess<delay ) continue;
-               //            m = f.getMem();
-               //            totMem+=m;
-               //            nb++;
-               //            statNbFree++;
-               //            //            map.remove(key);
-               //            try { remove(key); } catch( Exception e1 ) { }
-               //            if( totMem> mem/2L && map.size()<2*MAXFILE/3 ) { encore=false; break; }
-               //         }
             }
 
-            //      sortedMap.clear();
-            gc();
+            // Je fais explicitement un gc() si la taille RAM restante est plus petite que la moiti de la taille du cache
+            // sinon on laisse la JVM grer tout seul
+            if( freeMem < mem/2 ) { gc(); flagGC=true; }
+            
          } finally {
             cacheOutOfMem=false;
          }
 
-         long duree = System.currentTimeMillis() - now;
-         String s1 = i>1 ? "s":"";
+         long duree = Util.getTime(0) - now;
+         String s1 = pass>1 ? "s":"";
          long freeRam = getFreeMem();
-         if( context!=null ) {
-            context.stat("Cache: freeRAM="+Util.getUnitDisk(freeMem)+" => "+nb+" files released ("+Util.getUnitDisk(totMem)+") in "+i+" step"+s1+" in "+Util.getTemps(duree*1000L)
-            +" => freeRAM="+Util.getUnitDisk(freeRam));
+         nbClean++;
+         if( context!=null && context.getVerbose()>=3) {
+            String tps = duree>1000 ? " in "+Util.getTemps(duree/1000L):""; 
+            String p = pass>1 ? " in "+pass+" steps":"";
+            context.stat("Cache: freeRAM="+Util.getUnitDisk(freeMem)+" => "+nb+" files released ("+Util.getUnitDisk(totMem)+")"+p+s1+tps
+            +(flagGC?" => freeRAM="+Util.getUnitDisk(freeRam):""));
+         }
+         
+         // Modification de la capacit du cache
+         // (augmentation si dernier nettoyage en 2 passes, diminution si a fait longtemps qu'on n'a pas du augmenter)
+         now = System.currentTimeMillis();
+         if( pass>1 ) { 
+            if( increaseCache() ) timeLastIncrease=now;
+         } else {
+            if( System.currentTimeMillis()-timeLastIncrease>DELAYINCREASE ) decreaseCache();
          }
       }
    }
+   
+   // Augmente la capacit du cache si possible
+   private boolean increaseCache() {
+      if( maxFile>=LIMITFILE || maxMem>=LIMITMEM) return false;
+      long memPerItem = maxMem / maxFile;
+
+      // J'ajoute 50% d'items en plus
+      int maxFile2 = maxFile+ maxFile/2;
+      if( maxFile2>LIMITFILE ) maxFile2=LIMITFILE;
+      long maxMem2 = maxFile2 * memPerItem;
+      if( maxMem2 > LIMITMEM ) maxMem2=maxMem2;
+      maxFile=maxFile2;
+      maxMem=maxMem2;
+      if( context!=null && context.getVerbose()>=3) {
+         context.stat("Cache: increaseCache: items="+maxFile+" mem="+Util.getUnitDisk(maxMem));
+      }
+      return true;
+   }
+   
+   // Diminue la capacit du cache si possible
+   private boolean decreaseCache() {
+      if( maxFile<=initFile || maxMem<=initMem ) return false;
+      
+      int delay=5000;
+      long now = System.currentTimeMillis();
+      
+      // Je vrifie qu'il y a suffisamment d'items que l'on peut effectivement librer
+      int nb=0;
+      for( String key: map.keySet() ) {
+         FitsFile f = map.get(key);
+         if( f.fits.hasUsers() ) continue;
+         if( now-f.timeAccess<delay ) continue;
+         nb++;
+         if( nb< maxFile/3 ) return false;
+      }
+      
+      long memPerItem = maxMem / maxFile;
+
+      // Je diminue d'un tier d'items
+      int maxFile2 = maxFile- maxFile/3;
+      if( maxFile2  < initFile ) maxFile2=initFile;
+      long maxMem2 = maxFile2 * memPerItem;
+      if( maxMem2 < initMem ) maxMem2=initMem;
+      maxFile=maxFile2;
+      maxMem=maxMem2;
+      if( context!=null && context.getVerbose()>=3) {
+         context.stat("Cache: decreaseCache: items="+maxFile+" mem="+Util.getUnitDisk(maxMem));
+      }
+      return true;
+   }
+   
+   /** Retourne le nombre de fois o le cache a t purg */
+   public int getNbClean() { return nbClean; }
 
    // Reset totalement le cache
    public void reset() {
@@ -483,6 +550,11 @@ public class CacheFits {
       // Estimation au centre
       try {
          
+         double pcMin = pourcentMin;
+         double pcMax = pourcentMax;
+         if( pcMin==pcMax ) { pcMin=Fits.POURCENT_MIN; pcMax=Fits.POURCENT_MAX; }
+         String eval = "from "+Util.getPourcent(pcMin)+" to "+Util.getPourcent(pcMax);
+         
          // Initialisation de la taille
          if( WIDTHAUTOCUT==-1 ) {
             if( f1.width>512 && f1.height>512 ) {
@@ -490,11 +562,11 @@ public class CacheFits {
                if( WIDTHAUTOCUT>1024 ) WIDTHAUTOCUT=1024;
                HEIGHTAUTOCUT = (int)(f1.height/3.5);
                if( HEIGHTAUTOCUT>1024 ) HEIGHTAUTOCUT=1024;
-               context.info("skyval estimation based on median on 5 regions ("+WIDTHAUTOCUT+"x"+HEIGHTAUTOCUT+" pixels)");
+               context.info("Cut estimation ("+eval+") based on median on 5 regions ("+WIDTHAUTOCUT+"x"+HEIGHTAUTOCUT+" pixels)");
             } else {
-               WIDTHAUTOCUT = (int)(f1.width*0.8);
-               WIDTHAUTOCUT = (int)(f1.width*0.8);
-               context.info("skyval estimation based central region ("+WIDTHAUTOCUT+"x"+HEIGHTAUTOCUT+" pixels)");
+               WIDTHAUTOCUT  = (int)(f1.width*0.8);
+               HEIGHTAUTOCUT = (int)(f1.height*0.8);
+               context.info("Cut estimation ("+eval+") based on central region ("+WIDTHAUTOCUT+"x"+HEIGHTAUTOCUT+" pixels)");
            }
          }
          
@@ -507,10 +579,10 @@ public class CacheFits {
          ox=x; oy=y; oz=z; ow=w; oh=h; od=d;
 
          f1.loadFITS(f.getFilename(),f.ext,x,y,z,w,h,d);
-         if( context.hasAlternateBlank() ) f1.setBlank( context.getBlankOrig() );
+         setAltBlank(f1);
          cut = f1.findAutocutRange(pourcentMin,pourcentMax);
 
-         //      System.out.println("cut central: "+cut[0]+" pour "+filename);
+//               System.out.println("cut central: "+cut[0]+" pour "+filename);
 
          // Si l'image est assez grande on va faire 4 autres mesures
          // et prendre la mdiane des 5
@@ -569,7 +641,7 @@ public class CacheFits {
 
       Fits f1 = new Fits();
       f1.loadFITS(filename);
-      if( context.hasAlternateBlank() ) f1.setBlank( context.getBlankOrig() );
+      setAltBlank(f1);
       shape = f1.findData();
       shapeCache.put(filename,shape);
 //      context.info("Data area range => ["+shape[0]+","+shape[1]+" "+shape[2]+"x"+shape[3]+"] for "+filename);
@@ -580,6 +652,23 @@ public class CacheFits {
 
    private boolean first=true;
    
+   /** Passe l'image  8 bits en appliquant un autocut */
+   private void applyTo8(Fits f) throws Exception {
+      double pourcentMin=Fits.POURCENT_MIN;
+      double pourcentMax=Fits.POURCENT_MAX;
+      if( Context.hasPourcentCut( context.getPixelRangeCut() ) ) {
+         pourcentMin=context.getPixelRangeCut()[context.POURCMIN];
+         pourcentMax=context.getPixelRangeCut()[context.POURCMAX];
+      }
+      double cut [] = findAutocutRange(f,pourcentMin,pourcentMax);
+      byte [] pix8 = f.toPix8(cut[Context.CUTMIN], cut[Context.CUTMAX], null, Fits.PIX_255);
+      f.invImageLine(f.width, f.height, pix8);
+      f.bitpix=8;
+      f.setBlank(0);
+      f.setBscale(1);
+      f.setBzero(0);
+      f.pixels=pix8;
+   }
    
    /**
     * Applique un filtre (soustraction du skyval, division par le expTime, masque, Lupton, ...)
@@ -667,7 +756,7 @@ public class CacheFits {
                double pixelFull = f.getPixelDouble(x+f.xCell, y+f.yCell, z+f.zCell);
 
                if( Double.isNaN(pixelFull) ) continue;
-
+               
                if( context.good!=null && (pixelFull<context.good[0] || context.good[1]<pixelFull) ) {
                   if( f.bitpix<0 ) f.setPixelDouble(x+f.xCell, y+f.yCell, z+f.zCell, blank);
                   else f.setPixelInt(x+f.xCell, y+f.yCell, z+f.zCell, (int)blank);
@@ -725,12 +814,12 @@ public class CacheFits {
       //      int nbReleased = getNbReleased();
       int n = map.size();
       String s = n>1 ? "s":"";
-      return "Cache: "+n+" cell"+s
+      return "RAM cache: "+n+" item"+s+"/"+maxFile
             //      +(nbReleased>0 ? "("+nbReleased+" released)" : "")
             +" using "+Util.getUnitDisk(getMem())
             +(maxMem>0 ? "/"+Util.getUnitDisk(maxMem):"["+Util.getUnitDisk(maxMem)+"]")
             +" freeRAM="+Util.getUnitDisk(getFreeMem())
-            +" (opened="+statNbOpen+" reused="+statNbFind+" released="+statNbFree+")";
+            +" (opened="+statNbOpen+" reused="+statNbFind+" released="+statNbFree+(nbClean>0?" [flush:"+nbClean+"x]":"")+")";
    }
 
    // retourne le nombre de fichier dans le cache dont le bloc mmoire pixel[]
@@ -755,6 +844,8 @@ public class CacheFits {
       long timeAccess;
 
       private int id;
+      
+      public int hashCode() { return Integer.hashCode(id); } 
 
       public FitsFile() {
          timeAccess = System.currentTimeMillis();
