@@ -525,6 +525,7 @@ public final class HeaderFits {
    /** Surcharge ou ajout d'un mot cl */
    public void setKeyword(String key,String value) {
       header.put(key,value);
+      if( !keysOrder.contains(key) ) keysOrder.add(key);
    }
 
    /** Surcharge ou ajout d'un mot cl */
@@ -643,10 +644,20 @@ public final class HeaderFits {
     * comme  l'origine - les commentaires sont restitus 
     * @return le nombre d'octets crits */
    public int writeHeader(OutputStream os ) throws Exception {
+      byte [] buf = makeHeaderBuf();
+      os.write(buf);
+      return buf.length;
+   }
+
+   /** Prpapration de l'entte FITS des mots cls mmoriss. L'ordre est conserv
+    * comme  l'origine - les commentaires sont restitus 
+    * @return le buffer contenant la totalit de l'entete (2880 align) */
+   public byte [] makeHeaderBuf() throws Exception {
+
       int n=keysOrder.size()*80;
       byte [] b= getEndBourrage(n);
       byte buf [] = new byte[n + b.length];
-      
+
       int m=0;
       Enumeration e = keysOrder.elements();
       while( e.hasMoreElements() ) {
@@ -658,9 +669,7 @@ public final class HeaderFits {
          m+=80;
       }
       System.arraycopy(b,0,buf,m,b.length);
-      n+=b.length;
-      os.write(buf);
-      return n;
+      return buf;
    }
 
    /** Gnration de la fin de l'entte FITS, cd le END et le byte de bourrage
