@@ -21,9 +21,13 @@ package cds.moc;
 
 import static cds.healpix.Healpix.nHash;
 
+import cds.healpix.CompassPoint.MainWind;
 import cds.healpix.FlatHashIterator;
+import cds.healpix.HealpixNested;
 import cds.healpix.HealpixNestedBMOC;
 import cds.healpix.HealpixNestedFixedRadiusConeComputer;
+import cds.healpix.NeighbourList;
+import cds.healpix.NeighbourSelector;
 
 /** HEALPix CDS wrapper
  * Encapsulate the usage of the HEALpix lib
@@ -87,6 +91,23 @@ public final class Healpix implements HealpixImpl {
       return cells;
    }
 
+   public long[] neighbours(int order, long npix) throws Exception  {
+      final HealpixNested hn = cds.healpix.Healpix.getNested(order);
+      final NeighbourSelector neig = hn.newNeighbourSelector(); // For thread safety issues
+      // SW, W, NW, N, NE, E, SE and S
+      final NeighbourList neigList = neig.neighbours(npix);
+      final long[] res = new long[8];
+      res[0] = neigList.get(MainWind.SW);
+      res[1] = neigList.get(MainWind.W);
+      res[2] = neigList.get(MainWind.NW);
+      res[3] = neigList.get(MainWind.N);
+      res[4] = neigList.get(MainWind.NE);
+      res[5] = neigList.get(MainWind.E);
+      res[6] = neigList.get(MainWind.SE);
+      res[7] = neigList.get(MainWind.S);
+      return res;
+   }
+
    /*********************** Healpix Utilities ***************************************************/
 
    static public final double SKYAREA = 4.*Math.PI*Math.toDegrees(1.0)*Math.toDegrees(1.0);
