@@ -1,22 +1,20 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
-// astronomiques de Strasbourgs (CDS).
-// The Aladin Desktop program is distributed under the terms
+// Copyright 2021 - Unistra/CNRS
+// The MOC API project is distributed under the terms
 // of the GNU General Public License version 3.
 //
-//This file is part of Aladin Desktop.
+//This file is part of MOC API java project.
 //
-//    Aladin Desktop is free software: you can redistribute it and/or modify
+//    MOC API java project is free software: you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
 //    the Free Software Foundation, version 3 of the License.
 //
-//    Aladin Desktop is distributed in the hope that it will be useful,
+//    MOC API java project is distributed in the hope that it will be useful,
 //    but WITHOUT ANY WARRANTY; without even the implied warranty of
 //    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 //    GNU General Public License for more details.
 //
 //    The GNU General Public License is available in COPYING file
-//    along with Aladin Desktop.
+//    along with MOC API java project.
 //
 
 package cds.moc;
@@ -46,7 +44,7 @@ public interface HealpixImpl {
     * @return spherical coord (lon,lat) (expressed in the Healpix frame)
     * @throws Exception
     */
-   public abstract double [] pix2ang(int order,long npix) throws Exception;
+   public double [] pix2ang(int order,long npix) throws Exception;
    
    /** Provide the list of HEALPix numbers fully covering a circle (for a specified order)
     * @param order Healpix order
@@ -57,5 +55,7 @@ public interface HealpixImpl {
     * @throws Exception
     */
    public long [] queryDisc(int order, double lon, double lat, double radius) throws Exception;
-
+   
+   
+   public long[] neighbours(int order, long npix) throws Exception;
 }
