@@ -40,15 +40,17 @@ import java.util.StringTokenizer;
 /**
  * Multi Order Coverage Map (MOC)
  * This class provides read, write and process methods to manipulate a Multi Order Coverage Map (MOC).
- * A MOC is used to define a Coverage in space, time, etc, or combination of these physical dimensions
+ * A MOC is used to define a Coverage in space, time, frequency etc, or combination of these physical dimensions
  * 
  * See:  IVOA MOC 2.0 standard => https://www.ivoa.net/documents/MOC/
  * 
  * This abstract class Moc describes or implements the methods generic to MOCs, 
  * whatever their type (spatial, temporal, spatio-temporal, etc).
  * This class is derived in 2 classes: Moc1D and Moc2D.
- * Moc1D is a generic class for 1 physical dimensional MOCs, which is derived into SMOC (spatial MOCs) and TMoc (temporal MOCs). 
- * Moc2D is a generic class for 2-dimensional physical MOCs, which is derived into STMOC (space-time MOC)
+ * Moc1D is a generic class for 1 physical dimensional MOCs, which is derived into SMOC (spatial MOCs),
+ *    TMoc (temporal MOCs) and FMoc (frequency MOCs). 
+ * Moc2D is a generic class for 2-dimensional physical MOCs, which is derived into STMOC (space-time MOCs),
+ *    SFMOC (space-frequency MOCs and TFMOC (time-frequency MOCs)
  * 
  * Warning: The cds.moc package has been completely revised/recoded when the IVOA MOC2.0 standard was published (2021). 
  * the HealpixMoc class is provided only to ensure compatibility with old software. It is only a wrapper to
@@ -58,7 +60,7 @@ import java.util.StringTokenizer;
  * This package manipulates and stores MOCs only as a list of ranges (unlike its predecessor 
  * which used both a hierarchical and an range architecture). 
  * This refactoring was done to allow easy extension to MOCs covering other physical dimensions 
- * (currently only SPACE, TIME or TIME.SPACE)
+ * (SPACE, TIME, FREQUENCY and combinations)
  * It uses code and algorithm initially developed by Jan Kotek, then refactored/extended by M.Reinecker, 
  * and re-extended for the specific needs of 2D MOCs (see Range and Range2 classes)
  * 
@@ -67,6 +69,7 @@ import java.util.StringTokenizer;
  * of a MOC with the IVOA MOC 2.0 standard as well as its previous versions (1.1 and 1.0).
  * 
  * @author Pierre Fernique [CDS]
+ * @version 7.0 - Feb 2023 - Support for FMOC , SFMOC and TFMOC (frequency MOC)
  * @version 6.4 - Jan 2022 - Support for Planetry MOC (alternative COORDSYS)
  * @version 6.3 - Dec 2021 - bug fixed (setMinOrder + write Fits)
  * @version 6.2 - July 2021 - perf improvement
@@ -78,7 +81,7 @@ import java.util.StringTokenizer;
 public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Moc>{
    
    /** MOC API version number */
-   static public final String VERSION = "6.3";
+   static public final String VERSION = "7.0";
 
    /** Two binary serialization - RAW is the IVOA standard */
    public static final int RAW = 0;
@@ -117,23 +120,37 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
    static public void setMocOrderLogic(int logic) { mocOrderLogic=logic; }  
    
    /** Generic MOC factory. Recognize the MOC ASCII or JSON string and create the associated space,
-    * time or space-time MOC.
+    * time, frequency, space-time or freq-space MOC.
     * @param s MOC string => ex: SMOC:3/1-4... TMOC:t29/3456-6788... STMOC:t27/... s29/...
     * @return a MOC
     */
    static public Moc createMoc(String s) throws Exception {
       if( s==null ) throw new Exception("Null string MOC");
       if( s.length()==0 ) throw new Exception("Empty string MOC");
-      
+      Moc moc = createMocByASCIISignature(s);
+      moc.add( s );
+      moc.add(null);   // in case of Moc2D, we must pass null to flush the last buffer
+      return moc;
+   }
+   
+   /** Generic MOC factory. Recognize the MOC ASCII or JSON string and create the associated space,
+    * time, frequency, space-time or freq-space MOC.
+    * @param s MOC string => ex: SMOC:3/1-4... TMOC:t29/3456-6788... STMOC:t27/... s29/...
+    * @return an EMPTY MOC (the signature is just use for determine the type of MOC)
+    */
+   static private Moc createMocByASCIISignature(String s)  throws Exception {
       Moc moc;
-      int is = s.indexOf('s');
-      int it = s.indexOf('t');
+      int is  = s.indexOf('s');
+      int it  = s.indexOf('t');
+      int ifr = s.indexOf('f');
+      
       if( it!=-1 && is!=-1 ) moc = new STMoc();
+      else if( ifr!=-1 && is!=-1 ) moc = new SFMoc();
+      else if( it!=-1 && ifr!=-1 ) moc = new FTMoc();
       else if( it!=-1 ) moc = new TMoc();
+      else if( ifr!=-1 ) moc = new FMoc();
       else moc = new SMoc();
       
-      moc.add( s );
-      moc.add(null);   // in case of STMOC, we must pass null to flush the last buffer
       return moc;
    }
    
@@ -162,11 +179,7 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
          int n = in.read(b);
          in.reset();
          String s = new String(b,0,n);
-         int is = s.indexOf('s');
-         int it = s.indexOf('t');
-         if( it!=-1 && is!=-1 ) moc = new STMoc();
-         else if( it!=-1 ) moc = new TMoc();
-         else moc = new SMoc();
+         moc = createMocByASCIISignature(s);
          moc.readASCII(in); 
          
       // FITS reader
@@ -177,12 +190,15 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
          header.readHeader(in);   // HDU 1
          in.reset();
 
-         // Create SMOC, TMOC or STMOC according to the header content
+         // Create SMOC, TMOC, FMOC or STMOC, SFMOC according to the header content
          String dim  = header.getStringFromHeader("MOCDIM");
          if( dim==null ) dim  = header.getStringFromHeader("MOC");  // Proto compatibility
          if( dim!=null ) {
             if( dim.equals("TIME") ) moc = new TMoc();
+            else if( dim.equals("FREQUENCY") ) moc = new FMoc();
             else if( dim.equals("TIME.SPACE") ) moc = new STMoc();
+            else if( dim.equals("FREQUENCY.SPACE") ) moc = new SFMoc();
+            else if( dim.equals("TIME.FREQUENCY") ) moc = new FTMoc();
          }
          
          // Proto compatibility
@@ -200,12 +216,21 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
    public void setSpaceOrder( int order ) throws Exception {
       if( this instanceof SMoc )  ((SMoc)this).setMocOrder(order);
       else if( this instanceof STMoc ) ((STMoc)this).setSpaceOrder(order);
+      else if( this instanceof SFMoc ) ((SFMoc)this).setSpaceOrder(order);
       else throw new Exception("Unsupported physical dimension");
    }
    
    public void setTimeOrder( int order ) throws Exception {
       if( this instanceof TMoc )  ((TMoc)this).setMocOrder(order);
       else if( this instanceof STMoc ) ((STMoc)this).setTimeOrder(order);
+      else if( this instanceof FTMoc ) ((FTMoc)this).setTimeOrder(order);
+      else throw new Exception("Unsupported physical dimension");
+   }
+   
+   public void setFreqOrder( int order ) throws Exception {
+      if( this instanceof FMoc )  ((FMoc)this).setMocOrder(order);
+      else if( this instanceof SFMoc ) ((SFMoc)this).setFreqOrder(order);
+      else if( this instanceof FTMoc ) ((FTMoc)this).setFreqOrder(order);
       else throw new Exception("Unsupported physical dimension");
    }
    
@@ -213,6 +238,7 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
       try {
          if( this instanceof SMoc )  return ((SMoc)this).getMocOrder();
          if( this instanceof STMoc ) return ((STMoc)this).getSpaceOrder();
+         if( this instanceof SFMoc ) return ((SFMoc)this).getSpaceOrder();
       } catch( Exception e ) { }
       return -1;
    }
@@ -221,6 +247,16 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
       try {
          if( this instanceof TMoc ) return ((TMoc)this).getMocOrder();
          if( this instanceof STMoc ) return ((STMoc)this).getTimeOrder();
+         if( this instanceof FTMoc ) return ((FTMoc)this).getTimeOrder();
+      } catch( Exception e ) { }
+      return -1;
+   }
+   
+   public int getFreqOrder() {
+      try {
+         if( this instanceof FMoc ) return ((FMoc)this).getMocOrder();
+         if( this instanceof SFMoc ) return ((SFMoc)this).getFreqOrder();
+         if( this instanceof FTMoc ) return ((FTMoc)this).getFreqOrder();
       } catch( Exception e ) { }
       return -1;
    }
@@ -234,19 +270,31 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
    public SMoc getSpaceMoc()  throws Exception {
       if( this instanceof SMoc ) return (SMoc) this;
       if( this instanceof STMoc ) return ((STMoc)this).getSpaceMoc();
+      if( this instanceof SFMoc ) return ((SFMoc)this).getSpaceMoc();
       throw new Exception("Unsupported physical dimension");
    }
    
    public TMoc getTimeMoc()  throws Exception {
       if( this instanceof TMoc ) return (TMoc) this;
       if( this instanceof STMoc ) return ((STMoc)this).getTimeMoc();
+      if( this instanceof FTMoc ) return ((FTMoc)this).getTimeMoc();
       throw new Exception("Unsupported physical dimension");
    }
    
-   public STMoc getSpaceTimeMoc()  throws Exception { return STMoc.asSTMoc(this); }
+   public FMoc getFreqMoc()  throws Exception {
+      if( this instanceof FMoc ) return (FMoc) this;
+      if( this instanceof SFMoc ) return ((SFMoc)this).getFreqMoc();
+      if( this instanceof FTMoc ) return ((FTMoc)this).getFreqMoc();
+      throw new Exception("Unsupported physical dimension");
+   }
    
-   public boolean isSpace() { return this instanceof SMoc || this instanceof STMoc; }
-   public boolean isTime()  { return this instanceof TMoc || this instanceof STMoc; }
+   public STMoc getSTMoc()  throws Exception { return STMoc.asSTMoc(this); }
+   public SFMoc getSFMoc()  throws Exception { return SFMoc.asSFMoc(this); }
+   public FTMoc getFTMoc()  throws Exception { return FTMoc.asFTMoc(this); }
+   
+   public boolean isSpace() { return this instanceof SMoc || this instanceof STMoc || this instanceof SFMoc; }
+   public boolean isTime()  { return this instanceof TMoc || this instanceof STMoc || this instanceof FTMoc; }
+   public boolean isFreq()  { return this instanceof FMoc || this instanceof SFMoc || this instanceof FTMoc; }
    
    /*************************************************** Main methods **********************************************************/
    
@@ -295,7 +343,7 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
       for( char c : s.toCharArray() ) {
          if( flagCDim &&!Character.isDigit(c) ) continue;
          if( "{}[]\"".indexOf(c)>=0 ) continue;
-         flagCDim = c=='t' || c=='s';
+         flagCDim = c=='f' || c=='t' || c=='s';
          if( c==',' ) c=' ';
          if( c==':' ) c='/';
          res.append(c);
@@ -502,7 +550,6 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
    public void read(InputStream in, int mode) throws Exception {
 
       // Auto-detection du format ?
-      BufferedInputStream bis=null;
       if( mode==UNKNOWN && !in.markSupported() ) in = new BufferedInputStream(in, 32*1024);
 
       // Read the first charactere for deciding FITS or ASCII, and reset the stream
@@ -530,26 +577,26 @@ public abstract class Moc implements Iterable<MocCell>, Cloneable, Comparable<Mo
          if( s.charAt(0)=='#' ) continue;
          add(s);
       }
-      add(null);   // ncessaire, notamment pour STMOC
+      add(null);   // ncessaire, notamment pour Moc2D
       resetCache();
    }
-   
+
    /** Read MOC from an Binary FITS stream */
    public void readFITS(InputStream in) throws Exception {
       clear();
       HeaderFits header = new HeaderFits();
       header.readHeader(in);   // HDU 0
-         header.readHeader(in);  // HDU 1
+      header.readHeader(in);   // HDU 1
       readBinary(header,in);   // Data
    }
-   
+
    /** Read data binary part from an Binary FITS stream */
    private void readBinary(HeaderFits header, InputStream in )  throws Exception {
          int naxis1 = header.getIntFromHeader("NAXIS1");
          int naxis2 = header.getIntFromHeader("NAXIS2");
          String tform = header.getStringFromHeader("TFORM1");
          int nbyte= tform.indexOf('K')>=0 ? 8 : tform.indexOf('J')>=0 ? 4 : -1;   // entier 64 bits, sinon 32
-         if( nbyte<=0 ) throw new Exception("Multi Order Coverage Map only requieres integers (32bits or 64bits)");
+         if( nbyte<=0 ) throw new Exception("Multi Order Coverage map only requieres integers (32bits or 64bits)");
          
          // Store Fits Properties
          for( String k : header ) {
