@@ -615,7 +615,7 @@ public abstract class Moc1D extends Moc {
          createMocByUniq((naxis1*naxis2)/nbyte,nbyte,buf);
       } catch( Exception e ) {
          // Erroneous MOC, maybe just not sorted => try again with another method
-         if( e.getMessage().equals("bad append operation") ) createMocByUniqUnsorted((naxis1*naxis2)/nbyte,nbyte,buf,false);
+         if( "bad append operation".equals(e.getMessage())) createMocByUniqUnsorted((naxis1*naxis2)/nbyte,nbyte,buf,false);
          else throw e;
       }
    }
