@@ -27,13 +27,16 @@ import java.util.Iterator;
  * The Moc2D class implements the methods specific to two-dimensional MOCs (e.g. TIME.SPACE).
  * @author Pierre Fernique [CDS]
  * @version 1.0 - April 2021 - creation
+ * @version 1.1 - February 2023 - Support for SFMOC
  */
 public abstract class Moc2D extends Moc{
    
-   public Range2 range;         // list of ranges (first dimension). Each range pointing to a list of range (second dimension)
+   public Range2 range;         // List of ranges (first dimension). Each range pointing to a list of range (second dimension)
    protected Moc1D protoDim1;   // Moc1D concerned for the first dimension (ex: TMoc)
    protected Moc1D protoDim2;   // MOC1D concerned for the second dimension (ex: SMoc)
    
+   protected Moc1D cacheDim2Full;  // cache: SMoc union of all space coverages
+   
    /** Generic Moc 2D creator */
    protected Moc2D(Moc1D protoDim1, Moc1D protoDim2) { 
       super();
@@ -42,6 +45,49 @@ public abstract class Moc2D extends Moc{
       clear();
    }
    
+   /** Moc2D initialization from 2 individual Mocs
+    * @param m1 Moc1D concerning the first dimension (ex: TMoc);
+    * @param m2 Moc1D concerning the second dimension (ex: SMoc);
+    * @throws Exception
+    */
+   protected void init( Moc1D m1, Moc1D m2) throws Exception {
+      setMocOrder(m1.getMocOrder(), m2.getMocOrder());
+      Range rs = m2.seeRangeList();
+      for( int i=0; i<m1.range.sz; i+=2 ) {
+         range.append(m1.range.r[i], m1.range.r[i+1], rs );
+      }
+   }
+   
+   /**
+    * Associate to the full first dimension range the Moc m2
+    * @param m2
+    * @throws Exception
+    */
+   protected void initDim2( Moc1D m2  ) throws Exception {
+      if( !m2.isEmpty() ) {
+         Range2 r = new Range2(2);
+         r.add( 0L, protoDim1.maxVal(), m2.seeRangeList() );
+         setRangeList( r );
+      }
+   }
+   
+   /**
+    * Associate to the full second dimension range the Moc m1
+    * @param m1
+    * @throws Exception
+    */
+   protected void initDim1( Moc1D m1 ) throws Exception {
+      if( !m1.isEmpty() ) {
+         Range2 r = new Range2( m1.range.sz );
+         Range r2 = new Range();
+         r2.add( 0L, protoDim2.maxVal() );
+         for( int i=0; i<m1.range.sz; i+=2 ) {
+            r.append(m1.range.r[i], m1.range.r[i+1], r2 );
+         }
+         setRangeList( r );
+      }
+   }
+  
    public String toDebug() {
       flush();
       String so1 = ""+getMocOrder1();
@@ -244,6 +290,8 @@ public abstract class Moc2D extends Moc{
       m.protoDim1 = (Moc1D)protoDim1.clone();
       m.protoDim2 = (Moc1D)protoDim2.clone();
       m.range= (range==null) ? null : new Range2(range);
+      
+      ((Moc2D)moc).cacheDim2Full=cacheDim2Full==null ? null : (Moc1D) cacheDim2Full.clone();
    }
    
    /** Return true if the Moc is empty (no coverage) */
@@ -284,7 +332,12 @@ public abstract class Moc2D extends Moc{
    public int getNbRanges() { flush(); return range.sz/2; }
    
    /** Return approximatively the amount of memory used for storing this MOC in RAM (in bytes) */
-   public long getMem() { flush(); return range.getMem(); }
+   public long getMem() {
+      flush(); 
+      long mem = range.getMem();
+      if( cacheDim2Full!=null ) mem+=cacheDim2Full.getMem();
+      return mem; 
+   }
 
    /** Clear the MOC - data only (not the properties, nor the mocOrder) */
    public void clear() { 
@@ -295,6 +348,13 @@ public abstract class Moc2D extends Moc{
       range = new Range2();
       if( protoDim1!=null ) protoDim1.sys=null;
       if( protoDim2!=null ) protoDim2.sys=null;
+      
+      cacheDim2Full=null;
+   }
+   
+   protected void resetCache() {
+      super.resetCache();
+      cacheDim2Full=null;
    }
    
    /** Degrades the resolution(s) of the MOC until the RAM size of the MOC is reduced under the specified maximum (expressed in bytes). */
@@ -536,10 +596,19 @@ public abstract class Moc2D extends Moc{
    protected long codeTime(long a)  { return a|MASK_T; }
    protected long decodeTime(long a) { return a&UNMASK_T; }
    
+   static public long MASK_F = 3L<<62;
+   static public long UNMASK_F = ~MASK_F;
+
+   protected boolean isCodedFreq(long a)  { return (a&MASK_F)!=0L; }
+   protected long codeFreq(long a)  { return a|MASK_F; }
+   protected long decodeFreq(long a) { return a&UNMASK_F; }
+
+   
    protected abstract boolean isCodedDim1(long a);
    protected abstract long codeDim1( long a);
    protected abstract long decodeDim1( long a);
    
+   
    /** Write Moc2D data in Ranges
     * @param out output stream
     * @param mode RAW or COMP_SINGLETON
