@@ -1,22 +1,20 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
-// astronomiques de Strasbourgs (CDS).
-// The Aladin Desktop program is distributed under the terms
+// Copyright 2021 - Unistra/CNRS
+// The MOC API project is distributed under the terms
 // of the GNU General Public License version 3.
 //
-//This file is part of Aladin Desktop.
+//This file is part of MOC API java project.
 //
-//    Aladin Desktop is free software: you can redistribute it and/or modify
+//    MOC API java project is free software: you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
 //    the Free Software Foundation, version 3 of the License.
 //
-//    Aladin Desktop is distributed in the hope that it will be useful,
+//    MOC API java project is distributed in the hope that it will be useful,
 //    but WITHOUT ANY WARRANTY; without even the implied warranty of
 //    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 //    GNU General Public License for more details.
 //
 //    The GNU General Public License is available in COPYING file
-//    along with Aladin Desktop.
+//    along with MOC API java project.
 //
 
 package cds.moc;
@@ -48,15 +46,25 @@ public class Range2 extends Range {
          rr[i] = new Range( other.rr[i] );
       }
    }
-
-
+   
    public void resize(int newsize) {
+      if( newsize==r.length ) return;
       super.resize(newsize);
       Range[] nSpaceRangeArray = new Range[newsize];
       System.arraycopy(rr,0,nSpaceRangeArray,0,sz/2);
       rr = nSpaceRangeArray;
    }
    
+   public void trimSize() {
+      int n=sz/2;
+      for( int i=0; i<n; i++ ) { 
+         if( i>0 && rr[i].equals(rr[i-1]) ) rr[i] = rr[i-1];
+         else rr[i].trimSize(); 
+      }
+      super.trimSize();
+   }
+   
+   
    /** Retourne un range dont la prcision des intervalles est dgrade en fonction d'un nombre de bits
     * Aggrge les intervalles si ncessaires et ajuste l'occupation mmoire
     * @param shift1 Nombre de bits dgrads - premire dimension (1 => dgradation d'un facteur 2, 2 => d'un facteur 4...)
@@ -71,9 +79,9 @@ public class Range2 extends Range {
          long a =  r[i] & mask;
          long b = (((r[i+1]-1)>>>shift1)+1 ) << shift1;
          Range r = rr[i>>>1].degrade(shift2);
-         r1.append(a, b, r );
+         r1.add(a, b, r );
       }
-      r1.trimIfTooLarge();
+      r1.trimSize();
       return r1;
    }
    
@@ -102,10 +110,13 @@ public class Range2 extends Range {
      }
      ensureCapacity(sz+2);
 
+// A FAIRE EN AMONT
+//     int sz2 = sz>>>1;
+//     rr[sz2] = sz2>1 && m!=null && m.equals( rr[sz2-1]) ? rr[sz2-1] : m;   // En cas d'galit, on utilise le MOC spatial de l'intervalle temps prcdent.
      rr[sz>>>1] = m;
-     r[sz] = a;
-     r[sz+1] = b;
-     sz+=2;
+     
+     r[sz++] = a;
+     r[sz++] = b;
   }
 
   /** Append an entire range set to the object. */
@@ -341,6 +352,14 @@ public class Range2 extends Range {
      return operation(this,other,SUBTR);
   }
   
+  // Ajustement ncessaire pour que dans le cas o il y a deux intervalles conscutifs,
+  // l'index pointe le dbut de l'intervalle suivant, plutt que la fin de l'intervalle prcdent
+  public int indexOf( long val ) {
+     int n = super.indexOf(val);
+     if( n<sz && r[n+1]==val ) n++;
+     return n;
+  }
+  
   private void add1(long a, long b, Range m1) {
      int op=UNION;
      Range2 ajout = new Range2(10);
@@ -441,7 +460,7 @@ public class Range2 extends Range {
         if( (j&1)==0 ) rr[(pos+j)>>>1] = ajout.rr[j>>>1];
      }
 
-     // Dcallage  gauche ?
+     // Dcalage  gauche ?
      if( diff<0 ) {
         int j;
         for( j=pos+ajout.sz; j<sz+diff; j++) {
@@ -455,6 +474,96 @@ public class Range2 extends Range {
      sz+=diff;
   }
   
+  public boolean overlaps( Range other) {
+     if( isEmpty() || other.isEmpty() ) return false;
+     boolean flip = this.sz>other.sz;
+     Range2 a = flip ? (Range2) other : this;
+     Range2 b = flip ? this : (Range2) other;
+     return overlaps1( a, b);
+  }
+  
+  /** Check if b overlaps a. a and b are not empty and b is smaller than a */
+  private boolean overlaps1(Range2 a, Range2 b) {
+     // Zones temporelles totalement disjointes )> aucune chance
+     if( b.r[ b.sz-1 ]<=a.r[0] || b.r[0]>=a.r[ a.sz-1 ] ) return false;
+     
+     // Recherche d'au moins un lment spatio-temporel de b contenu dans a
+     for( int ib=0; ib<b.sz; ib+=2 ) {
+        int ia1=a.indexOf(b.r[ib]);
+        int ia2=a.indexOf(b.r[ib+1]);
+        if(    (ia1&1)==0 || (ia2&1)==0     // L'un des deux tombe dans un intervalle temporel
+            || ia1!=ia2) {                  // ou on est de part et d'autre d'au moins un intervalle temporel
+           for( int i=ia1; i<=ia2; i++ ) {
+              if( (i&1)==1 ) continue;      // On ne prend en compte que les indices de dbut d'intervalle
+              if( a.rr[i>>>1].overlaps( b.rr[ib>>>1] ) ) return true;    // test spatial
+           }
+        }
+     }
+     return false;
+  }
+  
+  public boolean contains( Range other) {
+     if( isEmpty() || other.isEmpty() ) return false;
+     return contains( this, (Range2) other);
+  }
+  
+  /** Check if b is contained in a. a and b are not empty and b is smaller than a */
+  private boolean contains(Range2 a, Range2 b) {
+     // Zones temporelles totalement disjointes => aucune chance
+     if( b.r[ b.sz-1 ]<=a.r[0] || b.r[0]>=a.r[ a.sz-1 ] ) return false;
+     
+     // Toutes les composantes spatio-temporelles de b doivent tre dans a 
+     for( int ib=0; ib<b.sz; ib+=2 ) {
+        int ia=a.indexOf(b.r[ib]);
+        if( b.r[ib+1] <= a.r[ia+1] ) {  // on est bien dans un unique intervalle temporaire...
+           if( a.rr[ia>>>1].contains( b.rr[ib>>>1] ) ) continue;   // test spatial
+        }
+        return false;
+     }
+     return true;
+  }
+                                                  
+  public boolean equals( Object obj ) {
+     if( this==obj ) return true;
+     if( obj==null || !(obj instanceof Range2) ) return false;
+     Range2 other = (Range2) obj;
+     if( other.sz!=sz ) return false;
+     for (int i=0; i<sz; ++i) {
+        if (other.r[i]!=r[i]) return false;
+        int i2=i>>>1;
+        if( (i&1)==0 && other.rr[i2]!=null && !other.rr[i2].equals(rr[i2]) ) return false;
+     }
+     return true;
+  }
+  
+  public int hashCode() {
+     if (sz == 0)  return 0;
+     int result = 1;
+     for( int i=0; i<sz; i++) {
+        long element = r[i];
+        result = 31 * result + (int)(element ^ (element >>> 32));
+        if( i%2==0 ) result = 31 * result + rr[i>>>1].hashCode();
+     }
+     return result;
+  }
+
+  /** Checks the object for internal consistency. If a problem is detected,
+  an IllegalArgumentException is thrown. */
+  public void checkConsistency() {
+     if( (sz&1)!=0 ) throw new IllegalArgumentException("invalid number of entries");
+     for (int i=0; i<sz; i+=2) {
+        if (r[i]>=r[i+1]) throw new IllegalArgumentException("inconsistent entry in one first dimension range [index="+i+"]");
+        if( i>0 && r[i]<r[i-1] ) throw new IllegalArgumentException("inconsistent entries in first dimension range list [index="+i+"]");
+     }
+     for( int i=0; i<sz/2; i++ ) {
+        try {
+           rr[i].checkConsistency();
+        } catch(Exception e ) {
+           throw new IllegalArgumentException("inconsisistent second dimension range index ["+i+"] => "+e.getLocalizedMessage());
+        }
+     }
+  }
+
   public boolean check() {
      Range oldm=null;
      
@@ -485,15 +594,14 @@ public class Range2 extends Range {
    public long getMem() {
       if( r==null ) return 0L;
       long mem =  super.getMem();
-      for( int i=0;i<sz/2; i++ ) mem += rr[i].getMem();
+      int n=sz/2;
+      for( int i=0;i<n; i++ ) {
+         if( i<n-1 && rr[i]==rr[i+1] ) continue;   // Si pointe sur le mme coverage, inutile de le compter
+         mem += rr[i].getMem();
+      }
       return mem;
    }
 
-
-   public void intersect (long a, long b) {
-      throw new IllegalArgumentException("not implemented yet");
-   }
-
    public void add(long a, long b, Range m) { 
       if( sz==0 || a>r[sz-1] ) append(a,b,m);
       else add1(a,b,m);
