@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -48,7 +48,7 @@ public final class BufReader {
       int n = readShort();
       if( n==-1 ) return null;
       availability(n);
-      String s = new String(buf,offset,n);
+      String s = new String(buf,offset,n,"UTF-8");
       offset+=n;
       return s;
    }
