@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -45,10 +45,12 @@ public final class BufWriter {
     */
    static public int sizeOfString(String s) { return 2+(s==null?0:s.getBytes().length); }
 
-   /** Mmorisation d'une chaine: 2 bytes pour la taille, suivi des lettres */
+   /** Mmorisation d'une chaine: 2 bytes pour la taille, suivi des lettres en UTF16 */
    public void memoString(String s) throws Exception {
       if( s==null ) { memoShort( (short)-1); return; }
-      byte[] a = s.getBytes();
+      byte[] a = s.getBytes("UTF-8");
+      int len = a.length;
+      if( len>Short.MAX_VALUE ) len=Short.MAX_VALUE;
       memoShort( (short)a.length );
       availability(a.length);
       System.arraycopy(a,0,buf,offset,a.length);
@@ -64,7 +66,7 @@ public final class BufWriter {
    /** Mmorisation d'un byte */
    public void memoByte(byte v) throws Exception {
       availability(1);
-      buf[offset++]= v;
+      buf[offset++]= (byte)(v & 0xFF);
    }
    
    /** Mmorisation d'un short (byte de poids faible en premier) */
