@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -22,16 +22,16 @@
 package cds.mocmulti;
 
 import cds.aladin.MyProperties;
-import cds.moc.SMoc;
+import cds.moc.Moc;
 
 
 public class MocItem {
    public String mocId;
-   public SMoc moc;
+   public Moc moc;
    public MyProperties prop;
    public long dateMoc,dateProp;
    
-   public MocItem(String id,SMoc m, MyProperties p, long dMoc, long dProp) {
+   public MocItem(String id,Moc m, MyProperties p, long dMoc, long dProp) {
       mocId=id; moc=m; prop=p;
       dateMoc=dMoc; dateProp=dProp;
       
