@@ -1,10 +1,10 @@
-// Copyright 1999-2018 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
 //
-//This file is part of Aladin.
+//This file is part of Aladin Desktop.
 //
 //    Aladin Desktop is free software: you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -16,19 +16,19 @@
 //    GNU General Public License for more details.
 //
 //    The GNU General Public License is available in COPYING file
-//    along with Aladin.
+//    along with Aladin Desktop.
 //
 
 package cds.mocmulti;
 
 import cds.aladin.MyProperties;
-import cds.moc.HealpixMoc;
+import cds.moc.Moc;
 
 
 public class MocItem2 extends MocItem {
-   public HealpixMoc mocRef;   // Couverture de rfrence (zone connue)
+   public Moc mocRef;   // Couverture de rfrence (zone connue)
    
-   public MocItem2(String id,HealpixMoc m, MyProperties p, long dMoc, long dProp) {
+   public MocItem2(String id,Moc m, MyProperties p, long dMoc, long dProp) {
       super(id,m,p,dMoc,dProp);
       mocRef=null;
    }
@@ -38,5 +38,5 @@ public class MocItem2 extends MocItem {
       mocRef=null;
    }
    
-   public HealpixMoc getMocRef() { return mocRef; }
+   public Moc getMocRef() { return mocRef; }
 }
