@@ -1,5 +1,5 @@
-// Copyright 1999-2020 - Universit de Strasbourg/CNRS
-// The Aladin Desktop program is developped by the Centre de Donnes
+// Copyright 1999-2022 - Universite de Strasbourg/CNRS
+// The Aladin Desktop program is developped by the Centre de Donnees
 // astronomiques de Strasbourgs (CDS).
 // The Aladin Desktop program is distributed under the terms
 // of the GNU General Public License version 3.
@@ -20,7 +20,7 @@
 //
 
 package cds.tools;
-import java.io.*;
+import java.io.InputStream;
 
 /**
  * Interface between two Virtual Observatory applications, such as
@@ -122,7 +122,7 @@ public abstract interface VOApp {
     * see VOObserver.position() and VOObserver.pixel() associated callback methods
     * ex: addObserver(this,VOApp.POSITION|VOApp.PIXEL)
     * @param app the application to register
-    * @param eventMasq a bit field (use POSITION or PIXEL),
+    * @param eventMasq a bit field (use POSITION, PIXEL, MEASURE, STACKEVENT or MOUSEEVENT),
     *                  (0 to remove the observer)
     */
    public abstract void addObserver(VOObserver app,int eventMasq);
@@ -139,5 +139,8 @@ public abstract interface VOApp {
    /** Stack event, see addObserver() */
    public final int STACKEVENT = 8;
    
+   /** Mouse event, see addObserver() */
+   public final int MOUSEEVENT = 16;
+   
    
 }
